package com.ibm.itso.sal404.email;

import com.ibm.itso.sal404.common.util.AppProperties;
import com.ibm.itso.sal404.email.dto.*;
import com.ibm.itso.sal404.propertycatalog.dto.PropertyDTO;
import com.ibm.itso.sal404.user.dto.UserDetailsDTO;

import javax.mail.internet.InternetAddress;
import java.util.*;
import java.io.*;

// Import Log4J Logger
import org.apache.log4j.Logger;

/**
 * 
 * sal404 Realty sample application
 * 
 * @component	Email Component
 * @layer		Business Facade
 * 
 * Description of the class here
 * 
 * @author 		Bo Gong
 * @created		May 13, 2003		
 * @version		x.y.z / @May 13, 2003	
 *
 * @see		 	EmailMessage
 * 
 */
public class EmailManager implements Serializable
{

	public static final char VAR_START = '{';
	public static final char VAR_END = '}';
	
	private AppProperties _appProperties = null;
	private HashMap _messageData = null;

	// Configure Log4J Logger
	private static Logger logger = Logger.getLogger(EmailManager.class);

	/**
	 * Constructor for MailManager.
	 */
	public EmailManager()
	{
		super();
		_appProperties = AppProperties.getInstance();
	}

	/**
	 * Create greeting message.
	 * @param UserDetailsDTO The registered user 
	 */
	public EmailMessage createGreetingMessage(UserDetailsDTO userDetailsDTO)
		throws Exception
	{
		_messageData = new HashMap();

		//get email attributes from properties	
		String messageHost = _appProperties.getProperty("mail.smtp.host");
		String messageFrom = _appProperties.getProperty("mail.greeting.from");
		String messageSubject = _appProperties.getProperty("mail.greeting.subject");
		String messageContentType = _appProperties.getProperty("mail.greeting.contentType");
		String messageTemplate = _appProperties.getProperty("mail.greeting.template");

		//set message variables	from DTO	
		_messageData.put("user.firstname", userDetailsDTO.getFirstName());
		_messageData.put("user.lastname", userDetailsDTO.getLastName());
		_messageData.put("user.title", userDetailsDTO.getTitle());
		_messageData.put("user.username", userDetailsDTO.getUserName());
		_messageData.put("user.password", userDetailsDTO.getPassword());
		_messageData.put("user.email", userDetailsDTO.getEmailAddr());
		_messageData.put("user.phone", userDetailsDTO.getPhoneNum());
		_messageData.put("user.webURL", userDetailsDTO.getWebURL());

		//set email attributes
		_messageData.put("config.host", messageHost);
		_messageData.put("config.from", new InternetAddress(messageFrom));
		InternetAddress[] messageTo =
			{
				 new InternetAddress(
					userDetailsDTO.getEmailAddr(),
					userDetailsDTO.getFirstName()
						+ " "
						+ userDetailsDTO.getLastName())};
		_messageData.put("config.to", messageTo);
		_messageData.put("config.subject", messageSubject);
		_messageData.put("config.contenttype", messageContentType);
		_messageData.put("config.template", messageTemplate);

		//create email message
		return createMessage();

	}

	/**
	 * Create password reply message.
	 * @param UserDetailsDTO The registered user 
	 */
	public EmailMessage createPasswordReplyMessage(UserDetailsDTO userDetailsDTO)
		throws Exception
	{
		_messageData = new HashMap();

		//get email attributes from properties	
		String messageHost = _appProperties.getProperty("mail.smtp.host");
		String messageFrom = _appProperties.getProperty("mail.passwordReply.from");
		String messageSubject = _appProperties.getProperty("mail.passwordReply.subject");
		String messageContentType = _appProperties.getProperty("mail.passwordReply.contentType");
		String messageTemplate = _appProperties.getProperty("mail.passwordReply.template");
		
		//set message variables	from DTO	
		_messageData.put("user.firstname", userDetailsDTO.getFirstName());
		_messageData.put("user.lastname", userDetailsDTO.getLastName());
		_messageData.put("user.title", userDetailsDTO.getTitle());
		_messageData.put("user.username", userDetailsDTO.getUserName());
		_messageData.put("user.password", userDetailsDTO.getPassword());
		_messageData.put("user.email", userDetailsDTO.getEmailAddr());
		_messageData.put("user.phone", userDetailsDTO.getPhoneNum());
		_messageData.put("user.webURL", userDetailsDTO.getWebURL());

		//set email attributes
		_messageData.put("config.host", messageHost);
		_messageData.put("config.from", new InternetAddress(messageFrom));
		InternetAddress[] messageTo =
			{
				 new InternetAddress(
					userDetailsDTO.getEmailAddr(),
					userDetailsDTO.getFirstName()
						+ " "
						+ userDetailsDTO.getLastName())};
		_messageData.put("config.to", messageTo);
		_messageData.put("config.subject", messageSubject);
		_messageData.put("config.contenttype", messageContentType);
		_messageData.put("config.template", messageTemplate);

		//create email message
		return createMessage();

	}

	/**
	 * Create user interest message.
	 * @param PropertyDTO The property in which the user is interested 
 	 * @param UserDetailsDTO The registered user 
  	 * @param UserDetailsDTO The property's agent 
	 */
	public EmailMessage createUserInterestMessage(
		PropertyDTO propertyDTO,
		UserDetailsDTO userDetailsDTO,
		UserDetailsDTO agentDetailsDTO)
		throws Exception
	{
		_messageData = new HashMap();

		//get email attributes from properties	
		String messageHost = _appProperties.getProperty("mail.smtp.host");
		String messageSubject = _appProperties.getProperty("mail.userInterest.subject");
		String messageContentType = _appProperties.getProperty("mail.userInterest.contentType");
		String messageTemplate = _appProperties.getProperty("mail.userInterest.template");


		//set message variables	from userDTO	
		_messageData.put("user.firstname", userDetailsDTO.getFirstName());
		_messageData.put("user.lastname", userDetailsDTO.getLastName());
		_messageData.put("user.title", userDetailsDTO.getTitle());
		_messageData.put("user.email", userDetailsDTO.getEmailAddr());
		_messageData.put("user.phone", userDetailsDTO.getPhoneNum());

		//set message variables	from propertyDTO	
		_messageData.put("property.id", propertyDTO.getId());
		_messageData.put("property.type", propertyDTO.getType());
		_messageData.put("property.type", propertyDTO.getType());
		_messageData.put(
			"property.buildingnumber",
			propertyDTO.getBuildingNumber());
		_messageData.put("property.street", propertyDTO.getStreetName());
		_messageData.put("property.unitnumber", propertyDTO.getUnitNumber());
		_messageData.put("property.municipality", propertyDTO.getMunicipality());
		_messageData.put("property.postalcode", propertyDTO.getPostalCode());
		_messageData.put("property.price", propertyDTO.getPrice().toString());

		//set message variables	from agentDTO	
		_messageData.put("agent.firstname", agentDetailsDTO.getFirstName());
		_messageData.put("agent.lastname", agentDetailsDTO.getLastName());
		_messageData.put("agent.title", agentDetailsDTO.getTitle());

		//set email attributes
		_messageData.put("config.host", messageHost);

		_messageData.put(
			"config.from",
			new InternetAddress(
				userDetailsDTO.getEmailAddr(),
				userDetailsDTO.getFirstName()
					+ " "
					+ userDetailsDTO.getLastName()));

		InternetAddress[] messageTo =
			{
				 new InternetAddress(
					agentDetailsDTO.getEmailAddr(),
					agentDetailsDTO.getFirstName()
						+ " "
						+ agentDetailsDTO.getLastName())};

		_messageData.put("config.to", messageTo);
		_messageData.put("config.subject", messageSubject);
		_messageData.put("config.contenttype", messageContentType);
		_messageData.put("config.template", messageTemplate);

		//create email message
		return createMessage();

	}

	/**
	 * Create email message using data stored in _messageData
	 * @return EmailMessage
	 */
	private EmailMessage createMessage() throws Exception
	{

		String messageHost = (String) _messageData.get("config.host");
		InternetAddress messageFrom =
			(InternetAddress) _messageData.get("config.from");
		InternetAddress[] messageTo =
			(InternetAddress[]) _messageData.get("config.to");
		String messageSubject = (String) _messageData.get("config.subject");
		String messageContentType = (String) _messageData.get("config.contenttype");
		String messageTemplate = (String) _messageData.get("config.template");

		EmailMessage emailMessage = new EmailMessage();
		// set email message attributes        
		emailMessage.setMessageHost(messageHost);
		emailMessage.setMessageFrom(messageFrom);
		emailMessage.setMessageTo(messageTo);
		emailMessage.setMessageSubject(messageSubject);
		emailMessage.setMessageContentType(messageContentType);

		//populate message content
		StringBuffer messageContentBuff = new StringBuffer();

		try
		{
			InputStream is =
				EmailManager.class.getClassLoader().getResourceAsStream(
					messageTemplate);
			BufferedReader dis = new BufferedReader(new InputStreamReader(is));
			String line = "";
			while ((line = dis.readLine()) != null)
			{

				StringBuffer strLine = new StringBuffer();
				int startPosition = 0;

				int varStart = line.indexOf(VAR_START, startPosition);
				int varEnd = line.indexOf(VAR_END, startPosition);

				while ((varStart < varEnd) && (varEnd > 0))
				{

					//get the part before the {data}
					if (varStart > startPosition)
					{
						strLine.append(line.substring(startPosition, varStart));
					}

					//replace it with data
					String varKey = line.substring((varStart + 1), varEnd);
					String varString = (String) _messageData.get(varKey);
					if (varString != null)
					{
						strLine.append(varString);
					}

					//search it again
					startPosition = varEnd + 1;
					varStart = line.indexOf(VAR_START, startPosition);
					varEnd = line.indexOf(VAR_END, startPosition);
				}

				//get the rest of the line 
				strLine.append(line.substring(startPosition));

				//add the line into content
				messageContentBuff.append(strLine.toString() + '\n');
			}

			String messageContent = messageContentBuff.toString();
			emailMessage.setMessageContent(messageContent);

		}
		catch (FileNotFoundException fnfe)
		{
			logger.error(fnfe.getMessage());
		}
		catch (IOException ioe)
		{
			logger.error(ioe.getMessage());
		}
		catch (Exception e)
		{
			logger.error(e.getMessage());
		}

		return emailMessage;
	}

	/**
	 * Returns the appProperties.
	 * @return AppProperties
	 */
	public AppProperties getAppProperties()
	{
		return _appProperties;
	}

	/**
	 * Returns the messageData.
	 * @return HashMap
	 */
	public HashMap getMessageData()
	{
		return _messageData;
	}

	/**
	 * Sets the appProperties.
	 * @param appProperties The appProperties to set
	 */
	public void setAppProperties(AppProperties appProperties)
	{
		_appProperties = appProperties;
	}

	/**
	 * Sets the messageData.
	 * @param messageData The messageData to set
	 */
	public void setMessageData(HashMap messageData)
	{
		_messageData = messageData;
	}

}
