package com.ibm.itso.sal404.news;

import java.text.DateFormat;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.Iterator;
import java.util.Vector;

import javax.ejb.EJBException;
import javax.ejb.RemoveException;

import org.apache.log4j.Logger;

import com.ibm.itso.sal404.common.base.ManagerIf;
import com.ibm.itso.sal404.common.exception.ApplicationException;
import com.ibm.itso.sal404.common.util.AppProperties;
import com.ibm.itso.sal404.common.util.KeyGenerator;
import com.ibm.itso.sal404.news.dao.AddNewsItemDAO;
import com.ibm.itso.sal404.news.dao.DeleteNewsItemDAO;
import com.ibm.itso.sal404.news.dao.GetNewsItemDetailsDAO;
import com.ibm.itso.sal404.news.dao.GetNewsItemDetailsDAORow;
import com.ibm.itso.sal404.news.dao.ModifyNewsItemDetailsDAO;
import com.ibm.itso.sal404.news.dao.NewsItemDAO;
import com.ibm.itso.sal404.news.dao.NewsItemDAORow;
import com.ibm.itso.sal404.news.dao.SDOListNewsDAO;
import com.ibm.itso.sal404.news.dao.SDOModifyNews;
import com.ibm.itso.sal404.news.dto.NewsItemDTO;
import com.ibm.itso.sal404.news.dto.WSNewsItemDTO;

import com.ibm.etools.service.locator.ServiceLocatorManager;
import com.ibm.itso.sal404.SAL404News_itmLocalHome;
import com.ibm.itso.sal404.SAL404News_itmLocal;

import com.ibm.itso.sal404.SAL404News_itmKey;

/**
 * 
 * sal404 Realty sample application
 * 
 * @component newscomponent
 * @layer Business Facade Layer
 * 
 * Responsible for managing the News items.
 * 
 * @author Ilaria Gorla
 * @created 14/05/2003
 * @version 1.0.0
 *  
 */
public class NewsManager implements ManagerIf
{
    private boolean useJDBC = false;

    private boolean useSDO = false;

    private boolean useEJB = false;

    /** Configure Log4J Logger */
    private static Logger logger = Logger.getLogger(NewsManager.class);

    private SimpleDateFormat formatter = new SimpleDateFormat("yyyy-MM-dd");

    private final static String STATIC_SAL404News_itmLocalHome_REF_NAME = "ejb/News_itm";

    private final static Class STATIC_SAL404News_itmLocalHome_CLASS = SAL404News_itmLocalHome.class;

    /*
     * Constructor for NewsManager class
     */
    public NewsManager()
    {
        super();
        String backend = AppProperties.getInstance().getProperty(
                "newsItemBackend");
        logger.info("Backend is " + backend);
        if (backend.equalsIgnoreCase("JDBC"))
            useJDBC = true;

        if (backend.equalsIgnoreCase("SDO"))
            useSDO = true;

        if (backend.equalsIgnoreCase("EJB"))
            useEJB = true;
    }

    /*
     * Shows a list of news item. @return Vector The News items list to show.
     */
    public Vector viewNewsItem() throws ApplicationException
    {
        logger.info("ENTRY: viewNewsItem");
        Vector vectorOfNewsItem = new Vector();

        if (useSDO)
            vectorOfNewsItem = listNewsItemsSDO();
        else
            vectorOfNewsItem = listNewsItemsJDBC();

        return vectorOfNewsItem;
    }

    /**
     * @return
     * @throws ApplicationException
     */
    private Vector listNewsItemsSDO() throws ApplicationException
    {
        logger.info("Entry: listNewsItemsSDO");
        //      Vector for all news items
        Vector vectorOfNewsItem = new Vector();

        //Create the DAO object
        SDOListNewsDAO newsItemDAO = new SDOListNewsDAO();
        vectorOfNewsItem = newsItemDAO.listNewsItems();
        logger.info("Exit: listNewsItemsSDO");
        return vectorOfNewsItem;

    }

    /**
     * @return
     * @throws ApplicationException
     */
    private Vector listNewsItemsJDBC() throws ApplicationException
    {
        //Vector for all news items
        Vector vectorOfNewsItem = new Vector();
        try
        {
            //Create the DAO object
            NewsItemDAO newsItemDAO = new NewsItemDAO();

            newsItemDAO.execute();
            NewsItemDAORow[] getNewsItemDAORow = newsItemDAO.getRows();

            NewsItemDTO newsItemDTO = null;

            for (int i = 0; i < getNewsItemDAORow.length; i++)
            {
                newsItemDTO = new NewsItemDTO();

                /* Setting the News ID */
                String newsId = (String) getNewsItemDAORow[i]
                        .getNEWS_ITM_NEWS_ITM_ID();
                newsItemDTO.setId(newsId);

                /* Setting the News title */
                String newsTitle = (String) getNewsItemDAORow[i]
                        .getNEWS_ITM_NEWS_ITM_TITLE();
                newsItemDTO.setTitle(newsTitle);

                /* Setting the News date */
                Date newsDate = (Date) getNewsItemDAORow[i]
                        .getNEWS_ITM_NEWS_ITM_DATE();
                newsItemDTO.setDate(newsDate);

                /* Setting the News author */
                String newsAuthor = (String) getNewsItemDAORow[i]
                        .getNEWS_ITM_NEWS_ITM_AUTHOR();
                newsItemDTO.setAuthor(newsAuthor);

                /* Setting the News body */
                String newsBody = (String) getNewsItemDAORow[i]
                        .getNEWS_ITM_NEWS_ITM_BODY();
                newsItemDTO.setBody(newsBody);

                /* populating the vector with all the news items */
                vectorOfNewsItem.add(newsItemDTO);
            }
        }
        catch (Exception exc)
        {
            logger.info("DBerror: " + exc.getMessage());
            ApplicationException ae = new ApplicationException();
            ae.setStrutsMessage("error.news.search");
            throw ae;
        }
        finally
        {
            logger.info("EXIT:  viewNewsItem");
        }
        return vectorOfNewsItem;
    }

    /*
     * Shows the news item selected. @return NewsItemDTO The details of the News
     * item selected.
     */
    public NewsItemDTO viewNewsItemDetails(String newsId)
            throws ApplicationException
    {
        logger.info("ENTRY: viewNewsItemDetails");

        NewsItemDTO newsItemDTO = new NewsItemDTO();
        try
        {
            GetNewsItemDetailsDAO getNewsItemDetailsDAO = new GetNewsItemDetailsDAO();

            //News Id
            getNewsItemDetailsDAO.execute(newsId);

            GetNewsItemDetailsDAORow getNewsItemDetailsDAORow = getNewsItemDetailsDAO
                    .getRows()[0];

            newsItemDTO.setId(newsId);

            if (getNewsItemDetailsDAORow.getNEWS_ITM_NEWS_ITM_TITLE() != null)
                newsItemDTO.setTitle((String) getNewsItemDetailsDAORow
                        .getNEWS_ITM_NEWS_ITM_TITLE());
            else
                newsItemDTO.setTitle("");

            //Date
            newsItemDTO.setDate((Date) getNewsItemDetailsDAORow
                    .getNEWS_ITM_NEWS_ITM_DATE());

            // check the date value
            logger.debug(newsItemDTO.getDate());

            // convert from Date to String
            DateFormat dateFormat = new SimpleDateFormat("yyyy-MM-dd");
            newsItemDTO.setDate(newsItemDTO.getDate());

            //Author
            if (getNewsItemDetailsDAORow.getNEWS_ITM_NEWS_ITM_AUTHOR() != null)
                newsItemDTO.setAuthor((String) getNewsItemDetailsDAORow
                        .getNEWS_ITM_NEWS_ITM_AUTHOR());
            else
                newsItemDTO.setAuthor("");

            //Body
            if (getNewsItemDetailsDAORow.getNEWS_ITM_NEWS_ITM_BODY() != null)
                newsItemDTO.setBody((String) getNewsItemDetailsDAORow
                        .getNEWS_ITM_NEWS_ITM_BODY());
            else
                newsItemDTO.setBody("");
        }
        catch (Exception exc)
        {
            logger.error("DBerror " + exc.getMessage());

            ApplicationException ae = new ApplicationException();
            ae.setStrutsMessage("news.error.fetchNewsItem");
            throw ae;
        }
        finally
        {
            logger.info("EXIT:  viewPropertyDetails");
        }

        return newsItemDTO;
    }

    public NewsItemDTO convertWSNewsToNewsItemDTO(WSNewsItemDTO WSNews)
            throws ApplicationException
    {
        logger.info("ENTRY: convertWSNewsToNewsItemDTO");
        NewsItemDTO news = new NewsItemDTO();
        news.setAuthor(WSNews.getAuthor());
        news.setBody(WSNews.getBody());
        news.setTitle(WSNews.getTitle());
        news.setDelete(WSNews.isDelete());
        news.setId(WSNews.getId());
        try
        {
            news.setDate(formatter.parse(WSNews.getDateString()));
        }
        catch (ParseException e)
        {
            logger.info("Parse eception on Date string  "
                    + WSNews.getDateString());
            logger.info("Exception is" + e.getMessage());
            ApplicationException ae = new ApplicationException();
            ae.setStrutsMessage("error.news.search");
            throw ae;
        }
        finally
        {
            logger.info("EXIT: convertWSNewsToNewsItemDTO");
        }
        logger.info("EXIT: convertWSNewsToNewsItemDTO");
        return news;
    }

    public WSNewsItemDTO convertNewsItemDTOToWSNews(NewsItemDTO news)
    {
        WSNewsItemDTO WSNews = new WSNewsItemDTO();
        WSNews.setAuthor(news.getAuthor());
        WSNews.setBody(news.getBody());
        WSNews.setTitle(news.getTitle());
        WSNews.setId(news.getId());
        WSNews.setDelete(news.isDelete());
        WSNews.setDateString(formatter.format(news.getDate()));
        return WSNews;
    }

    public java.util.Vector viewWSNewsItem() throws ApplicationException
    {
        logger.info("ENTRY: viewWSNewsItem");

        //Vector for all news items
        Vector vectorOfNewsItem = this.viewNewsItem();
        Vector vectorOfWSNewsItem = new Vector();

        Iterator iter = vectorOfNewsItem.iterator();
        while (iter.hasNext())
        {
            NewsItemDTO element = (NewsItemDTO) iter.next();
            WSNewsItemDTO WSNews = convertNewsItemDTOToWSNews(element);
            vectorOfWSNewsItem.addElement(WSNews);

        }

        logger.info("EXIT:  viewWSNewsItem");
        return vectorOfWSNewsItem;
    }

    /*
     * Adds a news item to the News List. @param newsItemDTO The item to add to
     * the News List.
     */
    public void addNewsItem(NewsItemDTO tempNewsItemDTO)
            throws ApplicationException
    {
        logger.info("ENTRY: addNewsItem");
        if (useEJB)
            addNewsItemEJB(tempNewsItemDTO);
        else
            addNewsItemJDBC(tempNewsItemDTO);

        logger.info("EXIT:  addNewsItem");

    }

    /*
     * Modify a news item. @param newsItemDTO The item to modify.
     */
    public void modifyNewsItem(NewsItemDTO tempNewsItemDTO)
            throws ApplicationException
    {
        logger.info("ENTRY: modifyNewsItem");

        if (useSDO)
            modifyNewsItemSDO(tempNewsItemDTO);
        else if (useEJB)
            modifyNewsItemEJB(tempNewsItemDTO);
        else
            modifyNewsItemJDBC(tempNewsItemDTO);
        return;
    }

    /**
     * @param tempNewsItemDTO
     */
    private void modifyNewsItemEJB(NewsItemDTO tempNewsItemDTO)
    {
        logger.info("ENTRY: modifyNewsItemEJB");
        SAL404News_itmKey primaryKey = new SAL404News_itmKey(tempNewsItemDTO
                .getId());
        SAL404News_itmLocal aSAL404News_itmLocal = find_SAL404News_itmLocalHome_findByPrimaryKey(primaryKey);
        aSAL404News_itmLocal.setNews_itm_author(tempNewsItemDTO.getAuthor());
        aSAL404News_itmLocal.setNews_itm_body(tempNewsItemDTO.getBody());
        java.sql.Date sqlDate = new java.sql.Date(tempNewsItemDTO.getDate()
                .getTime());
        aSAL404News_itmLocal.setNews_itm_date(sqlDate);
        aSAL404News_itmLocal.setNews_itm_title(tempNewsItemDTO.getTitle());
        logger.info("EXIT: modifyNewsItemEJB");
    }

    /**
     * @param tempNewsItemDTO
     */
    private void modifyNewsItemSDO(NewsItemDTO tempNewsItemDTO)
    {
        logger.info("ENTRY: modifyNewsItemSDO");
        SDOModifyNews dao = new SDOModifyNews();
        dao.modifyNews(tempNewsItemDTO);

    }

    /**
     * 
     *  
     */
    public void deleteNewsItem(String newsItemId) throws ApplicationException
    {
        logger.info("ENTRY: deleteNewsItem");

        if (useEJB)
            deleteNewsItemEJB(newsItemId);
        else
            deleteNewsItemJDBC(newsItemId);

        logger.info("EXIT:  deleteNewsItem");
    }

    /**
     * @param newsItemId
     * @throws ApplicationException
     */
    private void deleteNewsItemEJB(String newsItemId)
            throws ApplicationException
    {
        logger.info("ENTRY: deleteNewsItemEJB");
        SAL404News_itmKey primaryKey = new SAL404News_itmKey(newsItemId);
        SAL404News_itmLocal aSAL404News_itmLocal = find_SAL404News_itmLocalHome_findByPrimaryKey(primaryKey);
        try
        {
            aSAL404News_itmLocal.remove();
        }
        catch (Exception e)
        {
            logger.info("removeError: " + e.getMessage());
            ApplicationException ae = new ApplicationException();
            ae.setStrutsMessage("error.news.delete");
            throw ae;
        }
        finally
        {
            logger.info("EXIT: deleteNewsItemEJB");
        }

    }

    /*
     * Shows the news item selected. @return NewsItemDTO The details of the News
     * item selected.
     */
    public WSNewsItemDTO viewWSNewsItemDetails(String newsId)
            throws ApplicationException
    {
        logger.info("ENTRY: viewWSNewsItemDetails");

        NewsItemDTO news = this.viewNewsItemDetails(newsId);
        WSNewsItemDTO WSNews = this.convertNewsItemDTOToWSNews(news);

        logger.info("EXIT:  viewWSPropertyDetails");

        return WSNews;
    }

    /*
     * Adds a news item to the News List. @param newsItemDTO The item to add to
     * the News List.
     */
    public void addWSNewsItem(WSNewsItemDTO tempWSNewsItemDTO)
            throws ApplicationException
    {
        logger.info("ENTRY: addWSNewsItem");

        NewsItemDTO news = this.convertWSNewsToNewsItemDTO(tempWSNewsItemDTO);
        this.addNewsItem(news);

        logger.info("EXIT:  addWSNewsItem");

    }

    /*
     * Modify a news item. @param newsItemDTO The item to modify.
     */
    private void modifyNewsItemJDBC(NewsItemDTO tempNewsItemDTO)
            throws ApplicationException
    {
        logger.info("ENTRY: modifyNewsItemJDBC");

        /*
         * instantiates all the data transfer objects preparing them to transfer
         * and receive data for inserts to the database
         */
        NewsItemDTO newsItemDTO = new NewsItemDTO();

        try
        {

            newsItemDTO = tempNewsItemDTO;

            String title = newsItemDTO.getTitle();
            Date date = newsItemDTO.getDate();
            String author = newsItemDTO.getAuthor();
            String body = newsItemDTO.getBody();
            String id = newsItemDTO.getId();

            // check the date value
            logger.debug(date);

            ModifyNewsItemDetailsDAO modifyNewsItemDetailsDAO = new ModifyNewsItemDetailsDAO();

            //updates parent property record
            modifyNewsItemDetailsDAO.execute(title, date, author, body, id);

        }
        catch (Exception exc)
        {
            logger.info("DBerror: " + exc.getMessage());
            ApplicationException ae = new ApplicationException();
            ae.setStrutsMessage("error.news.search");
            throw ae;
        }
        finally
        {
            logger.info("EXIT:  modifyNewsItemJDBC");
        }
        return;
    }

    /*
     * Adds a news item to the News List. @param newsItemDTO The item to add to
     * the News List.
     */
    public void addNewsItemEJB(NewsItemDTO tempNewsItemDTO)
            throws ApplicationException
    {
        logger.info("ENTRY: addEJBNewsItem");
        KeyGenerator keyGenerator = new KeyGenerator();
        SAL404News_itmLocal ejbNewsItem = createSAL404News_itmLocal(keyGenerator
                .getKeyString());
        ejbNewsItem.setNews_itm_author(tempNewsItemDTO.getAuthor());
        ejbNewsItem.setNews_itm_body(tempNewsItemDTO.getBody());
        java.sql.Date sqlDate = new java.sql.Date(tempNewsItemDTO.getDate()
                .getTime());
        ejbNewsItem.setNews_itm_date(sqlDate);
        ejbNewsItem.setNews_itm_title(tempNewsItemDTO.getTitle());
        logger.info("EXIT:  addEJBNewsItem");

        return;
    }

    /*
     * Adds a news item to the News List. @param newsItemDTO The item to add to
     * the News List.
     */
    public void addNewsItemJDBC(NewsItemDTO tempNewsItemDTO)
            throws ApplicationException
    {
        logger.info("ENTRY: addNewsItemJDBC");

        /*
         * instantiates all the data transfer objects preparing them to transfer
         * and receive data for inserts to the database
         */
        NewsItemDTO newsItemDTO = new NewsItemDTO();

        try
        {
            newsItemDTO = tempNewsItemDTO;

            Integer id = new Integer(1);
            String title = newsItemDTO.getTitle();
            Date date = newsItemDTO.getDate();
            String author = newsItemDTO.getAuthor();
            String body = newsItemDTO.getBody();

            AddNewsItemDAO addNewsItemDAO = new AddNewsItemDAO();
            //inserts parent property record
            addNewsItemDAO.execute(id, title, date, author, body);
        }

        catch (Exception exc)
        {
            logger.info("DBerror " + exc.getMessage());

            logger.error("addNewsItem: " + exc.getMessage());

            ApplicationException ae = new ApplicationException();
            ae.setStrutsMessage("news.error.addNewsItem");
            throw ae;
        }
        finally
        {
            logger.info("EXIT:  addNewsItemJDBC");
        }

        return;
    }

    protected SAL404News_itmLocal find_SAL404News_itmLocalHome_findByPrimaryKey(
            SAL404News_itmKey primaryKey)
    {
        SAL404News_itmLocalHome aSAL404News_itmLocalHome = (SAL404News_itmLocalHome) ServiceLocatorManager
                .getLocalHome(STATIC_SAL404News_itmLocalHome_REF_NAME,
                        STATIC_SAL404News_itmLocalHome_CLASS);
        try
        {
            if (aSAL404News_itmLocalHome != null)
                return aSAL404News_itmLocalHome.findByPrimaryKey(primaryKey);
        }
        catch (javax.ejb.FinderException fe)
        {
            // TODO Auto-generated catch block
            fe.printStackTrace();
        }
        return null;
    }

    protected SAL404News_itmLocal createSAL404News_itmLocal(String news_itm_id)
    {
        SAL404News_itmLocalHome aSAL404News_itmLocalHome = (SAL404News_itmLocalHome) ServiceLocatorManager
                .getLocalHome(STATIC_SAL404News_itmLocalHome_REF_NAME,
                        STATIC_SAL404News_itmLocalHome_CLASS);
        try
        {
            if (aSAL404News_itmLocalHome != null)
                return aSAL404News_itmLocalHome.create(news_itm_id);
        }
        catch (javax.ejb.CreateException ce)
        {
            // TODO Auto-generated catch block
            ce.printStackTrace();
        }
        return null;
    }

    /**
     * 
     *  
     */
    public void deleteNewsItemJDBC(String newsItemId)
            throws ApplicationException
    {
        logger.info("ENTRY: deleteNewsItemJDBC");
        /*
         * instantiates all the data transfer objects preparing them to transfer
         * and receive data for inserts to the database
         */
        NewsItemDTO newsItemDTO = new NewsItemDTO();

        try
        {
            DeleteNewsItemDAO deleteNewsItemDAO = new DeleteNewsItemDAO();

            deleteNewsItemDAO.execute(newsItemId);
        }
        catch (Exception exc)
        {
            logger.info("DBerror: " + exc.getMessage());
            ApplicationException ae = new ApplicationException();
            ae.setStrutsMessage("error.news.delete");
            throw ae;
        }
        finally
        {
            logger.info("EXIT:  deleteNewsItemJDBC");
        }
        return;
    }
}