package com.ibm.itso.sal404.propertycatalog;

import java.math.BigDecimal;
import java.rmi.RemoteException;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.Vector;

import org.apache.log4j.Logger;

import com.ibm.itso.sab404r.listings.dto.ListingDTO;
import com.ibm.itso.sal404.common.base.ManagerIf;
import com.ibm.itso.sal404.common.exception.ApplicationException;
import com.ibm.itso.sal404.propertycatalog.dao.AddPropertyDetailsDAO;
import com.ibm.itso.sal404.propertycatalog.dao.AddPropertyDetailsFeatureDAO;
import com.ibm.itso.sal404.propertycatalog.dao.GetPropertiesBySearchCriteriaDAO;
import com.ibm.itso.sal404.propertycatalog.dao.GetPropertiesBySearchCriteriaRowDAO;
import com.ibm.itso.sal404.propertycatalog.dao.GetPropertiesForAgentDAO;
import com.ibm.itso.sal404.propertycatalog.dao.GetPropertiesForAgentDAORow;
import com.ibm.itso.sal404.propertycatalog.dao.GetPropertyByIdDAO;
import com.ibm.itso.sal404.propertycatalog.dao.GetPropertyByIdDAORow;
import com.ibm.itso.sal404.propertycatalog.dao.GetPropertyDetailsDAO;
import com.ibm.itso.sal404.propertycatalog.dao.GetPropertyDetailsRowDAO;
import com.ibm.itso.sal404.propertycatalog.dao.GetPropertyFeaturesDAO;
import com.ibm.itso.sal404.propertycatalog.dao.GetPropertyFeaturesDAORow;
import com.ibm.itso.sal404.propertycatalog.dao.GetPropertyStatusDAO;
import com.ibm.itso.sal404.propertycatalog.dao.GetPropertyStatusDAORow;
import com.ibm.itso.sal404.propertycatalog.dao.ListingServiceDAO;
import com.ibm.itso.sal404.propertycatalog.dao.ModifyPropertyDetailsDAO;
import com.ibm.itso.sal404.propertycatalog.dao.NewPropertyIdDAO;
import com.ibm.itso.sal404.propertycatalog.dao.NewPropertyIdDAORow;
import com.ibm.itso.sal404.propertycatalog.dto.PropertyDTO;
import com.ibm.itso.sal404.propertycatalog.dto.PropertyFeatureDTO;
import com.ibm.itso.sal404.propertycatalog.dto.PropertyFeatureVectorDTO;
import com.ibm.itso.sal404.propertycatalog.dto.PropertyStatusDTO;
import com.ibm.itso.sal404.propertycatalog.dto.ResultPropertiesDTO;
import com.ibm.itso.sal404.propertycatalog.dto.ResultPropertyDetailsDTO;
import com.ibm.itso.sal404.propertycatalog.dto.ResultPropertyFeaturesDTO;
import com.ibm.itso.sal404.propertycatalog.dto.SearchPropertiesByCriteriaDTO;

/**
 * 
 * sal404 Realty sample application
 * 
 * @component propertycatalog
 * @layer business facade
 * 
 * Description of the class here Holds public methods within the
 * propertycatalog.
 * @author Gwen Gaumond, Pasi Valjus
 * @created May 13, 2003
 * @version 1.0.0 /
 * @May 13, 2003
 * 
 * @see all classes within the Property Catalog component
 *  
 */
public class PropertyCatalogManager implements ManagerIf
{
    // Configure Log4J Logger
    private static Logger logger = Logger
            .getLogger(PropertyCatalogManager.class);

    /**
     * Constructor for PropertyCatalogManager.
     */
    public PropertyCatalogManager()
    {
        super();
    }

    public PropertyDTO addPropertyDetails(PropertyDTO propertyDTO)
            throws ApplicationException
    {
        /*
         * instantiates all the data transfer objects preparing them to transfer
         * and receive data for inserts to the database
         */

        PropertyFeatureDTO propertyFeatureDTO = null;
        try
        {
            logger.info("ENTRY: addPropertyDetails");

            logger.debug("Seller ID is: " + propertyDTO.getSeller().toString());

            /*
             * The following code creates a new data access object that will
             * insert property values into the database. The values are then
             * passed to the execute method within the data access object.
             */

            AddPropertyDetailsDAO addPropertyDetailsDAO = new AddPropertyDetailsDAO();

            //The execute method inserts the property record

            addPropertyDetailsDAO.execute(propertyDTO.getUserId(), propertyDTO
                    .getType(), propertyDTO.getStatus(), propertyDTO
                    .getCountryCode(), propertyDTO.getPostalCode(), propertyDTO
                    .getRegion(), propertyDTO.getMunicipality(), propertyDTO
                    .getStreetName(), propertyDTO.getBuildingNumber(),
                    propertyDTO.getUnitNumber(),
                    propertyDTO.getPostOfficeBox(), propertyDTO
                            .getAdditionalText(), propertyDTO.getPrice(),
                    propertyDTO.getPictureURL(), propertyDTO.getSeller());

            /*
             * After the parent record is inserted, the id field that was used
             * to insert the property values - the propertyId must be retrieved.
             * It is a mandatory value in the database to insert a property
             * feature record.
             */

            propertyDTO.setId(retrieveNewPropertyId(propertyDTO));
            
       //     addToListingService(propertyDTO);

        } catch (SQLException e)
        {
            logger.error("Error when when adding property details"
                    + e.getMessage());
            ApplicationException applicationException = new ApplicationException();
            applicationException
                    .setStrutsMessage("prop.error.propertyadd.dberror");
            throw applicationException;
        } catch (Exception e)
        {
            ApplicationException applicationException = new ApplicationException();
            applicationException.setStrutsMessage("prop.error.general.failure");
            throw applicationException;
        }
        return propertyDTO;

    }

    /**
     * @param propertyDTO
     * @throws RemoteException
     */
    private void addToListingService(PropertyDTO propertyDTO) throws RemoteException
    {
        ListingServiceDAO listServiceDAO = new ListingServiceDAO();
        ListingDTO listDto = new ListingDTO();
        StringBuffer buf = new StringBuffer();
        buf.append(propertyDTO.getStreetName());
        buf.append(" ");
        buf.append(propertyDTO.getMunicipality());
        buf.append(" ");
        buf.append(propertyDTO.getPostalCode());
        buf.append(" ");
        buf.append(propertyDTO.getCountryCode());
        
        listDto.setListingAddress(buf.toString());
        listDto.setListingAgent(propertyDTO.getUserId().toString());
        listDto.setListingDescription("A great property added by Sal404");
        listDto.setListingId(propertyDTO.getId().intValue());
        listDto.setListingPrice(propertyDTO.getPrice());
        listServiceDAO.addListing(listDto);
        
    }

    public PropertyDTO addPropertyFeatures(PropertyDTO propertyDTO,
            PropertyFeatureVectorDTO propertyFeatureVectorDTO)
            throws ApplicationException
    {
        /*
         * instantiates all the data transfer objects preparing them to transfer
         * and receive data for inserts to the database
         */
        logger.debug("adding property features");
        PropertyFeatureDTO propertyFeatureDTO = null;

        try
        {
            AddPropertyDetailsFeatureDAO addPropertyDetailsFeatureDAO = new AddPropertyDetailsFeatureDAO();
            /*
             * The following code loads the propertyFeatureVector with each
             * property feature value.
             */

            for (int i = 0; i < propertyFeatureVectorDTO.size(); i++)
            {
                propertyFeatureDTO = (PropertyFeatureDTO) (propertyFeatureVectorDTO
                        .elementAt(i));
                //adds each feature into the database associated with the
                // correct property
                addPropertyDetailsFeatureDAO.execute(propertyDTO.getId(),
                        propertyFeatureDTO.getName(), propertyFeatureDTO
                                .getValue());
            }
        } catch (SQLException e)
        {
            logger.error("Error when when adding property details"
                    + e.getMessage());
            ApplicationException applicationException = new ApplicationException();
            applicationException
                    .setStrutsMessage("prop.error.propertyadd.dberror");
            throw applicationException;
        } catch (Exception e)
        {
            ApplicationException applicationException = new ApplicationException();
            applicationException.setStrutsMessage("prop.error.general.failure");
            throw applicationException;
        }
        return propertyDTO;
    }

    public Integer retrieveNewPropertyId(PropertyDTO propertyDTO)
            throws SQLException
    {
        NewPropertyIdDAO newPropertyIdDAO = new NewPropertyIdDAO();
        //This execute method will return the new property id.
        newPropertyIdDAO.execute(propertyDTO.getUserId(), propertyDTO
                .getBuildingNumber(), propertyDTO.getStreetName(), propertyDTO
                .getUnitNumber(), propertyDTO.getPostOfficeBox(), propertyDTO
                .getPrice(), propertyDTO.getPictureURL());

        NewPropertyIdDAORow[] newPropertyIdRow = newPropertyIdDAO.getRows();

        Integer propertyId = (Integer) newPropertyIdRow[0].getPROP_PROP_ID();

        return propertyId;
    }

    public PropertyDTO populatePropertyDetails(Integer propertyId)
            throws ApplicationException
    {
        logger.info("ENTRY: modifyPropertyDetailsLoad");
        PropertyDTO propertyDTO = new PropertyDTO();
        propertyDTO.setId(propertyId);
        try
        {

            propertyDTO.setId(propertyId);

            /*
             * The following code executes a database query based by the
             * propertyId parameter passed to the method and then returns the
             * data for the associated property. The ManagePropertyAction.java
             * class then uses this data to populate the
             * modifyPropertyDetails.jsp form.
             */

            GetPropertyByIdDAO getPropertyByIdDAO = new GetPropertyByIdDAO();
            //Property Id
            getPropertyByIdDAO.execute(propertyId);
            GetPropertyByIdDAORow[] getPropertyByIdRowDAO = getPropertyByIdDAO
                    .getRows();
            if (getPropertyByIdRowDAO[0].getPROP_PROP_ADDR_ADDL_TEX() != null)
                propertyDTO.setAdditionalText((String) getPropertyByIdRowDAO[0]
                        .getPROP_PROP_ADDR_ADDL_TEX());
            else
                propertyDTO.setAdditionalText("");
            //Bldg nmbr
            if (getPropertyByIdRowDAO[0].getPROP_PROP_ADDR_BLDG_NUM() != null)
                propertyDTO.setBuildingNumber((String) getPropertyByIdRowDAO[0]
                        .getPROP_PROP_ADDR_BLDG_NUM());
            else
                propertyDTO.setBuildingNumber("");
            //Municipality
            if (getPropertyByIdRowDAO[0].getPROP_PROP_ADDR_MUNI() != null)
                propertyDTO.setMunicipality((String) getPropertyByIdRowDAO[0]
                        .getPROP_PROP_ADDR_MUNI());
            else
                propertyDTO.setMunicipality("");
            //Po box
            if (getPropertyByIdRowDAO[0].getPROP_PROP_ADDR_PO_BOX() != null)
                propertyDTO.setPostOfficeBox((String) getPropertyByIdRowDAO[0]
                        .getPROP_PROP_ADDR_PO_BOX());
            else
                propertyDTO.setPostOfficeBox("");
            //Postal code
            if (getPropertyByIdRowDAO[0].getPROP_PROP_ADDR_POST_CD() != null)
                propertyDTO.setPostalCode((String) getPropertyByIdRowDAO[0]
                        .getPROP_PROP_ADDR_POST_CD());
            else
                propertyDTO.setPostalCode("");
            //Region
            if (getPropertyByIdRowDAO[0].getPROP_PROP_ADDR_RGN() != null)
                propertyDTO.setRegion((String) getPropertyByIdRowDAO[0]
                        .getPROP_PROP_ADDR_RGN());
            else
                propertyDTO.setRegion("");
            //Street name
            if (getPropertyByIdRowDAO[0].getPROP_PROP_ADDR_STRT_NAM() != null)
                propertyDTO.setStreetName((String) getPropertyByIdRowDAO[0]
                        .getPROP_PROP_ADDR_STRT_NAM());
            else
                propertyDTO.setStreetName("");
            //Unit nmbr
            if (getPropertyByIdRowDAO[0].getPROP_PROP_ADDR_UNIT_NUM() != null)
                propertyDTO.setUnitNumber((String) getPropertyByIdRowDAO[0]
                        .getPROP_PROP_ADDR_UNIT_NUM());
            else
                propertyDTO.setUnitNumber("");
            //Picture URL
            if (getPropertyByIdRowDAO[0].getPROP_PROP_PIC_URL() != null)
                propertyDTO.setPictureURL((String) getPropertyByIdRowDAO[0]
                        .getPROP_PROP_PIC_URL());
            else
                propertyDTO.setPictureURL("");
            //Price
            BigDecimal price = (BigDecimal) getPropertyByIdRowDAO[0]
                    .getPROP_PROP_PRICE();
            logger.debug("Price is " + price);
            propertyDTO.setPrice(price);
            //CountryName
            propertyDTO.setCountryCode((String) getPropertyByIdRowDAO[0]
                    .getPROP_PROP_ADDR_CNTRY_CD());
            //UserName
            propertyDTO.setUserId((Integer) getPropertyByIdRowDAO[0]
                    .getPROP_USR_ID());
            //Status
            propertyDTO.setStatus((Integer) getPropertyByIdRowDAO[0]
                    .getPROP_PROP_STATUS_ID());
            //Property type description
            propertyDTO.setType((Integer) getPropertyByIdRowDAO[0]
                    .getPROP_PROP_TYPE_ID());
            // Property seller
            propertyDTO.setSeller((Integer) getPropertyByIdRowDAO[0]
                    .getPROP_PROP_PROP_SELLER());
            logger.info("Seller is " + propertyDTO.getSeller());
        } catch (SQLException e)
        {
            logger.error("Error when when loading modify property details"
                    + e.getMessage());
            ApplicationException applicationException = new ApplicationException();
            applicationException
                    .setStrutsMessage("prop.error.propertymodifyload.dberror");
            throw applicationException;
        } catch (Exception e)
        {
            ApplicationException applicationException = new ApplicationException();
            applicationException.setStrutsMessage("prop.error.general.failure");
            throw applicationException;
        }
        logger.info("EXIT:  modifyPropertyDetailsLoad");
        return propertyDTO;
    }

    public void modifyPropertyDetails(PropertyDTO modifyPropertyDTO)
            throws ApplicationException
    {
        logger.info("ENTRY: modifyPropertyDetails");
        /*
         * instantiates all the data transfer objects preparing them to transfer
         * and receive data for inserts to the database
         */

        PropertyFeatureDTO propertyFeatureDTO = new PropertyFeatureDTO();
        PropertyFeatureVectorDTO propertyFeatureVectorDTO = new PropertyFeatureVectorDTO();
        try
        {
            logger.info("ENTRY: modifyPropertyDetails");

            ModifyPropertyDetailsDAO modifyPropertyDetailsDAO = new ModifyPropertyDetailsDAO();
            //updates the property record
            modifyPropertyDetailsDAO.execute(modifyPropertyDTO.getId(),
                    modifyPropertyDTO.getUserId(), modifyPropertyDTO.getType(),
                    modifyPropertyDTO.getStatus(), modifyPropertyDTO
                            .getCountryCode(), modifyPropertyDTO
                            .getPostalCode(), modifyPropertyDTO.getRegion(),
                    modifyPropertyDTO.getMunicipality(), modifyPropertyDTO
                            .getStreetName(), modifyPropertyDTO
                            .getBuildingNumber(), modifyPropertyDTO
                            .getUnitNumber(), modifyPropertyDTO
                            .getPostOfficeBox(), modifyPropertyDTO
                            .getAdditionalText(), modifyPropertyDTO.getPrice(),
                    modifyPropertyDTO.getPictureURL());
            
      //      changeListingService(modifyPropertyDTO);
            
        } catch (SQLException e)
        {
            logger.error("Error when when modifying property details"
                    + e.getMessage());
            ApplicationException applicationException = new ApplicationException();
            applicationException
                    .setStrutsMessage("prop.error.propertymodify.dberror");
            throw applicationException;
        } catch (Exception e)
        {
            ApplicationException applicationException = new ApplicationException();
            applicationException.setStrutsMessage("prop.error.general.failure");
            throw applicationException;
        }
        logger.info("EXIT:  modifyPropertyDetails");
        return;
    }

    public ArrayList getPropertyStatus() throws ApplicationException
    {
        ArrayList arrayPropertyStatus = new ArrayList();
        try
        {
            //Call to DAO Just testing
            logger.info("ENTRY: getPropertyStatus");
            GetPropertyStatusDAO getPropertyStatusDAO = new GetPropertyStatusDAO();
            getPropertyStatusDAO.execute();
            GetPropertyStatusDAORow[] getPropertyStatusDAORow = getPropertyStatusDAO
                    .getRows();
            for (int i = 0; i < getPropertyStatusDAO.getRows().length; i++)
            {
                PropertyStatusDTO propertyStatusDTO = new PropertyStatusDTO();
                Integer propertyStatusId = (Integer) getPropertyStatusDAORow[i]
                        .getPROP_STS_PROP_STS_ID();
                propertyStatusDTO.setId(propertyStatusId.intValue());
                propertyStatusDTO
                        .setDescription((String) getPropertyStatusDAORow[i]
                                .getPROP_STS_PROP_STS_DESC());
                arrayPropertyStatus.add(propertyStatusDTO);
            }
        } catch (SQLException e)
        {
            logger.error("Error when executing get country code"
                    + e.getMessage());
            ApplicationException applicationException = new ApplicationException();
            applicationException
                    .setStrutsMessage("prop.error.propertystatus.dberror");
            throw applicationException;
        } catch (Exception e)
        {
            ApplicationException applicationException = new ApplicationException();
            applicationException.setStrutsMessage("prop.error.general.failure");
            throw applicationException;
        }
        logger.info("EXIT:  getPropertyStatus");
        return arrayPropertyStatus;
    }

    public ResultPropertyDetailsDTO viewPropertyDetails(int propertyId)
            throws ApplicationException
    {
        logger.info("ENTRY: viewPropertyDetails");
        ResultPropertyDetailsDTO resultFromPropertyDetailsDTO = new ResultPropertyDetailsDTO();
        try
        {
            //*********************************************
            //Property details
            //*********************************************
            GetPropertyDetailsDAO getPropertyDetailsDAO = new GetPropertyDetailsDAO();
            //Property Id
            getPropertyDetailsDAO.execute(new Integer(propertyId));
            GetPropertyDetailsRowDAO getPropertyDetailsRowDAO = getPropertyDetailsDAO
                    .getRows()[0];
            //Additional text
            if (getPropertyDetailsRowDAO.getPROP_PROP_ADDR_ADDL_TEX() != null)
                resultFromPropertyDetailsDTO
                        .setAddressAdditionalText((String) getPropertyDetailsRowDAO
                                .getPROP_PROP_ADDR_ADDL_TEX());
            else
                resultFromPropertyDetailsDTO.setAddressAdditionalText("");
            //Bldg nmbr
            if (getPropertyDetailsRowDAO.getPROP_PROP_ADDR_BLDG_NUM() != null)
                resultFromPropertyDetailsDTO
                        .setAddressBuildingNumber((String) getPropertyDetailsRowDAO
                                .getPROP_PROP_ADDR_BLDG_NUM());
            else
                resultFromPropertyDetailsDTO.setAddressBuildingNumber("");
            //Municipality
            if (getPropertyDetailsRowDAO.getPROP_PROP_ADDR_MUNI() != null)
                resultFromPropertyDetailsDTO
                        .setAddressMunicipality((String) getPropertyDetailsRowDAO
                                .getPROP_PROP_ADDR_MUNI());
            else
                resultFromPropertyDetailsDTO.setAddressMunicipality("");
            //Po box
            if (getPropertyDetailsRowDAO.getPROP_PROP_ADDR_PO_BOX() != null)
                resultFromPropertyDetailsDTO
                        .setAddressPOBox((String) getPropertyDetailsRowDAO
                                .getPROP_PROP_ADDR_PO_BOX());
            else
                resultFromPropertyDetailsDTO.setAddressPOBox("");
            //Postal code
            if (getPropertyDetailsRowDAO.getPROP_PROP_ADDR_POST_CD() != null)
                resultFromPropertyDetailsDTO
                        .setAddressPostCode((String) getPropertyDetailsRowDAO
                                .getPROP_PROP_ADDR_POST_CD());
            else
                resultFromPropertyDetailsDTO.setAddressPostCode("");
            //Region
            if (getPropertyDetailsRowDAO.getPROP_PROP_ADDR_RGN() != null)
                resultFromPropertyDetailsDTO
                        .setAddressRegion((String) getPropertyDetailsRowDAO
                                .getPROP_PROP_ADDR_RGN());
            else
                resultFromPropertyDetailsDTO.setAddressRegion("");
            //Street name
            if (getPropertyDetailsRowDAO.getPROP_PROP_ADDR_STRT_NAM() != null)
                resultFromPropertyDetailsDTO
                        .setAddressStreetName((String) getPropertyDetailsRowDAO
                                .getPROP_PROP_ADDR_STRT_NAM());
            else
                resultFromPropertyDetailsDTO.setAddressStreetName("");
            //Unit nmbr
            if (getPropertyDetailsRowDAO.getPROP_PROP_ADDR_UNIT_NUM() != null)
                resultFromPropertyDetailsDTO
                        .setAddressUnitNumber((String) getPropertyDetailsRowDAO
                                .getPROP_PROP_ADDR_UNIT_NUM());
            else
                resultFromPropertyDetailsDTO.setAddressUnitNumber("");
            //Picture URL
            if (getPropertyDetailsRowDAO.getPROP_PROP_PIC_URL() != null)
                resultFromPropertyDetailsDTO
                        .setPictureURL((String) getPropertyDetailsRowDAO
                                .getPROP_PROP_PIC_URL());
            else
                resultFromPropertyDetailsDTO.setPictureURL("");
            //Price
            BigDecimal price = (BigDecimal) getPropertyDetailsRowDAO
                    .getPROP_PROP_PRICE();
            resultFromPropertyDetailsDTO.setPrice(price.doubleValue());
            //CountryName
            resultFromPropertyDetailsDTO
                    .setCountryName((String) getPropertyDetailsRowDAO
                            .getCNTRY_CNTRY_NAME());
            //UserName
            resultFromPropertyDetailsDTO
                    .setUserName((String) getPropertyDetailsRowDAO
                            .getUSR_USR_USERNAME());
            //Status
            resultFromPropertyDetailsDTO
                    .setStatusDescription((String) getPropertyDetailsRowDAO
                            .getPROP_STS_PROP_STS_DESC());
            //Property type description
            resultFromPropertyDetailsDTO
                    .setTypeDescription((String) getPropertyDetailsRowDAO
                            .getPROP_TYPE_PROP_TYPE_DESC());
            //First name
            String firstName = (String) getPropertyDetailsRowDAO
                    .getUSR_USR_FIRST_NAME();
            resultFromPropertyDetailsDTO.setFirstName(firstName);
            //Last name
            String lastName = (String) getPropertyDetailsRowDAO
                    .getUSR_USR_LAST_NAME();
            resultFromPropertyDetailsDTO.setLastName(lastName);
            //*********************************************
            //PropertyFeatures
            //*********************************************
            Vector vectorPropertyFeatures = new Vector();
            GetPropertyFeaturesDAORow[] getPropertyFeaturesDAORow = new GetPropertyFeaturesDAO()
                    .getRows();
            ResultPropertyFeaturesDTO resultFromPropertyFeaturesDTO;
            for (int i = 0; i < getPropertyFeaturesDAORow.length; i++)
            {
                resultFromPropertyFeaturesDTO = new ResultPropertyFeaturesDTO();
                resultFromPropertyFeaturesDTO
                        .setName((String) getPropertyFeaturesDAORow[i]
                                .getPROP_FTR_ITM_PROP_FTR_NAME());
                resultFromPropertyFeaturesDTO
                        .setValue((String) getPropertyFeaturesDAORow[0]
                                .getPROP_FTR_ITM_PROP_FTR_VALUE());
                vectorPropertyFeatures.add(resultFromPropertyFeaturesDTO);
            }
            resultFromPropertyDetailsDTO
                    .setPropertyFeatures(vectorPropertyFeatures);
        } catch (SQLException e)
        {
            logger.error("Error when executing view property details"
                    + e.getMessage());
            ApplicationException applicationException = new ApplicationException();
            applicationException
                    .setStrutsMessage("prop.error.property.dberror");
            applicationException
                    .setSeverityLevel(ApplicationException.FATAL_ERROR);
            throw applicationException;
        } catch (Exception e)
        {
            ApplicationException applicationException = new ApplicationException();
            applicationException.setStrutsMessage("prop.error.general.failure");
            applicationException
                    .setSeverityLevel(ApplicationException.FATAL_ERROR);
            throw applicationException;
        }
        logger.info("EXIT:  viewPropertyDetails");
        return resultFromPropertyDetailsDTO;
    }

    public Vector viewAgentProperties(int agentId) throws ApplicationException
    {
        logger.info("ENTRY: viewAgentProperties");
        //Vector for all properties
        Vector vectorProperties = new Vector();
        try
        {
            //Create the DAO
            GetPropertiesForAgentDAO getPropertiesForAgentDAO = new GetPropertiesForAgentDAO();
            getPropertiesForAgentDAO.execute(new Integer(agentId));
            GetPropertiesForAgentDAORow[] getPropertiesForAgentDAORow = getPropertiesForAgentDAO
                    .getRows();
            ResultPropertiesDTO resultFromPropertyBySearchCriteraDTO = null;
            for (int i = 0; i < getPropertiesForAgentDAORow.length; i++)
            {
                resultFromPropertyBySearchCriteraDTO = new ResultPropertiesDTO();
                //Property Id
                Integer propertyId = (Integer) getPropertiesForAgentDAORow[i]
                        .getPROP_PROP_ID();
                resultFromPropertyBySearchCriteraDTO.setId(propertyId
                        .intValue());
                //StreetName
                String streetName = (String) getPropertiesForAgentDAORow[i]
                        .getPROP_PROP_ADDR_STRT_NAM();
                resultFromPropertyBySearchCriteraDTO
                        .setAddressStreetName(streetName);
                //Propertytype
                String propertyTypeDescription = (String) getPropertiesForAgentDAORow[i]
                        .getPROP_TYPE_PROP_TYPE_DESC();
                resultFromPropertyBySearchCriteraDTO
                        .setTypeDescription(propertyTypeDescription);
                //Property status description
                String propertyStatusDescription = (String) getPropertiesForAgentDAORow[i]
                        .getPROP_STS_PROP_STS_DESC();
                resultFromPropertyBySearchCriteraDTO
                        .setStatusDescription(propertyStatusDescription);
                //Price
                BigDecimal price = (BigDecimal) getPropertiesForAgentDAORow[i]
                        .getPROP_PROP_PRICE();
                resultFromPropertyBySearchCriteraDTO.setPrice(price
                        .doubleValue());
                //User name
                String userName = (String) getPropertiesForAgentDAORow[i]
                        .getUSR_USR_USERNAME();
                resultFromPropertyBySearchCriteraDTO.setUserName(userName);
                //First name
                String firstName = (String) getPropertiesForAgentDAORow[i]
                        .getUSR_USR_FIRST_NAME();
                resultFromPropertyBySearchCriteraDTO.setFirstName(firstName);
                //Last name
                String lastName = (String) getPropertiesForAgentDAORow[i]
                        .getUSR_USR_LAST_NAME();
                resultFromPropertyBySearchCriteraDTO.setLastName(lastName);
                vectorProperties.add(resultFromPropertyBySearchCriteraDTO);
            }
        } catch (SQLException e)
        {
            logger.error("Error when executing view properties for agent"
                    + e.getMessage());
            ApplicationException applicationException = new ApplicationException();
            applicationException
                    .setStrutsMessage("prop.error.propertiesagent.dberror");
            applicationException
                    .setSeverityLevel(ApplicationException.FATAL_ERROR);
            throw applicationException;
        } catch (Exception e)
        {
            ApplicationException applicationException = new ApplicationException();
            applicationException.setStrutsMessage("prop.error.general.failure");
            applicationException
                    .setSeverityLevel(ApplicationException.FATAL_ERROR);
            throw applicationException;
        }
        logger.info("EXIT:  viewAgentProperties");
        return vectorProperties;
    }

    public Vector searchByCriteria(
            SearchPropertiesByCriteriaDTO searchByCriteriaDTO)
            throws ApplicationException
    {
        logger.info("ENTRY: searchByCriteria");
        logger.info("Input is" + searchByCriteriaDTO.getMinPrice()
                + searchByCriteriaDTO.getMaxPrice());
        //Vector for all properties
        Vector vectorProperties = new Vector();
        try
        {
            //Read the DTO for the searchcriterias
            //Property type
            Integer propertyType = new Integer(Integer
                    .parseInt(searchByCriteriaDTO.getPropertyTypeId()));
            logger.info("type " + propertyType);
            //Min price
            long minPrice = Long.parseLong(searchByCriteriaDTO.getMinPrice());
            BigDecimal minPriceBDec = BigDecimal.valueOf(minPrice);
            logger.info("min" + minPrice);
            //Max price
            long maxPrice = Long.parseLong(searchByCriteriaDTO.getMaxPrice());
            logger.info("Max" + maxPrice);
            BigDecimal maxPriceBDec = BigDecimal.valueOf(maxPrice);
            //Postal code
            String postalCode = searchByCriteriaDTO.getPostalCode();
            logger.info("Post code" + postalCode);
            //Create the DAO
            GetPropertiesBySearchCriteriaDAO getPropertiesBySearchCriteria = new GetPropertiesBySearchCriteriaDAO();
            getPropertiesBySearchCriteria.execute(propertyType, minPriceBDec,
                    maxPriceBDec, postalCode);
            GetPropertiesBySearchCriteriaRowDAO[] getPropertiesBySearchCriteriaRow = getPropertiesBySearchCriteria
                    .getRows();
            //Iterate the properties
            ResultPropertiesDTO resultFromPropertyBySearchCriteraDTO = null;
            for (int i = 0; i < getPropertiesBySearchCriteriaRow.length; i++)
            {
                resultFromPropertyBySearchCriteraDTO = new ResultPropertiesDTO();
                //Property Id
                Integer propertyId = (Integer) getPropertiesBySearchCriteriaRow[i]
                        .getPROP_PROP_ID();
                resultFromPropertyBySearchCriteraDTO.setId(propertyId
                        .intValue());
                //StreetName
                String streetName = (String) getPropertiesBySearchCriteriaRow[i]
                        .getPROP_PROP_ADDR_STRT_NAM();
                resultFromPropertyBySearchCriteraDTO
                        .setAddressStreetName(streetName);
                //Propertytype
                String propertyTypeDescription = (String) getPropertiesBySearchCriteriaRow[i]
                        .getPROP_TYPE_PROP_TYPE_DESC();
                resultFromPropertyBySearchCriteraDTO
                        .setTypeDescription(propertyTypeDescription);
                //Property status description
                String propertyStatusDescription = (String) getPropertiesBySearchCriteriaRow[i]
                        .getPROP_STS_PROP_STS_DESC();
                resultFromPropertyBySearchCriteraDTO
                        .setStatusDescription(propertyStatusDescription);
                //Price
                BigDecimal price = (BigDecimal) getPropertiesBySearchCriteriaRow[i]
                        .getPROP_PROP_PRICE();
                resultFromPropertyBySearchCriteraDTO.setPrice(price
                        .doubleValue());
                //UserName
                String userName = (String) getPropertiesBySearchCriteriaRow[i]
                        .getUSR_USR_USERNAME();
                resultFromPropertyBySearchCriteraDTO.setUserName(userName);
                //First name
                String firstName = (String) getPropertiesBySearchCriteriaRow[i]
                        .getUSR_USR_FIRST_NAME();
                resultFromPropertyBySearchCriteraDTO.setFirstName(firstName);
                //Last name
                String lastName = (String) getPropertiesBySearchCriteriaRow[i]
                        .getUSR_USR_LAST_NAME();
                resultFromPropertyBySearchCriteraDTO.setLastName(lastName);
                vectorProperties.add(resultFromPropertyBySearchCriteraDTO);
            }
        } catch (SQLException e)
        {
            logger.error("Error when executing search properties"
                    + e.getMessage());
            ApplicationException applicationException = new ApplicationException();
            applicationException
                    .setStrutsMessage("prop.error.propertiessearch.dberror");
            applicationException
                    .setSeverityLevel(ApplicationException.FATAL_ERROR);
            throw applicationException;
        } catch (Exception e)
        {
            ApplicationException applicationException = new ApplicationException();
            applicationException.setStrutsMessage("prop.error.general.failure");
            applicationException
                    .setSeverityLevel(ApplicationException.FATAL_ERROR);
            throw applicationException;
        }
        logger.info("EXIT:  searchByCriteria");
        return vectorProperties;
    }

    public static String returnSearch(
            SearchPropertiesByCriteriaDTO searchByCriteriaDTO)
            throws ApplicationException
    {
        String returnSearch = new String();
        try
        {
            logger.info("ENTRY: returnStringFromSearchByCriteria");
            Integer propertyType = new Integer(Integer
                    .parseInt(searchByCriteriaDTO.getPropertyTypeId()));
            //Min price
            long minPrice = Long.parseLong(searchByCriteriaDTO.getMinPrice());
            BigDecimal minPriceBDec = BigDecimal.valueOf(minPrice);
            //Max price
            long maxPrice = Long.parseLong(searchByCriteriaDTO.getMaxPrice());
            BigDecimal maxPriceBDec = BigDecimal.valueOf(maxPrice);
            //Postal code
            String postalCode = searchByCriteriaDTO.getPostalCode();
            //Create the DAO
            GetPropertiesBySearchCriteriaDAO getPropertiesBySearchCriteria = new GetPropertiesBySearchCriteriaDAO();
            getPropertiesBySearchCriteria.execute(propertyType, minPriceBDec,
                    maxPriceBDec, postalCode);
            GetPropertiesBySearchCriteriaRowDAO[] getPropertiesBySearchCriteriaRow = getPropertiesBySearchCriteria
                    .getRows();
            for (int i = 0; i < getPropertiesBySearchCriteriaRow.length; i++)
            {
                //Property Id
                Integer propertyId = (Integer) getPropertiesBySearchCriteriaRow[i]
                        .getPROP_PROP_ID();
                returnSearch = (returnSearch + propertyId);
                //StreetName
                String streetName = (String) getPropertiesBySearchCriteriaRow[i]
                        .getPROP_PROP_ADDR_STRT_NAM();
                returnSearch = (returnSearch + "," + streetName);
                //Propertytype
                String propertyTypeDescription = (String) getPropertiesBySearchCriteriaRow[i]
                        .getPROP_TYPE_PROP_TYPE_DESC();
                returnSearch = (returnSearch + "," + propertyTypeDescription);
                //Property status description
                String propertyStatusDescription = (String) getPropertiesBySearchCriteriaRow[i]
                        .getPROP_STS_PROP_STS_DESC();
                returnSearch = (returnSearch + "," + propertyStatusDescription);
                //Price
                BigDecimal price = (BigDecimal) getPropertiesBySearchCriteriaRow[i]
                        .getPROP_PROP_PRICE();
                returnSearch = (returnSearch + "," + price);
                //UserName
                String userName = (String) getPropertiesBySearchCriteriaRow[i]
                        .getUSR_USR_USERNAME();
                returnSearch = (returnSearch + "," + userName);
                //First name
                String firstName = (String) getPropertiesBySearchCriteriaRow[i]
                        .getUSR_USR_FIRST_NAME();
                returnSearch = (returnSearch + "," + firstName);
                //Last name
                String lastName = (String) getPropertiesBySearchCriteriaRow[i]
                        .getUSR_USR_LAST_NAME();
                returnSearch = (returnSearch + "," + lastName + ":");
            }
        } catch (SQLException e)
        {
            logger.error("Error when executing search properties"
                    + e.getMessage());
            ApplicationException applicationException = new ApplicationException();
            applicationException
                    .setStrutsMessage("prop.error.propertiessearch.dberror");
            applicationException
                    .setSeverityLevel(ApplicationException.FATAL_ERROR);
            throw applicationException;
        } catch (Exception e)
        {
            ApplicationException applicationException = new ApplicationException();
            applicationException.setStrutsMessage("prop.error.general.failure");
            throw applicationException;
        }
        logger.info("EXIT:  returnStringFromSearchByCriteria");
        return returnSearch;
    }

    /**
     * @param propertyDTO
     * @throws RemoteException
     */
    private void changeListingService(PropertyDTO propertyDTO) throws RemoteException
    {
        ListingServiceDAO listServiceDAO = new ListingServiceDAO();
        ListingDTO listDto = new ListingDTO();
        StringBuffer buf = new StringBuffer();
        buf.append(propertyDTO.getStreetName());
        buf.append(" ");
        buf.append(propertyDTO.getMunicipality());
        buf.append(" ");
        buf.append(propertyDTO.getPostalCode());
        buf.append(" ");
        buf.append(propertyDTO.getCountryCode());
        
        listDto.setListingAddress(buf.toString());
        listDto.setListingAgent(propertyDTO.getUserId().toString());
        listDto.setListingDescription("A great property changed by Sal404");
        listDto.setListingId(propertyDTO.getId().intValue());
        listDto.setListingPrice(propertyDTO.getPrice());
        listServiceDAO.changeListing(listDto);
        
    }

    
}