package com.ibm.itso.sal404.reporting;

import java.math.BigDecimal;
import java.sql.SQLException;
import java.sql.Timestamp;
import java.util.Calendar;
import java.util.Vector;

import org.apache.log4j.Logger;

import com.ibm.itso.sal404.common.base.ManagerIf;
import com.ibm.itso.sal404.common.exception.ApplicationException;
import com.ibm.itso.sal404.common.util.BooleanValueHelper;
import com.ibm.itso.sal404.reporting.dao.ReportPropertyForAgentDAO;
import com.ibm.itso.sal404.reporting.dao.ReportPropertyForAgentDAORow;
import com.ibm.itso.sal404.reporting.dao.ReportUserForPropertyDAO;
import com.ibm.itso.sal404.reporting.dao.ReportUserForPropertyDAORow;
import com.ibm.itso.sal404.reporting.dto.PropertyDetailsReportItemDTO;
import com.ibm.itso.sal404.reporting.dto.ReportDTO;
import com.ibm.itso.sal404.reporting.dto.UserDetailsReportItemDTO;

/**
 * 
 * sal404 Realty sample application
 * 
 * @component	Reporting component
 * @layer		Business logic layer
 * 
 * This class acts as a business facade for the Reporting component.
 * It exposes two public methods:
 * 	
 * 			viewInterestForAgentReport
 * 			viewInterestForPropertyReport
 * 
 * @author 		Stelios Psarras, Cyantific.net Ltd
 * @created		14 May 2003		
 * @version		1.0.0 / @14-May-03	
 *
 * @see		 	classes associated with this class
 * 
 */
public class ReportingManager implements ManagerIf
{
	private static Logger logger = Logger.getLogger(ReportingManager.class);
			
	/**
	 * Constructor for ReportingManager.
	 */
	public ReportingManager()
	{
		super();
	}
	
	public ReportDTO viewInterestForPropertyReport(int propertyId) throws ApplicationException
	{		
		Object tempObject = null;
		Vector tempReportItems = new Vector();
		ReportUserForPropertyDAO tempReportUserForPropertyDAO = null;
		ReportUserForPropertyDAORow tempReportUserForPropertyDAORow = null;
		ReportUserForPropertyDAORow[] tempReportUserForPropertyDAORows = null;
		UserDetailsReportItemDTO tempUserDetailsReportItemDTO = null;
		ReportDTO tempReportDTO = null;
		
		logger.info("ENTRY: viewInterestForPropertyReport");

		try
		{		
			/** -- begin: 	create result DTO bean	-- **/
			tempReportDTO = new ReportDTO();
			tempReportDTO.setDescription("Property Report");
			tempReportDTO.setDate(Calendar.getInstance());
			/** -- end: 	create result DTO bean	-- **/
						
			/** -- begin: create DAO bean			-- **/
			tempReportUserForPropertyDAO = new ReportUserForPropertyDAO();
			/** -- end: create DAO bean				-- **/

			/** -- begin: execute DAO bean			-- **/
			tempReportUserForPropertyDAO.execute(new Integer(propertyId));
			/** -- end: execute DAO bean			-- **/

			/** -- begin: retrieve results 			-- **/
			tempReportUserForPropertyDAORows = tempReportUserForPropertyDAO.getRows();
			if (tempReportUserForPropertyDAORows != null)
			{
				for (int i=0; i<tempReportUserForPropertyDAORows.length; i++)
				{
					tempReportUserForPropertyDAORow = tempReportUserForPropertyDAORows[i];
					tempUserDetailsReportItemDTO = new UserDetailsReportItemDTO();
					
					// firstName
					tempObject = tempReportUserForPropertyDAORow.getUSR_USR_FIRST_NAME();
					if (tempObject != null)
					{
						tempUserDetailsReportItemDTO.setFirstName((String) tempObject);
					}
					// lastName
					tempObject = tempReportUserForPropertyDAORow.getUSR_USR_LAST_NAME();
					if (tempObject != null)
					{
						tempUserDetailsReportItemDTO.setLastName((String) tempObject);
					}
					// emailAddress
					tempObject = tempReportUserForPropertyDAORow.getUSR_USR_EMAIL_ADDR();
					if (tempObject != null)
					{
						tempUserDetailsReportItemDTO.setEmailAddress((String) tempObject);
					}
					// webURL
					tempObject = tempReportUserForPropertyDAORow.getUSR_USR_WEB_URL();
					if (tempObject != null)
					{
						tempUserDetailsReportItemDTO.setWebURL((String) tempObject);
					}		
					// phoneNumber
					tempObject = tempReportUserForPropertyDAORow.getUSR_USR_PHN_NUM();
					if (tempObject != null)
					{
						tempUserDetailsReportItemDTO.setPhoneNumber((String) tempObject);
					}									
					// active
					tempObject = tempReportUserForPropertyDAORow.getUSR_USR_ACTIVE();
					if (tempObject != null)
					{
						tempUserDetailsReportItemDTO.setActive(BooleanValueHelper.convertStringToBoolean((String) tempObject));
					}									
					// emailRequested
					tempObject = tempReportUserForPropertyDAORow.getINT_LST_ITM_INT_LST_ITM_EMAIL();
					if (tempObject != null)
					{
						tempUserDetailsReportItemDTO.setEmailRequested(BooleanValueHelper.convertStringToBoolean((String) tempObject));
					}						
					// brochureRequested
					tempObject = tempReportUserForPropertyDAORow.getINT_LST_ITM_INT_LST_ITM_BROC();
					if (tempObject != null)
					{
						tempUserDetailsReportItemDTO.setBrochureRequested(BooleanValueHelper.convertStringToBoolean((String) tempObject));
					}	
					tempReportItems.add(tempUserDetailsReportItemDTO);
				}
			}
			/** -- end: retrieve results			-- **/
			
			/** -- begin: 	put results in the result
			 * 				DTO						-- **/
			tempReportDTO.setReportItems(tempReportItems);
			/** -- end: 	put results in the result
			 * 				DTO						-- **/			
		}
		catch(SQLException e)
		{
			logger.error("An error occured while executing viewInterestForPropertyReport() method: " + '\n' + e.getMessage());
			ApplicationException ae = new ApplicationException();
			ae.setStrutsMessage("reporting.error.viewInterestForPropertyReport");
			throw ae;
		}	
		catch(Exception e)
		{
			logger.error("An error occured while executing viewInterestForPropertyReport() method: " + '\n' + e.getMessage());
			ApplicationException ae = new ApplicationException();
			ae.setStrutsMessage("reporting.error.viewInterestForPropertyReport");
			throw ae;
		}			
		logger.info("EXIT: viewInterestForPropertyReport");		
		return tempReportDTO;
	}
	
	
	public ReportDTO viewInterestForAgentReport(int agentId) throws ApplicationException
	{
		Object tempObject = null;
		Vector tempReportItems = new Vector();
		ReportPropertyForAgentDAO tempReportPropertiesForAgentDAO = null;
		ReportPropertyForAgentDAORow tempReportPropertiesForAgentDAORow = null;
		ReportPropertyForAgentDAORow[] tempReportPropertiesForAgentDAORows = null;
		PropertyDetailsReportItemDTO tempPropertyDetailsReportItemDTO = null;
		ReportDTO tempReportDTO = null;
		

		logger.info("ENTRY: viewInterestForAgentReport");

		try
		{
			/** -- begin: 	create result DTO bean	-- **/
			tempReportDTO = new ReportDTO();
			tempReportDTO.setDescription("Agent Report");
			tempReportDTO.setDate(Calendar.getInstance());
			/** -- end: 	create result DTO bean	-- **/
						
			/** -- begin: create DAO bean			-- **/
			tempReportPropertiesForAgentDAO = new ReportPropertyForAgentDAO();
			/** -- end: create DAO bean				-- **/

			/** -- begin: execute DAO bean			-- **/
			tempReportPropertiesForAgentDAO.execute(new Integer(agentId));
			/** -- end: execute DAO bean			-- **/

			/** -- begin: retrieve results 			-- **/
			tempReportPropertiesForAgentDAORows = tempReportPropertiesForAgentDAO.getRows();
			if (tempReportPropertiesForAgentDAORows != null)
			{
				for (int i=0; i<tempReportPropertiesForAgentDAORows.length; i++)
				{
					tempReportPropertiesForAgentDAORow = tempReportPropertiesForAgentDAORows[i];
					tempPropertyDetailsReportItemDTO = new PropertyDetailsReportItemDTO();
					
					// id
					tempObject = tempReportPropertiesForAgentDAORow.getPROP_PROP_ID();
					if (tempObject != null)
					{
						tempPropertyDetailsReportItemDTO.setId(((Integer) tempObject).intValue());
					}										
					// typeDescription
					tempObject = tempReportPropertiesForAgentDAORow.getPROP_TYPE_PROP_TYPE_DESC();
					if (tempObject != null)
					{
						tempPropertyDetailsReportItemDTO.setTypeDescription((String) tempObject);
					}										
					// statusDescription
					tempObject = tempReportPropertiesForAgentDAORow.getPROP_STS_PROP_STS_DESC();
					if (tempObject != null)
					{
						tempPropertyDetailsReportItemDTO.setStatusDescription((String) tempObject);
					}										
					// addressCountryName
					tempObject = tempReportPropertiesForAgentDAORow.getCNTRY_CNTRY_NAME();
					if (tempObject != null)
					{
						tempPropertyDetailsReportItemDTO.setAddressCountryName((String) tempObject);
					}				
					// addressPostCode
					tempObject = tempReportPropertiesForAgentDAORow.getPROP_PROP_ADDR_POST_CD();
					if (tempObject != null)
					{
						tempPropertyDetailsReportItemDTO.setAddressPostCode((String) tempObject);
					}									
					// addressRegion
					tempObject = tempReportPropertiesForAgentDAORow.getPROP_PROP_ADDR_RGN();
					if (tempObject != null)
					{
						tempPropertyDetailsReportItemDTO.setAddressRegion((String) tempObject);
					}									
					// addressMunicipality
					tempObject = tempReportPropertiesForAgentDAORow.getPROP_PROP_ADDR_MUNI();
					if (tempObject != null)
					{
						tempPropertyDetailsReportItemDTO.setAddressMunicipality((String) tempObject);
					}									
					// addressStreetName
					tempObject = tempReportPropertiesForAgentDAORow.getPROP_PROP_ADDR_STRT_NAM();
					if (tempObject != null)
					{
						tempPropertyDetailsReportItemDTO.setAddressStreetName((String) tempObject);
					}										
					// addressUnitNumber
					tempObject = tempReportPropertiesForAgentDAORow.getPROP_PROP_ADDR_UNIT_NUM();
					if (tempObject != null)
					{
						tempPropertyDetailsReportItemDTO.setAddressUnitNumber((String) tempObject);
					}										
					// addressPOBox
					tempObject = tempReportPropertiesForAgentDAORow.getPROP_PROP_ADDR_PO_BOX();
					if (tempObject != null)
					{
						tempPropertyDetailsReportItemDTO.setAddressPOBox((String) tempObject);
					}									
					// addressBuildingNumber
					tempObject = tempReportPropertiesForAgentDAORow.getPROP_PROP_ADDR_BLDG_NUM();
					if (tempObject != null)
					{
						tempPropertyDetailsReportItemDTO.setAddressBuildingNumber((String) tempObject);
					}															
					// addressAdditionalText
					tempObject = tempReportPropertiesForAgentDAORow.getPROP_PROP_ADDR_ADDL_TEX();
					if (tempObject != null)
					{
						tempPropertyDetailsReportItemDTO.setAddressAdditionalText((String) tempObject);
					}									
					// price
					tempObject = tempReportPropertiesForAgentDAORow.getPROP_PROP_PRICE();
					if (tempObject != null)
					{
						tempPropertyDetailsReportItemDTO.setPrice(((BigDecimal) tempObject).doubleValue());
					}																																						
					// pictureURL
					tempObject = tempReportPropertiesForAgentDAORow.getPROP_PROP_PIC_URL();
					if (tempObject != null)
					{
						tempPropertyDetailsReportItemDTO.setPictureURL((String) tempObject);
					}							
					// createdOn
					tempObject = tempReportPropertiesForAgentDAORow.getPROP_PROP_CRD_ON();
					if (tempObject != null)
					{
						tempPropertyDetailsReportItemDTO.setCreatedOn((Timestamp) tempObject);
					}							
					// addedToInterestListCount
					tempObject = tempReportPropertiesForAgentDAORow.getINT_LST_ITM_INT_LST_ITM_COUNT();
					if (tempObject != null)
					{
						tempPropertyDetailsReportItemDTO.setAddedToInterestListCount(((Integer) tempObject).intValue());
					}																				
					tempReportItems.add(tempPropertyDetailsReportItemDTO);
				}
			}
			/** -- end: retrieve results			-- **/
			
			/** -- begin: 	put results in the result
			 * 				DTO						-- **/
			tempReportDTO.setReportItems(tempReportItems);
			/** -- end: 	put results in the result
			 * 				DTO						-- **/			
		}
		catch(SQLException e)
		{
			logger.error("An error occured while executing viewInterestForAgentReport() method: " + '\n' + e.getMessage());
			ApplicationException ae = new ApplicationException();
			ae.setStrutsMessage("reporting.error.viewInterestForPropertyReport");
			throw ae;
		}	
		catch(Exception e)
		{
			logger.error("An error occured while executing viewInterestForAgentReport() method: " + '\n' + e.getMessage());
			ApplicationException ae = new ApplicationException();
			ae.setStrutsMessage("reporting.error.viewInterestForPropertyReport");
			throw ae;
		}			
		logger.info("EXIT: viewInterestForAgentReport");		
		return tempReportDTO;
	}
		
}
