package com.ibm.itso.sal404.user;

import java.sql.SQLException;
import java.util.Date;

import org.apache.log4j.Logger;

import com.ibm.itso.sal404.common.base.ManagerIf;
import com.ibm.itso.sal404.common.exception.ApplicationException;
import com.ibm.itso.sal404.user.dao.CreateUserAddrDAO;
import com.ibm.itso.sal404.user.dao.CreateUserDAO;
import com.ibm.itso.sal404.user.dao.DeleteUserDAO;
import com.ibm.itso.sal404.user.dao.GetAllUsersDAO;
import com.ibm.itso.sal404.user.dao.GetAllUsersDAORow;
import com.ibm.itso.sal404.user.dao.GetIdForUserDAO;
import com.ibm.itso.sal404.user.dao.GetIdForUserDAORow;
import com.ibm.itso.sal404.user.dao.GetUsersInRoleDAO;
import com.ibm.itso.sal404.user.dao.GetUsersInRoleDAORow;
import com.ibm.itso.sal404.user.dao.UpdateUserAddressDAO;
import com.ibm.itso.sal404.user.dao.UpdateUserDetailsDAO;
import com.ibm.itso.sal404.user.dao.UserAddressSearchDAO;
import com.ibm.itso.sal404.user.dao.UserAddressSearchDAORow;
import com.ibm.itso.sal404.user.dao.UserSearchDAO;
import com.ibm.itso.sal404.user.dao.UserSearchDAORow;
import com.ibm.itso.sal404.user.dto.UserAddrDTO;
import com.ibm.itso.sal404.user.dto.UserDetailsDTO;
import com.ibm.itso.sal404.user.dto.UserSearchCriteriaDTO;
import com.ibm.itso.sal404.user.dto.UserVectorDTO;

/**
 * 
 * sal404 Realty sample application
 * 
 * @component	name of component here
 * @layer		name of layer here
 * 
 * Description of the class here
 * 
 * @author 		Author full name here
 * @created		initial creation date here		
 * @version		x.y.z / @May 15, 2003	
 *
 * @see		 	classes associated with this class
 * 
 */
public class UserManagerDB implements ManagerIf
{
	// Configure Log4J Logger
	private static Logger logger = Logger.getLogger(UserManagerDB.class);

	/**
	 * 
	 * 
	 */
	public UserDetailsDTO login(UserDetailsDTO loginDTO)
		throws ApplicationException
	{
		UserDetailsDTO userDetailsDTO = null;

		try
		{
			userDetailsDTO = buildUserDetailsDTO(loginDTO);
		}
		catch (ApplicationException e)
		{
			logger.error(e.getMessage());
			ApplicationException appEx = new ApplicationException();
			appEx.setStrutsMessage("user.error.login.failure");
			throw (appEx);
		}

		if (userDetailsDTO == null)
		{
			ApplicationException appEx = new ApplicationException();
			appEx.setStrutsMessage("user.error.login.failure");
			throw (appEx);
		}

		if (!loginDTO.getPassword().equals(userDetailsDTO.getPassword()))
		{
			ApplicationException appEx = new ApplicationException();
			appEx.setStrutsMessage("user.error.login.failure");
			throw (appEx);
		}

		return userDetailsDTO;
	}

	protected UserVectorDTO getUsersInRole(String roleName)
		throws ApplicationException
	{
		logger.info("ENTRY: getUsersInRole");
		UserVectorDTO usersInRole = new UserVectorDTO();

		GetUsersInRoleDAO usersInRoleDAO = new GetUsersInRoleDAO();
		try
		{
			usersInRoleDAO.execute(roleName);
			GetUsersInRoleDAORow[] usersInRoleDAORow = usersInRoleDAO.getRows();

			for (int i = 0; i < usersInRoleDAORow.length; i++)
			{

				UserDetailsDTO userDetailsDTO = new UserDetailsDTO();
				userDetailsDTO.setId(
					(Integer) usersInRoleDAORow[i].getUSR_USR_ID());
				userDetailsDTO.setUserName(
					(String) usersInRoleDAORow[i].getUSR_USR_USERNAME());

				userDetailsDTO.setRole(
					(String) usersInRoleDAORow[i].getUSR_USR_ROLE());

				userDetailsDTO.setTitle(new String());
				userDetailsDTO.setFirstName(
					(String) usersInRoleDAORow[i].getUSR_USR_FIRST_NAME());
				userDetailsDTO.setLastName(
					(String) usersInRoleDAORow[i].getUSR_USR_LAST_NAME());

				String tst = (String) usersInRoleDAORow[i].getUSR_USR_ACTIVE();
				if (tst.equalsIgnoreCase("Y"))
					userDetailsDTO.setActive(new Boolean(true));
				else
					userDetailsDTO.setActive(new Boolean(false));

				usersInRole.getUserVector().add(userDetailsDTO);
			}

		}
		catch (Exception e)
		{
			logger.error(e.getMessage());

			e.printStackTrace(System.err);

			ApplicationException ae = new ApplicationException();
			ae.setStrutsMessage("user.error.getting.roles");
			throw (ae);
		}
		logger.info("EXIT: getUsersInRole");
		return usersInRole;

	} /**
					 * 
					 */
	public UserDetailsDTO registerUser(UserDetailsDTO userDetailsDTO)
		throws ApplicationException
	{
		try
		{
			CreateUserDAO createUserDAO = new CreateUserDAO();

			String isActive = null;
			if ((userDetailsDTO.getActive() != null)
				&& (userDetailsDTO.getActive().booleanValue()))
				isActive = "N";
			else
				isActive = "Y";

			if (userDetailsDTO.getRole() == null)
				userDetailsDTO.setRole("Customers");

			createUserDAO.execute(
				userDetailsDTO.getUserName(),
				userDetailsDTO.getPassword(),
				userDetailsDTO.getRole(),
				userDetailsDTO.getFirstName(),
				userDetailsDTO.getLastName(),
				userDetailsDTO.getEmailAddr(),
				userDetailsDTO.getWebURL(),
				userDetailsDTO.getPhoneNum(),
				isActive);
		}
		catch (Exception e)
		{
			logger.error(e.getMessage());

			e.printStackTrace(System.err);

			ApplicationException ae = new ApplicationException();
			ae.setStrutsMessage("register.error.username.duplicate");
			throw (ae);
		}

		// pull back the record to get the id ....
		UserSearchDAO userSearchDAO = new UserSearchDAO();
		Integer userID = null;
		try
		{
			userSearchDAO.execute(userDetailsDTO.getUserName());

			UserSearchDAORow[] userSearchDAORow = userSearchDAO.getRows();

			userID = (Integer) userSearchDAORow[0].getUSR_USR_ID();
			logger.info("USER ID: " + userID);
		}
		catch (Exception e)
		{
			logger.error(e.getMessage());

			e.printStackTrace(System.err);

			ApplicationException ae = new ApplicationException();
			ae.setStrutsMessage("register.error.username.duplicate");
			throw (ae);
		}

		// create the address
		CreateUserAddrDAO createUserAddrDAO = new CreateUserAddrDAO();
		UserAddrDTO userAddrDTO = userDetailsDTO.getUserAddrDTO();
		try
		{
			createUserAddrDAO.execute(userID, new String(), // what is name?
			userAddrDTO.getAddrCntryCode(),
				userAddrDTO.getAddrPostCode(),
				userAddrDTO.getAddrRgn(),
				userAddrDTO.getAddrMuni(),
				userAddrDTO.getStreetName(),
				userAddrDTO.getAddrBldNum(),
				userAddrDTO.getAddrUnitNum(),
				userAddrDTO.getAddrPoBox(),
				userAddrDTO.getAddrAddltext());
		}
		catch (Exception e)
		{
			logger.error("Add address: " + e.getMessage());
			e.printStackTrace(System.err);
		}

		return userDetailsDTO;
	}

	/**
	 */
	public UserVectorDTO search(UserSearchCriteriaDTO userSearchCriteriaDTO)
		throws ApplicationException
	{
		logger.info("ENTRY: search");

		UserVectorDTO userVectorDTO = buildUserDetailsDTO("*");

		logger.info("EXIT:  search");
		return userVectorDTO;
	}

	/**
	 * This function builds the User DTO that is placed
	 * in the session scope.
	 * 
	 */
	public UserDetailsDTO buildUserDetailsDTO(UserDetailsDTO loginDTO)
		throws ApplicationException
	{
		UserDetailsDTO userDetailsDTO = new UserDetailsDTO();

		// pull back the record to get the id ....
		UserSearchDAO userSearchDAO = new UserSearchDAO();
		try
		{
			userSearchDAO.execute(loginDTO.getUserName());

			UserSearchDAORow[] userSearchDAORow = userSearchDAO.getRows();

			if ((userSearchDAORow == null) || (userSearchDAORow.length == 0))
				return null;

			userDetailsDTO.setId((Integer) userSearchDAORow[0].getUSR_USR_ID());
			userDetailsDTO.setUserName(
				(String) userSearchDAORow[0].getUSR_USR_USERNAME());
			userDetailsDTO.setPassword(
				(String) userSearchDAORow[0].getUSR_USR_PASSWORD());
			userDetailsDTO.setRole(
				(String) userSearchDAORow[0].getUSR_USR_ROLE());
			//			userDetailsDTO.setTitle((String)userSearchDAORow[0].getUSR_USR);
			userDetailsDTO.setTitle(new String());
			userDetailsDTO.setFirstName(
				(String) userSearchDAORow[0].getUSR_USR_FIRST_NAME());
			userDetailsDTO.setLastName(
				(String) userSearchDAORow[0].getUSR_USR_LAST_NAME());
			userDetailsDTO.setEmailAddr(
				(String) userSearchDAORow[0].getUSR_USR_EMAIL_ADDR());
			userDetailsDTO.setWebURL(
				(String) userSearchDAORow[0].getUSR_USR_WEB_URL());
			userDetailsDTO.setPhoneNum(
				(String) userSearchDAORow[0].getUSR_USR_PHN_NUM());

			String tst = (String) userSearchDAORow[0].getUSR_USR_ACTIVE();
			if (tst.equalsIgnoreCase("Y"))
				userDetailsDTO.setActive(new Boolean(true));
			else
				userDetailsDTO.setActive(new Boolean(false));

			try
			{
				userDetailsDTO.setCrdOn(
					(Date) userSearchDAORow[0].getUSR_USR_CRD_ON());
			}
			catch (Exception e)
			{
				//				userDetailsDTO.setCrdOn(new Date());
			}
		}
		catch (Exception e)
		{
			logger.error(e.getMessage());

			e.printStackTrace(System.err);

			ApplicationException ae = new ApplicationException();
			ae.setStrutsMessage("register.error.username.duplicate");
			throw (ae);
		}

		logger.debug(userDetailsDTO.getId());
		logger.debug(userDetailsDTO.getUserName());
		logger.debug(userDetailsDTO.getPassword());
		logger.debug(userDetailsDTO.getRole());
		logger.debug(userDetailsDTO.getTitle());
		logger.debug(userDetailsDTO.getFirstName());
		logger.debug(userDetailsDTO.getLastName());
		logger.debug(userDetailsDTO.getEmailAddr());
		logger.debug(userDetailsDTO.getWebURL());
		logger.debug(userDetailsDTO.getPhoneNum());

		// get the address
		UserAddressSearchDAO userAddressSearchDAO = new UserAddressSearchDAO();
		UserAddrDTO userAddrDTO = new UserAddrDTO();
		try
		{
			userAddressSearchDAO.execute(userDetailsDTO.getId());

			UserAddressSearchDAORow[] userAddressSearchDAORows =
				userAddressSearchDAO.getRows();

			userAddrDTO.setAddrId(
				(Integer) userAddressSearchDAORows[0]
					.getUSR_ADDR_USR_ADDR_ID());
			userAddrDTO.setId(
				(Integer) userAddressSearchDAORows[0].getUSR_ADDR_USR_ID());
			userAddrDTO.setAddrName(
				(String) userAddressSearchDAORows[0]
					.getUSR_ADDR_USR_ADDR_NAME());
			userAddrDTO.setAddrCntryCode(
				(String) userAddressSearchDAORows[0]
					.getUSR_ADDR_USR_ADDR_CNTRY_CD());
			userAddrDTO.setAddrPostCode(
				(String) userAddressSearchDAORows[0]
					.getUSR_ADDR_USR_ADDR_POST_CD());
			userAddrDTO.setAddrRgn(
				(String) userAddressSearchDAORows[0]
					.getUSR_ADDR_USR_ADDR_RGN());
			userAddrDTO.setAddrMuni(
				(String) userAddressSearchDAORows[0]
					.getUSR_ADDR_USR_ADDR_MUNI());
			userAddrDTO.setAddrStreetName(
				(String) userAddressSearchDAORows[0]
					.getUSR_ADDR_USR_ADDR_STRT_NAME());
			userAddrDTO.setAddrBldNum(
				(String) userAddressSearchDAORows[0]
					.getUSR_ADDR_USR_ADDR_BLDG_NUM());
			userAddrDTO.setAddrUnitNum(
				(String) userAddressSearchDAORows[0]
					.getUSR_ADDR_USR_ADDR_UNIT_NUM());
			userAddrDTO.setAddrPoBox(
				(String) userAddressSearchDAORows[0]
					.getUSR_ADDR_USR_ADDR_PO_BOX());
			userAddrDTO.setAddrAddltext(
				(String) userAddressSearchDAORows[0]
					.getUSR_ADDR_USR_ADDR_ADDL_TEXT());
			//			userAddrDTO.setCrdOn((Date)userAddressSearchDAORows[0].getUSR_ADDR_USR_ADDR_CNTRY_CD());

			logger.info("user address id: " + userAddrDTO.getId());
		}
		catch (SQLException e)
		{
			logger.error(e.getMessage());

			e.printStackTrace(System.err);

			ApplicationException ae = new ApplicationException();
			ae.setStrutsMessage("register.error.username.duplicate");
			throw ae;
		}

		userDetailsDTO.setUserAddrDTO(userAddrDTO);
		return userDetailsDTO;
	}

	/**
	 * 
	 */
	public void modifyUserDetails(UserDetailsDTO userDetailsDTO)
		throws ApplicationException
	{
		logger.debug(userDetailsDTO.getId());
		logger.debug(userDetailsDTO.getUserName());
		logger.debug(userDetailsDTO.getPassword());
		logger.debug(userDetailsDTO.getRole());
		logger.debug(userDetailsDTO.getTitle());
		logger.debug(userDetailsDTO.getFirstName());
		logger.debug(userDetailsDTO.getLastName());
		logger.debug(userDetailsDTO.getEmailAddr());
		logger.debug(userDetailsDTO.getWebURL());
		logger.debug(userDetailsDTO.getPhoneNum());

		try
		{
			UpdateUserDetailsDAO updateUserDAO = new UpdateUserDetailsDAO();

			String _tmpBool = null;
			if ((userDetailsDTO.getActive() != null)
				&& (userDetailsDTO.getActive().booleanValue()))
				_tmpBool = "Y";
			else
				_tmpBool = "N";

			updateUserDAO.execute(
				userDetailsDTO.getId(),
				userDetailsDTO.getUserName(),
				userDetailsDTO.getPassword(),
				userDetailsDTO.getRole(),
				userDetailsDTO.getFirstName(),
				userDetailsDTO.getLastName(),
				userDetailsDTO.getEmailAddr(),
				userDetailsDTO.getWebURL(),
				userDetailsDTO.getPhoneNum(),
				new String("Y"));
			
			UpdateUserAddressDAO updateUserAddtDTO = new UpdateUserAddressDAO();
			updateUserAddtDTO.execute(
			        userDetailsDTO.getAddrName(),
			        userDetailsDTO.getAddrCntryCode(),
			        userDetailsDTO.getAddrPostCode(),
			        userDetailsDTO.getAddrRgn(),
			        userDetailsDTO.getAddrMuni(),
			        userDetailsDTO.getAddrStreetName(),
			        userDetailsDTO.getAddrBldNum(),
			        userDetailsDTO.getAddrUnitNum(),
			        userDetailsDTO.getAddrPoBox(),
			        userDetailsDTO.getAddrAddltext(),
			        userDetailsDTO.getAddrId()
			);
		}
		catch (Exception e)
		{
			logger.error(e.getMessage());

			e.printStackTrace(System.err);

			ApplicationException ae = new ApplicationException();
			ae.setStrutsMessage("modify.error.user");
			throw (ae);
		}

	}

	/**
	 * 
	 * 
	 */
	public UserVectorDTO buildUserDetailsDTO(String userName)
		throws ApplicationException
	{
		UserVectorDTO userVectorDTO = new UserVectorDTO();

		// pull back the record to get the id ....
		GetAllUsersDAO getAllUsersDAO = new GetAllUsersDAO();
		GetAllUsersDAORow[] allUsersDAORows = null;
		try
		{
			getAllUsersDAO.execute();
			allUsersDAORows = (GetAllUsersDAORow[]) getAllUsersDAO.getRows();

			for (int i = 0; i < allUsersDAORows.length; i++)
			{
				UserDetailsDTO userDetailsDTO = new UserDetailsDTO();
				UserAddrDTO userAddrDTO = new UserAddrDTO();
				userDetailsDTO.setUserAddrDTO(userAddrDTO);

				userDetailsDTO.setId(
					(Integer) allUsersDAORows[i].getUSR_USR_ID());
				userDetailsDTO.setUserName(
					(String) allUsersDAORows[i].getUSR_USR_USERNAME());
				userDetailsDTO.setPassword(
					(String) allUsersDAORows[i].getUSR_USR_PASSWORD());
				userDetailsDTO.setRole(
					(String) allUsersDAORows[i].getUSR_USR_ROLE());
				//			userDetailsDTO.setTitle((String)userSearchDAORow[0].getUSR_USR);
				userDetailsDTO.setTitle(new String());
				userDetailsDTO.setFirstName(
					(String) allUsersDAORows[i].getUSR_USR_FIRST_NAME());
				userDetailsDTO.setLastName(
					(String) allUsersDAORows[i].getUSR_USR_LAST_NAME());
				userDetailsDTO.setEmailAddr(
					(String) allUsersDAORows[i].getUSR_USR_EMAIL_ADDR());
				userDetailsDTO.setWebURL(
					(String) allUsersDAORows[i].getUSR_USR_WEB_URL());
				userDetailsDTO.setPhoneNum(
					(String) allUsersDAORows[i].getUSR_USR_PHN_NUM());

				String tst = (String) allUsersDAORows[0].getUSR_USR_ACTIVE();
				if ((tst != null) && (tst.equalsIgnoreCase("Y")))
					userDetailsDTO.setActive(new Boolean(true));
				else
					userDetailsDTO.setActive(new Boolean(false));

				//				if (userSearchDAORow[0].getUSR_USR_CRD_ON() != null)
				//					userDetailsDTO.setCrdOn((Date)userSearchDAORow[0].getUSR_USR_CRD_ON());

				userVectorDTO.getUserVector().add(userDetailsDTO);
			}
		}
		catch (Exception e)
		{
			logger.error(e.getMessage());

			e.printStackTrace(System.err);

			ApplicationException ae = new ApplicationException();
			ae.setStrutsMessage("register.error.username.duplicate");
			throw (ae);
		}

		// get the address
		UserAddressSearchDAO userAddressSearchDAO = new UserAddressSearchDAO();
		try
		{
			for (int i = 0; i < allUsersDAORows.length; i++)
			{
				UserDetailsDTO userDetailsDTO =
					(UserDetailsDTO) userVectorDTO.getUserVector().elementAt(i);
				UserAddrDTO userAddrDTO = userDetailsDTO.getUserAddrDTO();

				userAddressSearchDAO.execute(userDetailsDTO.getId());

				UserAddressSearchDAORow[] userAddressSearchDAORows =
					userAddressSearchDAO.getRows();

				if ((userAddressSearchDAORows == null)
					|| (userAddressSearchDAORows.length == 0))
					continue;

				userAddrDTO.setAddrId(
					(Integer) userAddressSearchDAORows[0]
						.getUSR_ADDR_USR_ADDR_ID());
				userAddrDTO.setId(
					(Integer) userAddressSearchDAORows[0].getUSR_ADDR_USR_ID());
				userAddrDTO.setAddrName(
					(String) userAddressSearchDAORows[0]
						.getUSR_ADDR_USR_ADDR_NAME());
				userAddrDTO.setAddrCntryCode(
					(String) userAddressSearchDAORows[0]
						.getUSR_ADDR_USR_ADDR_CNTRY_CD());
				userAddrDTO.setAddrPostCode(
					(String) userAddressSearchDAORows[0]
						.getUSR_ADDR_USR_ADDR_POST_CD());
				userAddrDTO.setAddrRgn(
					(String) userAddressSearchDAORows[0]
						.getUSR_ADDR_USR_ADDR_RGN());
				userAddrDTO.setAddrMuni(
					(String) userAddressSearchDAORows[0]
						.getUSR_ADDR_USR_ADDR_MUNI());
				userAddrDTO.setAddrStreetName(
					(String) userAddressSearchDAORows[0]
						.getUSR_ADDR_USR_ADDR_STRT_NAME());
				userAddrDTO.setAddrBldNum(
					(String) userAddressSearchDAORows[0]
						.getUSR_ADDR_USR_ADDR_BLDG_NUM());
				userAddrDTO.setAddrUnitNum(
					(String) userAddressSearchDAORows[0]
						.getUSR_ADDR_USR_ADDR_UNIT_NUM());
				userAddrDTO.setAddrPoBox(
					(String) userAddressSearchDAORows[0]
						.getUSR_ADDR_USR_ADDR_PO_BOX());
				userAddrDTO.setAddrAddltext(
					(String) userAddressSearchDAORows[0]
						.getUSR_ADDR_USR_ADDR_ADDL_TEXT());
				//			userAddrDTO.setCrdOn((Date)userAddressSearchDAORows[0].getUSR_ADDR_USR_ADDR_CNTRY_CD());
			}
		}
		catch (SQLException e)
		{
			logger.error(e.getMessage());

			e.printStackTrace(System.err);

			ApplicationException ae = new ApplicationException();
			ae.setStrutsMessage("register.error.username.duplicate");
			throw ae;
		}
		catch (Exception e)
		{
			logger.error(e.getMessage());

			e.printStackTrace(System.err);
		}

		return userVectorDTO;
	}

	/**
	 * 
	 * 
	 */
	public void deleteUser(UserDetailsDTO userDetails)
	{
		logger.info("Delete user: " + userDetails.getId());
		//	 	logger.info("Delete user addr: " + userDetails.getUserAddrDTO().getId());
		try
		{
			// delete the address first
			//	 		DeleteUserAddrDAO deleteUserAddrDAO = new DeleteUserAddrDAO();
			//			deleteUserAddrDAO.execute(userDetails.getUserAddrDTO().getId());	 		

			// delete the user
			DeleteUserDAO deleteUserDAO = new DeleteUserDAO();
			deleteUserDAO.execute(userDetails.getId());
		}
		catch (Exception e)
		{
			logger.error("Error deleting user " + e.getMessage());
		}
	}

	/**
	 * Constructor for UserManagerDB.
	 */
	public UserManagerDB()
	{
		super();
	}
	public UserDetailsDTO getIdForUser(UserDetailsDTO userDTO)
		throws ApplicationException
	{
		UserVectorDTO userVectorDTO = new UserVectorDTO();

		// pull back the record to get the id ....
		GetIdForUserDAO idDAO = new GetIdForUserDAO();
		GetIdForUserDAORow[] idDAORows = null;

		try
		{
			idDAO.execute(userDTO.getUserName());
			idDAORows = (GetIdForUserDAORow[]) idDAO.getRows();

			for (int i = 0; i < idDAORows.length; i++)
			{
				UserDetailsDTO userDetailsDTO = new UserDetailsDTO();
				userDetailsDTO.setId((Integer) idDAORows[i].getUSR_USR_ID());
				userVectorDTO.getUserVector().add(userDetailsDTO);
			}
		}
		catch (SQLException e)
		{
			logger.error(e.getMessage());

			e.printStackTrace(System.err);

			ApplicationException ae = new ApplicationException();
			ae.setStrutsMessage("register.error.getting.user.ID");
			throw (ae);
		}
		userDTO.setId(
			((UserDetailsDTO) userVectorDTO.getUserVector().firstElement())
				.getId());

		return userDTO;

	}
}
