package com.ibm.itso.sal404.user;

import java.util.Date;
import java.util.Hashtable;
import java.util.Iterator;

import javax.naming.AuthenticationException;
import javax.naming.CommunicationException;
import javax.naming.Context;
import javax.naming.NameAlreadyBoundException;
import javax.naming.NamingEnumeration;
import javax.naming.NamingException;
import javax.naming.directory.Attribute;
import javax.naming.directory.Attributes;
import javax.naming.directory.BasicAttribute;
import javax.naming.directory.BasicAttributes;
import javax.naming.directory.DirContext;
import javax.naming.directory.SearchControls;
import javax.naming.directory.SearchResult;

import com.ibm.itso.sal404.common.base.ManagerIf;
import com.ibm.itso.sal404.common.exception.ApplicationException;
import com.ibm.itso.sal404.common.util.AppProperties;
import com.ibm.itso.sal404.user.dto.UserAddrDTO;
import com.ibm.itso.sal404.user.dto.UserDetailsDTO;
import com.ibm.itso.sal404.user.dto.UserSearchCriteriaDTO;
import com.ibm.itso.sal404.user.dto.UserVectorDTO;

// Import Log4J Logger
import org.apache.log4j.Logger;

/**
 * 
 * sal404 Realty sample application
 * 
 * @component	name of component here
 * @layer		name of layer here
 * 
 * Description of the class here
 * 
 * @author 		Author full name here
 * @created		initial creation date here		
 * @version		x.y.z / @${date}	
 *
 * @see		 	classes associated with this class
 * 
 */
public class UserManagerLDAP implements ManagerIf
{
	// Configure Log4J Logger
	private static Logger logger = Logger.getLogger(UserManagerLDAP.class);

	//  naming context - if null, then class is not bound to a server
	private DirContext ctx = null;

	/**
	 * 
	 * 
	 */
	public UserDetailsDTO login(UserDetailsDTO loginDTO)
		throws ApplicationException
	{
		//  if bound, unbind
		if (getCtx() != null)
		{
			try
			{
				getCtx().close();
			}
			catch (NamingException ne)
			{
				logger.error("error closing context");
			}
			finally
			{
				setCtx(null);
			}
		}

		//  environment hashtable
		Hashtable env = new Hashtable(11);

		env.put(
			"java.naming.ldap.noBind",
			AppProperties.getInstance().getProperty("java.naming.ldap.noBind"));

		env.put(
			Context.SECURITY_AUTHENTICATION,
			AppProperties.getInstance().getProperty(
				Context.SECURITY_AUTHENTICATION));

		env.put(
			"java.naming.factory.initial",
			AppProperties.getInstance().getProperty(
				"java.naming.factory.initial"));

		env.put(
			"java.naming.factory.url.pkgs",
			AppProperties.getInstance().getProperty(
				"java.naming.factory.url.pkgs"));

		env.put(
			"java.naming.provider.url",
			AppProperties.getInstance().getProperty(
				"java.naming.provider.url"));

		logger.debug(
			"LDAP server: "
				+ AppProperties.getInstance().getProperty(
					"java.naming.provider.url"));

		// build the user id for LDAP
		String user =
			"cn="
				+ loginDTO.getUserName()
				+ ","
				+ AppProperties.getInstance().getProperty("search_base");

		env.put(Context.SECURITY_PRINCIPAL, user);
		env.put(Context.SECURITY_CREDENTIALS, loginDTO.getPassword());

		//  Create the initial directory context. Let any exceptions be thrown,
		// but log exit in the finally clause.
		try
		{
			setCtx(new javax.naming.directory.InitialDirContext(env));
		}
		catch (AuthenticationException ae)
		{
			// invalid credentials
			logger.error("ERROR: " + ae.getMessage());

			ApplicationException appEx = new ApplicationException();
			appEx.setStrutsMessage("user.error.login.failure");
			throw (appEx);
		}
		catch (CommunicationException ce)
		{
			// can't find directory server
			logger.error("ERROR: " + ce.getMessage());

			ApplicationException appEx = new ApplicationException();
			appEx.setStrutsMessage("user.error.directoryserver.failure");
			throw (appEx);
		}
		catch (NamingException ne)
		{
			logger.error("ERROR: " + ne.getMessage());

			ApplicationException appEx = new ApplicationException();
			appEx.setStrutsMessage("user.error.general.failure");
			throw (appEx);
		}
		catch (Throwable t)
		{
			logger.error("ERROR: " + t.getMessage());

			ApplicationException appEx = new ApplicationException();
			appEx.setStrutsMessage("user.error.general.failure");
			throw (appEx);
		}
		finally
		{
			logger.info("EXIT:  login");
		}

		// Initialise the User DTO
		UserVectorDTO userVectorDTO =
			buildUserDetailsDTO(loginDTO.getUserName());

		if (userVectorDTO.getUserVector().isEmpty())
			return null;
		else
			return (UserDetailsDTO) userVectorDTO.getUserVector().elementAt(0);
	}

	/**
		* 
		*/
	public void logout()
	{
		logger.info("ENTRY: logout");
		//  if bound, unbind
		if (getCtx() != null)
		{
			try
			{
				getCtx().close();
			}
			catch (NamingException ne)
			{
				//  shouldn't happen, intentionally ignore
				logger.error("ERROR: " + ne.getMessage());
			}
			setCtx(null);
		}
		logger.info("EXIT:  logout");
	}

	/**
	 * User Registration
	 */
	public UserDetailsDTO registerUser(UserDetailsDTO userDetailsDTO)
		throws ApplicationException
	{
		logger.debug("username: " + userDetailsDTO.getUserName());

		UserAddrDTO userAddrDTO = userDetailsDTO.getUserAddrDTO();

		String name =
			"cn="
				+ userDetailsDTO.getUserName()
				+ ","
				+ AppProperties.getInstance().getProperty("search_base");

		Attribute oc = new BasicAttribute("objectclass");

		oc.add("inetOrgPerson");
		oc.add("organizationalPerson");
		oc.add("person");
		oc.add("top");

		BasicAttributes attrs = new BasicAttributes();
		attrs.put(oc);
		attrs.put("cn", userDetailsDTO.getUserName());
		attrs.put("sn", userDetailsDTO.getLastName());
		attrs.put("givenName", userDetailsDTO.getFirstName());
		attrs.put("userPassword", userDetailsDTO.getPassword());
		attrs.put("mail", userDetailsDTO.getEmailAddr());
		attrs.put("telephoneNumber", userDetailsDTO.getPhoneNum());
		attrs.put("title", userDetailsDTO.getTitle());
		attrs.put("labeledURI", userDetailsDTO.getWebURL());
		attrs.put("uid", userDetailsDTO.getId().toString());

		logger.info("UID: " + userDetailsDTO.getId().toString());

		// address
		attrs.put("street", userAddrDTO.getStreetName());
		attrs.put("postalCode", userAddrDTO.getAddrPostCode());
		attrs.put("postOfficeBox", userAddrDTO.getAddrPoBox());
		attrs.put("roomNumber", userAddrDTO.getAddrBldNum());
		attrs.put("st", userAddrDTO.getAddrMuni());

		loginAdmin();
		try
		{
			getCtx().createSubcontext(name, attrs);
			String customers =
				"cn=Customers,"
					+ AppProperties.getInstance().getProperty("role_search_base");
			modifyRole(userDetailsDTO.getUserName(), customers, true);
		}
		catch (NameAlreadyBoundException e)
		{
			logger.error("ERROR: " + e.getMessage());

			ApplicationException ae = new ApplicationException();
			ae.setStrutsMessage("register.error.username.duplicate");
			throw (ae);
		}
		catch (Exception e)
		{
			logger.error("ERROR: " + e.getMessage());
		}

		// Initialise the User DTO
		UserVectorDTO userVectorDTO =
			buildUserDetailsDTO(userDetailsDTO.getUserName());

		if (userVectorDTO.getUserVector().isEmpty())
			return null;
		else
			return (UserDetailsDTO) userVectorDTO.getUserVector().elementAt(0);
	}

	/**
	 * Search for users
	 * 
	 * Parameter currently ignored
	 */
	public UserVectorDTO search(UserSearchCriteriaDTO userSearchCriteriaDTO)
	{
		logger.info("ENTRY: search");

		UserVectorDTO userVectorDTO = buildUserDetailsDTO("*");

		logger.info("EXIT:  search");
		return userVectorDTO;
	}

	/**
	 * Returns the ctx.
	 * @return DirContext
	 */
	public DirContext getCtx()
	{
		return ctx;
	}

	/**
	 * Sets the ctx.
	 * @param ctx The ctx to set
	 */
	public void setCtx(DirContext ctx)
	{
		this.ctx = ctx;
	}

	/**
	 * This function builds the User DTO that is placed
	 * in the session scope.
	 * 
	 * Also finds all users when called with "*"
	 * 
	 */
	public UserVectorDTO buildUserDetailsDTO(String userName)
	{
		logger.info("ENTRY: buildUserDetailsDTO");

		UserVectorDTO userVectorDTO = new UserVectorDTO();

		// log in as admin
		loginAdmin();

		String base = AppProperties.getInstance().getProperty("search_base");
		String filter = "(|(cn=" + userName + "))";

		// perform search for user
		SearchControls constraints = null;
		NamingEnumeration results = null;
		try
		{
			constraints = new SearchControls();
			constraints.setSearchScope(SearchControls.SUBTREE_SCOPE);

			results = getCtx().search(base, filter, constraints);
		}
		catch (Exception e)
		{
			logger.error("Search Error: " + e.getMessage());
		}

		// unpack results
		SearchResult sr = null;
		Attributes attrs = null;
		UserDetailsDTO userDetailsDTO = null;
		UserAddrDTO userAddrDTO = null;
		try
		{
			while (results.hasMore())
			{
				sr = (SearchResult) results.next();
				attrs = sr.getAttributes();

				userDetailsDTO = new UserDetailsDTO();
				userAddrDTO = new UserAddrDTO();
				userDetailsDTO.setUserAddrDTO(userAddrDTO);

				for (NamingEnumeration ae = attrs.getAll(); ae.hasMore();)
				{
					Attribute attr = (Attribute) ae.next();
					String id = attr.getID();
					String info = null;
					try
					{
						info = (String) attr.getAll().nextElement();
					}
					catch (Exception e)
					{
						info = "";
					}

					if ((id.equalsIgnoreCase("cn"))
						&& (info.equals("ou=People")))
						break;

					if (id.equalsIgnoreCase("cn"))
						userDetailsDTO.setUserName(info);

					if (id.equalsIgnoreCase("givenName"))
						userDetailsDTO.setFirstName(info);

					if (id.equalsIgnoreCase("sn"))
						userDetailsDTO.setLastName(info);

					if (id.equalsIgnoreCase("telephoneNumber"))
						userDetailsDTO.setPhoneNum(info);

					if (id.equalsIgnoreCase("mail"))
						userDetailsDTO.setEmailAddr(info);

					if (id.equalsIgnoreCase("labeledURI"))
						userDetailsDTO.setWebURL(info);

					if (id.equalsIgnoreCase("uid"))
						userDetailsDTO.setId(new Integer(info));

					if (id.equalsIgnoreCase("title"))
						userDetailsDTO.setTitle(info);

					if (id.equalsIgnoreCase("street"))
						userAddrDTO.setAddrStreetName(info);

					if (id.equalsIgnoreCase("postalCode"))
						userAddrDTO.setAddrPostCode(info);

					if (id.equalsIgnoreCase("postOfficeBox"))
						userAddrDTO.setAddrPoBox(info);

					if (id.equalsIgnoreCase("roomNumber"))
						userAddrDTO.setAddrBldNum(info);

					if (id.equalsIgnoreCase("st"))
						userAddrDTO.setAddrMuni(info);

					if (id.equalsIgnoreCase("uid"))
						userAddrDTO.setId(new Integer(info));

					logger.debug(id + " " + info);
				}

				userDetailsDTO.setActive(new Boolean(true));
				userDetailsDTO.setCreatedOn(new Date());

				// get the users role
				getUserRole(userDetailsDTO);

				// add the user
				if (userDetailsDTO.getUserName() != null)
					userVectorDTO.getUserVector().add(userDetailsDTO);
				else
					logger.debug("user name is null ");

			}
		}
		catch (NamingException e)
		{
			logger.error("NamingException: " + e.getMessage());
		}
		catch (Exception e)
		{
			logger.error("Exception: " + e.getMessage());
			e.printStackTrace(System.err);
		}
		finally
		{
			logout();
		}

		logger.info("EXIT:  buildUserDetailsDTO");
		return userVectorDTO;
	}

	/*
	 * Modify User
	 * 
	 * 
	 */
	public void modifyUserDetails(UserDetailsDTO userDetailsDTO)
		throws ApplicationException
	{
		UserAddrDTO userAddrDTO = userDetailsDTO.getUserAddrDTO();

		String uName =
			"cn="
				+ userDetailsDTO.getUserName()
				+ ","
				+ AppProperties.getInstance().getProperty("search_base");

		logger.debug("Modify User " + uName);
		logger.debug(userDetailsDTO.getFirstName());
		logger.debug(userDetailsDTO.getLastName());
		logger.debug(userDetailsDTO.getEmailAddr());
		logger.debug(userDetailsDTO.getPhoneNum());
		logger.debug(userDetailsDTO.getTitle());
		logger.debug(userDetailsDTO.getWebURL());

		logger.debug(userAddrDTO.getStreetName());
		logger.debug(userAddrDTO.getAddrPostCode());
		logger.debug(userAddrDTO.getAddrPoBox());
		logger.debug(userAddrDTO.getAddrBldNum());
		logger.debug(userAddrDTO.getAddrMuni());

		loginAdmin();

		BasicAttributes attrs = new BasicAttributes();
		attrs.put("sn", userDetailsDTO.getLastName());
		attrs.put("givenName", userDetailsDTO.getFirstName());

		// handle user password seperatley
		if ((userDetailsDTO.getPassword() != null)
			&& (!userDetailsDTO.getPassword().equalsIgnoreCase("")))
		{
			attrs.put("userPassword", userDetailsDTO.getPassword());
			logger.info("User password change " + userDetailsDTO.getPassword());
		}

		attrs.put("mail", userDetailsDTO.getEmailAddr());
		attrs.put("telephoneNumber", userDetailsDTO.getPhoneNum());
		attrs.put("title", userDetailsDTO.getTitle());
		attrs.put("labeledURI", userDetailsDTO.getWebURL());

		// address
		attrs.put("street", userAddrDTO.getStreetName());
		attrs.put("postalCode", userAddrDTO.getAddrPostCode());
		attrs.put("postOfficeBox", userAddrDTO.getAddrPoBox());
		attrs.put("roomNumber", userAddrDTO.getAddrBldNum());
		attrs.put("st", userAddrDTO.getAddrMuni());

		try
		{
			getCtx().modifyAttributes(
				uName,
				DirContext.REPLACE_ATTRIBUTE,
				attrs);
		}
		catch (Exception e)
		{
			logger.error("Modify User: " + e.getMessage());
			e.printStackTrace(System.err);

			ApplicationException ae = new ApplicationException();
			ae.setStrutsMessage("user.error.modify");
			throw ae;
		}

		logout();
	}

	/**
	 * Log in the administrator
	 * 
	 */
	private boolean loginAdmin()
	{
		// **** Log4J
		logger.info("ENTRY: loginAdmin");

		// **** if bound, unbind
		if (getCtx() != null)
		{
			try
			{
				getCtx().close();
			}
			catch (NamingException ne)
			{
				// **** shouldn't happen, intentionally ignore
				logger.error("ERROR: " + ne.getMessage());
			}
			setCtx(null);
		}

		// **** environment hashtable
		Hashtable env = new Hashtable(11);

		env.put(
			"java.naming.ldap.noBind",
			AppProperties.getInstance().getProperty("java.naming.ldap.noBind"));

		env.put(
			Context.SECURITY_AUTHENTICATION,
			AppProperties.getInstance().getProperty(
				Context.SECURITY_AUTHENTICATION));

		env.put(
			"java.naming.factory.initial",
			AppProperties.getInstance().getProperty(
				"java.naming.factory.initial"));

		env.put(
			"java.naming.factory.url.pkgs",
			AppProperties.getInstance().getProperty(
				"java.naming.factory.url.pkgs"));

		env.put(
			"java.naming.provider.url",
			AppProperties.getInstance().getProperty(
				"java.naming.provider.url"));

		// the user name and password below should be exteranlised ....
		String user = "cn=Directory Admin,dc=ibm,dc=us";
		env.put(Context.SECURITY_PRINCIPAL, user);
		env.put(Context.SECURITY_CREDENTIALS, "sal404");

		// **** Create the initial directory context.
		try
		{
			setCtx(new javax.naming.directory.InitialDirContext(env));
		}
		catch (AuthenticationException ae)
		{
			// **** invalid credentials
			logger.error("ERROR: " + ae.getMessage());
			return false;
		}
		catch (javax.naming.NamingException ne)
		{
			logger.error("ERROR: " + ne.getMessage());
			return false;
		}
		catch (NoClassDefFoundError ncdef)
		{
			logger.error("ERROR: " + ncdef.getMessage());
			return false;
		}
		finally
		{
			logger.info("EXIT:  loginAdmin");
		}

		return true;
	}

	protected UserVectorDTO getUsersInRole(String roleName)
	{
		logger.info("ENTRY: getUsersInRole");
		UserVectorDTO usersInRole = new UserVectorDTO();
		UserSearchCriteriaDTO searchDTO = new UserSearchCriteriaDTO();
		UserVectorDTO allUsers = search(searchDTO);
		Iterator iterator = allUsers.getUserVector().iterator();

		while (iterator.hasNext())
		{
			UserDetailsDTO aUser =
				(UserDetailsDTO) iterator.next();
			if (aUser.getRole().equalsIgnoreCase(roleName))
			{
				usersInRole.getUserVector().add(aUser);
			}

		}

		logger.info("EXIT: getUsersInRole");
		return usersInRole;

	}

	/**
	 * Get the role for a user
	 * 
	 */
	protected void getUserRole(UserDetailsDTO UserDetailsDTO)
	{
		logger.info("ENTRY: getUserRole");

		String base = AppProperties.getInstance().getProperty("search_base");
		String filter = "(|(cn=" + UserDetailsDTO.getUserName() + "))";

		// perform search for roles
		base = AppProperties.getInstance().getProperty("role_search_base");
		filter = "(|(cn=*))";

		SearchControls constraints = null;
		NamingEnumeration results = null;
		try
		{
			constraints = new SearchControls();
			constraints.setSearchScope(SearchControls.ONELEVEL_SCOPE);

			results = getCtx().search(base, filter, constraints);
		}
		catch (Exception e)
		{
			logger.error(e.getMessage());
		}

		// unpack results
		SearchResult sr = null;
		Attributes attrs = null;
		try
		{
			while (results.hasMore())
			{
				sr = (SearchResult) results.next();
				attrs = sr.getAttributes();

				for (NamingEnumeration ae = attrs.getAll(); ae.hasMore();)
				{
					Attribute attr = (Attribute) ae.next();
					String id = attr.getID();
					String info = (String) attr.getAll().nextElement();

					logger.debug(info);
					NamingEnumeration role = attrs.getAll();
					while (role.hasMore())
					{
						attr = (Attribute) role.next();

						NamingEnumeration person = attr.getAll();
						while (person.hasMore())
						{
							String personRole = (String) person.next();
							if (personRole
								.startsWith(
									"cn=" + UserDetailsDTO.getUserName()))
								UserDetailsDTO.setRole(info);
						}
					}
				}
			}
		}
		catch (NamingException e)
		{
			logger.error("NamingException: " + e.getMessage());
		}
		catch (Exception e)
		{
			logger.error("Exception: " + e.getMessage());
		}

		logger.info("EXIT:  getUserRole");
	}

	/**
	 * 
	 * 
	 */
	public void deleteUser(UserDetailsDTO userDetails)
	{

		logger.info("DELETE USER " + userDetails.getUserName());

		loginAdmin();

		String name = AppProperties.getInstance().getProperty("search_base");
		String user = "cn=" + userDetails.getUserName() + "," + name;

		try
		{
			int attr = DirContext.REMOVE_ATTRIBUTE;
			this.getCtx().destroySubcontext(user);
		}
		catch (Exception e)
		{
			logger.error(e.getMessage());
		}
		finally
		{
			logout();
		}
	}

	/**
	 * 
	 * 
	 * 
	 */
	private void modifyRole(String userName, String role, boolean add)
		throws ApplicationException
	{

		String name =
			"cn="
				+ userName
				+ ","
				+ AppProperties.getInstance().getProperty("search_base");

		Attribute oc = new BasicAttribute("objectclass");

		loginAdmin();
		int cmd = 0;
		if (add)
			cmd = DirContext.ADD_ATTRIBUTE;
		else
			cmd = DirContext.REMOVE_ATTRIBUTE;

		try
		{
			getCtx().modifyAttributes(
				role,
				cmd,
				new BasicAttributes("uniqueMember", name));
		}
		catch (Exception e)
		{
			logger.error("ERROR: " + e.getMessage());
		}
		finally
		{
			logout();
		}
	}
}
