/*
 * Created on Nov 4, 2004
 *
 */
package com.ibm.itso.sal404.user;

import org.apache.log4j.Logger;

import com.ibm.itso.sal404.common.exception.ApplicationException;
import com.ibm.itso.sal404.user.dto.UserDetailsDTO;
import com.ibm.itso.sal404.user.dto.UserSearchCriteriaDTO;
import com.ibm.itso.sal404.user.dto.UserVectorDTO;

/**
 * @author grove
 *  
 */
public class UserSessionData
{
    // Configure Log4J Logger
    private static Logger logger = Logger.getLogger(UserSessionData.class);

    // **** the managed list
    UserVectorDTO userList = null;

    // **** the search criteria
    UserSearchCriteriaDTO criteria = null;

    // **** currently logged in user
    UserDetailsDTO logInUser = null;

    // **** currently selected in user
    UserDetailsDTO user = null;

    // **** my manager
    UserManager manager = new UserManager();

    /**
     * @param user
     *            The user to set.
     */
    public void setUser(UserDetailsDTO user)
    {
        this.user = user;
    }

    /**
     * @param user
     *            The user to set.
     */
    public void setUser(int user)
    {
        logger.debug("set user " + user);
    }

    /**
     * @param user
     *            The user to set.
     * @throws ApplicationException
     */
    public void setUser(String user) throws ApplicationException
    {
        logger.debug("set user " + user);

        UserDetailsDTO userDTO = null;
        for (int i = 0; i < getUserList().getUserVector().size(); i++)
        {
            userDTO = (UserDetailsDTO) getUserList().getUserVector().elementAt(
                    i);
            if (user.equals(userDTO.getUserName()))
            {
                setUser(userDTO);
                return;
            }
        }
    }

    /**
     * @param userList
     *            The userList to set.
     */
    private void setUserList(UserVectorDTO userList)
    {
        this.userList = userList;
    }

    public void reset()
    {
        userList = null;
        UserSearchCriteriaDTO criteria = null;
        UserDetailsDTO logInUser = null;
        UserDetailsDTO user = null;
    }

    /**
     * @return Returns the user.
     */
    public UserDetailsDTO getUser()
    {
        return user;
    }

    /**
     * @return Returns the userList.
     * @throws ApplicationException
     */
    public UserVectorDTO getUserList() throws ApplicationException
    {
        // **** if the list is null, re-search
        // **** this method should always return at least
        // **** an empty vector
        logger.info("Entered Search");
        logger.info("UserList is " + userList);

        if (userList == null)
            setUserList(search());

        return userList;
    }

    /**
     * @return Returns the manager.
     */
    private UserManager getManager()
    {
        return manager;
    }

    // **** No setter for the manager

    /**
     * @return Returns the logInUser.
     */
    public UserDetailsDTO getLogInUser()
    {
        return logInUser;
    }

    /**
     * @param logInUser
     *            The logInUser to set.
     */
    private void setLogInUser(UserDetailsDTO logInUser)
    {
        this.logInUser = logInUser;
    }

    /**
     * @return Returns the criteria.
     */
    public UserSearchCriteriaDTO getCriteria()
    {
        return criteria;
    }

    /**
     * @param criteria
     *            The criteria to set.
     */
    private void setCriteria(UserSearchCriteriaDTO criteria)
    {
        this.criteria = criteria;
    }

    /**
     * Login
     *  
     */
    public UserDetailsDTO login(UserDetailsDTO loginDTO)
            throws ApplicationException
    {

        logger.info("ENTRY: login");

        reset();
        setLogInUser(getManager().login(loginDTO));

        logger.info("EXIT:  login");

        return getLogInUser();
    }

    /**
     * 
     * 
     *  
     */
    public UserVectorDTO search(UserSearchCriteriaDTO userSearchCriteriaDTO)
            throws ApplicationException
    {
        logger.info("ENTRY: search");

        // **** save the search criteria
        setCriteria(userSearchCriteriaDTO);

        setUserList(null);
        setUserList(getManager().search(getCriteria()));

        logger.info("EXIT:  search");
        return getUserList();
    }

    /**
     * 
     * 
     *  
     */
    public UserVectorDTO search() throws ApplicationException
    {
        logger.info("ENTRY: search");

        setUserList(null);
        setUserList(getManager().search(getCriteria()));

        logger.info("EXIT:  search");
        return getUserList();
    }

    /**
     *  
     */
    public UserDetailsDTO create(UserDetailsDTO userDetails)
            throws ApplicationException
    {
        logger.info("ENTRY: create");

        setUser((UserDetailsDTO) null);
        setUser(getManager().registerUser(userDetails));
        setLogInUser(getUser());

        // *** may modify the list ....
        setUserList(null);

        logger.info("EXIT:  create");
        return getUser();
    }

    /**
     * 
     *  
     */
    public void deleteUser(UserDetailsDTO userDetails)
    {
        logger.info("ENTRY: deleteUser");

        getManager().deleteUser(userDetails);

        // *** may modify the list ....
        setUserList(null);

        logger.info("EXIT:  deleteUser");
    }

    /**
     *  
     */
    public void modifyUserDetails(UserDetailsDTO userDetailsDTO)
            throws ApplicationException
    {
        logger.info("ENTRY: modifyUserDetails");

        getManager().modifyUserDetails(userDetailsDTO);
        setUser(userDetailsDTO);
        setUserList(null);

        if (getLogInUser().getId().equals(getUser().getId()))
            setLogInUser(getUser());

        logger.info("EXIT:  modifyUserDetails");
    }

    public void resetUserList()
    {
        userList = null;
    }
}