/* $Id: UserMessageListenerBean.java,v 1.4 2004/12/14 15:30:03 grove Exp $
 * 
 * This code is part of the sample application that has been created
 * for the redbook WebSphere Application Server - Express V6
 * Developers Guide and A Development Example (SG24-6500).
 *
 * Revision History:
 *
 *   $Log: UserMessageListenerBean.java,v $
 *   Revision 1.4  2004/12/14 15:30:03  grove
 *   refactoring
 *
 *   Revision 1.1  2004/11/25 14:47:55  grovedc
 *   week 4
 *
 *   Revision 1.3  2004/11/23 18:12:31  ansgar
 *   minor changes
 *
 *   Revision 1.2  2004/11/22 17:38:09  grove
 *   yet more refactoring
 *
 *   Revision 1.1  2004/11/22 15:14:33  ansgar
 *   reorganized the project structure
 *
 */
package com.ibm.itso.sal404.jms;

import java.util.Enumeration;

import javax.jms.JMSException;
import javax.jms.ObjectMessage;

import org.apache.log4j.Logger;

import com.ibm.itso.sal404.user.UserBusinessDelegate;
import com.ibm.itso.sal404.user.dto.UserDetailsDTO;

/**
 * Bean implementation class for message driven bean UserMessageListener.
 * 
 * More detailed, arbitrarily elaborate description and information. <BR>
 * <BR>
 * Project : SAL404RealtyControlEJB <BR>
 * <BR>
 * Creation date: Nov 18, 2004
 * 
 * @author ansgar
 */
public class UserMessageListenerBean implements javax.ejb.MessageDrivenBean,
		javax.jms.MessageListener {

	private static Logger logger = Logger
			.getLogger(UserMessageListenerBean.class);

	private javax.ejb.MessageDrivenContext fMessageDrivenCtx;
	
	private UserBusinessDelegate userBusinessDelegate;

	/**
	 * getMessageDrivenContext
	 */
	public javax.ejb.MessageDrivenContext getMessageDrivenContext() {
		return fMessageDrivenCtx;
	}

	/**
	 * setMessageDrivenContext
	 */
	public void setMessageDrivenContext(javax.ejb.MessageDrivenContext ctx) {
		fMessageDrivenCtx = ctx;
	}

	/**
	 * ejbCreate
	 */
	public void ejbCreate() {
		logger.debug("ENTER: ejbCreate()");
		// just create a reference to the delegate
		userBusinessDelegate = new UserBusinessDelegate();
		logger.debug("EXIT : ejbCreate()");
	}

	/**
	 * Recieves a message on the queue where the bean is registered and
	 * delegates the processing of the business logic.
	 * 
	 * @see javax.jms.MessageListener#onMessage(javax.jms.Message)
	 */
	public void onMessage(javax.jms.Message msg) {
		logger.debug("ENTER: onMessage()");

		UserDetailsDTO userDetailsDTO = filterforUserDetailsDTO(msg);
		if (userDetailsDTO != null) {
			logger.info("filterMessage() start processing the message");
			userBusinessDelegate.createUser(userDetailsDTO);
		}

		logger.debug("EXIT : onMessage()");
	}

	/**
	 * Parse message for objectMessage that has the object of type
	 * <code>UserDetailsDTO</code> in the body of the message.
	 * 
	 * @param message
	 *            the <code>javax.jms.Message</code> to parse
	 * @return - the <code>UserDetailsDTO</code> contained in the message,
	 *         <code>null</code> if the object is not of type
	 *         <code>UserDetailsDTO</code>
	 */
	private UserDetailsDTO filterforUserDetailsDTO(javax.jms.Message message) {
		if (message instanceof ObjectMessage) {
			logger.debug("filterMessage() recieved ObjectMessage");
			ObjectMessage objectMessage = (ObjectMessage) message;
			try {
				logMessageDetails(objectMessage);

				Object jmsObject = objectMessage.getObject();
				if (!(jmsObject instanceof UserDetailsDTO)) {
					return null;
				} else {
					logger
							.info("filterMessage() objectMessage is of type UserDetailsDTO");
					UserDetailsDTO userDetailsDTO = (UserDetailsDTO) jmsObject;
					return userDetailsDTO;
				}

			} catch (JMSException e) {
				logger.error("filterMessage() error, ignoring message", e);
				logger.error("filterMessage() error code=" + e.getErrorCode());
				Exception linkedException = e.getLinkedException();
				if (linkedException != null) {
					logger.error("filterMessage() linked exception=",
							linkedException);
				}
			}
		}
		return null;
	}

	/**
	 * Logs the property names of the message on debug level.
	 * 
	 * @param objectMessage
	 * @throws JMSException
	 */
	private void logMessageDetails(ObjectMessage objectMessage)
			throws JMSException {
		if (logger.isDebugEnabled()) {
			Enumeration enum = objectMessage.getPropertyNames();
			while (enum.hasMoreElements()) {
				String propertyName = (String) enum.nextElement();
				logger.debug("onMessage() propertyName=" + propertyName);
			}
		}
	}

	/**
	 * ejbRemove
	 */
	public void ejbRemove() {
		logger.debug("ENTER: ejbRemove()");
		logger.debug("EXIT : ejbRemove()");
	}
}