package com.ibm.itso.sal404.common.util;

import java.util.*;
import java.io.*;

import org.apache.log4j.Logger;

/**
 */
public class AppProperties
{
 	private static Logger logger = Logger.getLogger(AppProperties.class);
	
	/**
	 * Singleton instance of the AppProperties class
	 */
	private static AppProperties instance = null;

	/**
	 * The name of the system property which defines the
	 * location of the properties file
	 */
	private static final String FILE_NAME = "app.properties";

	//**********************//
	// Property keys			
	//**********************//

	// **** LDAP Properties
	public static final String LDAP_NAMING_FACTORY_INITIAL = "java.naming.factory.initial";
	public static final String LDAP_NAMING_FACTORY_PKGS = "java.naming.factory.url.pkgs";
	public static final String LDAP_NOBIND           = "java.naming.ldap.noBind";
	public static final String LDAP_PROVIDER_URL     = "java.naming.provider.url";
	public static final String LDAP_SEARCH_BASE      = "search_base";
	public static final String LDAP_ROLE_SEARCH_BASE = "role_search_base";
	
	public static final String JMS_JNDI_CONNECTION_FACTORY = "jms.jndi.connectionfactory";
	public static final String JMS_JNDI_OUT_QUEUE = "jms.jndi.outqueue";
	public static final String JMS_JNDI_GLOBAL = "jms.jndi.global";

	/**
	* Contains all the properties specified in the file
	 */
	private Properties props;

	/**
	 * Insert the method's description here.
	 * Creation date: (9/22/2002 3:16:48 AM)
	 */
	private AppProperties()
	{
		super();
	}
	
	/**
	 *  @return The singleton instance of the AppProperties
	 *
	 * DCG 22/9/02
	 *
	 * This method always returns an instance even though the properties
	 * file may not have been found.  This is the desired behavior.
	 *
	 */
	public static synchronized AppProperties getInstance()
	{
		if (instance == null)
		{
			instance = new AppProperties();

			try
			{
				instance.init();
			} 
			catch (Exception ex)
			{
				logger.error("can't load properties: " + ex);
			}
		}

		return instance;
	}
	
	/**
	 * 
	 * @return The property specified by the key argument
	 * @param key The property key to look up
	 */
	public String getProperty(String key)
	{
		return props.getProperty(key);
	}
	
	/**
	 * Initialises the properties object based on a file
	 * specified as a system parameter
	 */
	private void init() throws FileNotFoundException, IOException
	{
		// **** create default properties
		initDefaults();

		InputStream is = null;

		is = AppProperties.class.getClassLoader().getResourceAsStream(FILE_NAME);

		this.props.load(is);
	}
	
	/**
	 * This method populates default values for properties.
	 * Creation date: (9/22/2002 3:08:05 AM)
	 */
	private void initDefaults()
	{
		this.props = new Properties();

		// ****
		// **** LDAP Defaults
		// ****

		// **** Sun SDK 1.2.2 or greater
		this.props.setProperty(LDAP_NAMING_FACTORY_INITIAL, "com.sun.jndi.ldap.LdapCtxFactory");

		// ****	
		this.props.setProperty(LDAP_NAMING_FACTORY_PKGS, "com.ibm.jndi");

		// **** testing purposes
//		this.props.setProperty(LDAP_PROVIDER_URL, "ldap://m10df5df.itso.ral.ibm.com:389");
		this.props.setProperty(LDAP_PROVIDER_URL, "ldap://9.24.104.133:389");
//		this.props.setProperty(LDAP_PROVIDER_URL, "ldap://localhost:389");

		// **** setting nobind to false forces a bind
		this.props.setProperty(LDAP_NOBIND, "false");

		// **** changing this propery is not currently supported
		this.props.setProperty(javax.naming.Context.SECURITY_AUTHENTICATION, "simple");

		// **** used to search for people
		this.props.setProperty(LDAP_SEARCH_BASE, "ou=People,o=ITSO Raleigh,dc=ibm,dc=us");

		// **** used to search for groups
		this.props.setProperty(LDAP_ROLE_SEARCH_BASE, "ou=Groups,o=ITSO Raleigh,dc=ibm,dc=us");
	}

	/**
	 * Insert the method's description here.
	 * Creation date: (9/22/2002 3:31:14 AM)
	 * @param name java.lang.String
	 * @param val java.lang.String
	 */
	public void setProperty(String name, String val)
	{
		this.props.setProperty(name, val);
	}
}
