package com.ibm.itso.sal404.email.dto;

import javax.activation.*;
import javax.mail.internet.*;
import javax.mail.*;
import java.util.*;
import java.io.*;

// Import Log4J Logger
import org.apache.log4j.Logger;


/**
 * 
 * sal404 Realty sample application
 * 
 * @component	Email Component
 * @layer		Data Transfer Object
 * 
 * Description of the class here
 * 
 * @author 		Bo Gong
 * @created		May 13, 2003		
 * @version		1.0.0 / @May 13, 2003	
 *
 * @see		 	EmailManager
 * 
 */
public class EmailMessage implements Serializable
{

	private String _messageHost = null;
	private InternetAddress _messageFrom = null;
	private InternetAddress[] _messageTo = null;
	private InternetAddress[] _messageCc = null;
	private String _messageSubject = null;
	private String _messageContentType = null;
	private String _messageContent = null;
	private String _messageAttachment = null;

	// Configure Log4J Logger
	private static Logger logger = Logger.getLogger(EmailMessage.class);

	
	/**
	 * Constructor for EmailMessage.
	 */
	public EmailMessage()
	{
		super();
	}
	
	/**
	 * send out message.
	 */
	
	public boolean sendMessage() throws Exception 
	{
		try
		{
			//Create a session
			Properties props = new Properties();
			props.put("mail.smtp.host", _messageHost);
			Session session = Session.getDefaultInstance(props, null);
		
			//Create a message, set header fields
			MimeMessage mimeMessage = new MimeMessage(session);
			mimeMessage.setFrom(_messageFrom);
			mimeMessage.setRecipients(Message.RecipientType.TO, _messageTo);
			if (_messageCc != null)
			{
				mimeMessage.setRecipients(Message.RecipientType.CC, _messageCc);
			}
			mimeMessage.setSubject(_messageSubject);
			mimeMessage.setSentDate(new Date());
		
			//Create message content
			 Multipart multiPart = new MimeMultipart();

			//Create and fill the message text
		 	MimeBodyPart mimeBodyPart = new MimeBodyPart();
			mimeBodyPart.setContent(_messageContent, _messageContentType);
			multiPart.addBodyPart(mimeBodyPart);

			//Create and attach the attachment file
			if ((_messageAttachment != null) && (_messageAttachment.length() > 0))
			{
				mimeBodyPart = new MimeBodyPart();
				DataSource dataSource = new FileDataSource(_messageAttachment);
				mimeBodyPart.setDataHandler(new DataHandler(dataSource));
				mimeBodyPart.setFileName(_messageAttachment);
				multiPart.addBodyPart(mimeBodyPart);
			}
		
			//send the message
			mimeMessage.setContent(multiPart);
	 		Transport.send(mimeMessage);
	 	} 
		catch (SendFailedException sfex) 
		{
			logger.error(sfex.getMessage());
			return false;
		}	
		
		return true;
	}
	

	/**
	 * @return
	 */
	public InternetAddress getMessageFrom() {
		return _messageFrom;
	}

	/**
	 * @return
	 */
	public String getMessageSubject() {
		return _messageSubject;
	}

	/**
	 * @return
	 */
	public InternetAddress[] getMessageTo() {
		return _messageTo;
	}


	/**
	 * @param string
	 */
	public void setMessageSubject(String string) {
		_messageSubject = string;
	}


	/**
	 * @return
	 */
	public String getMessageAttachment() {
		return _messageAttachment;
	}

	/**
	 * @return
	 */
	public String getMessageContent() {
		return _messageContent;
	}

	/**
	 * @return
	 */
	public String geMmessageContentType() {
		return _messageContentType;
	}

	/**
	 * @param string
	 */
	public void setMessageAttachment(String string) {
		_messageAttachment = string;
	}

	/**
	 * @param string
	 */
	public void setMessageContent(String string) {
		_messageContent = string;
	}

	/**
	 * @param string
	 */
	public void setMessageContentType(String string) {
		_messageContentType = string;
	}

	/**
	 * @return
	 */
	public InternetAddress[] getMessageCc() {
		return _messageCc;
	}

	/**
	 * Returns the _messageHost.
	 * @return String
	 */
	public String getMessageHost()
	{
		return _messageHost;
	}

	/**
	 * Sets the _messageHost.
	 * @param _messageHost The _messageHost to set
	 */
	public void setMessageHost(String _messageHost)
	{
		this._messageHost = _messageHost;
	}

	/**
	 * Returns the messageContentType.
	 * @return String
	 */
	public String getMessageContentType()
	{
		return _messageContentType;
	}

	/**
	 * Sets the messageCc.
	 * @param messageCc The messageCc to set
	 */
	public void setMessageCc(InternetAddress[] messageCc)
	{
		_messageCc = messageCc;
	}

	/**
	 * Sets the messageFrom.
	 * @param messageFrom The messageFrom to set
	 */
	public void setMessageFrom(InternetAddress messageFrom)
	{
		_messageFrom = messageFrom;
	}

	/**
	 * Sets the messageTo.
	 * @param messageTo The messageTo to set
	 */
	public void setMessageTo(InternetAddress[] messageTo)
	{
		_messageTo = messageTo;
	}

    private static final long serialVersionUID = 7496848337497219874L;

}

