package com.ibm.itso.sal404.interestlist.dao;
import java.sql.*;
import com.ibm.db.beans.*;

// Import Log4J Logger
import org.apache.log4j.Logger;

/**
 * 
 * sal404 Realty sample application
 * 
 * @component	Interest list
 * @layer		Model
 * 
 * CheckoutInterestListDAO<br>
 * This DAO writes a new interest list to the database.<br>
 * 
 * 
 * @author 		Mark Buensalido
 * @version		1.0.0
 *
 * 
 */
public class CheckoutInterestListDAO
{


	/**
	 * Configures the log4j Logger.
	 * @since 1.0.0
	 */
	private static Logger logger =
		Logger.getLogger(CheckoutInterestListDAO.class);


	/**
	 * Field for modify statement.
	 */
	private DBModify modify;
	/**
	 * Field for selecting the new value of the update
	 */
	private DBSelect select;

	/**
	 * Constructor for a DBModify class.
	 */
	public CheckoutInterestListDAO()
	{
		super();
		initializer();
	}

	/**
	 * Creates a DBModify instance and initializes its properties.
	 */
	protected void initializer()
	{

		/* 
		 * these statements create the new INT_LIST in the database
		 * and return the identity that was generated by the database
		 * 
		 */
		modify = new DBModify();
		select = new DBSelect();

		try
		{

			modify.setDataSourceName("jdbc/sal404");
			logger.debug("DataSourceName:jdbc/sal404:INCODE");


			// here is the first statement that will insert the interest list
			modify.setCommand(
				"INSERT INTO DB2ADMIN.INT_LIST ( INT_LIST_ID, USR_ID, INT_LIST_CRD_ON ) VALUES ( DEFAULT, :USR_ID, DEFAULT )");
			DBParameterMetaData parmMetaData = modify.getParameterMetaData();
			parmMetaData.setParameter(
				1,
				"USR_ID",
				java.sql.DatabaseMetaData.procedureColumnIn,
				java.sql.Types.INTEGER,
				Integer.class);
			logger.debug("modify statement constructed");


			/*
			 * Notice that the connection from the modify statement is shared with
			 * the select statement.
			 * This is good for a the following reasons:
			 * 
			 * 1. Shares the connection resource.
			 * 2. IDENTITY_VAL_LOCAL returns the correct ID based on connection
			 */
			select.shareConnectionWith(modify);
			select.setCommand(
				"VALUES IDENTITY_VAL_LOCAL()");

			logger.debug("select statement constructed with shared connection");

		}
		catch (SQLException ex)
		{
			logger.error("SQLException:SQLSTATE:" + ex.getSQLState());
			ex.printStackTrace();
		}
	}

	/**
	 * Executes the SQL statement.
	 * @exception SQLException
	 */
	public void execute(Integer USR_ID) throws SQLException
	{
		try
		{
			// first the insert is called
			modify.setParameter("USR_ID", USR_ID);
			modify.execute();
			
			// then the identity val function is called
			select.execute();
		}

		// Free resources of modify object. 
		// Free resources of select object.
		finally
		{
			modify.close();
			select.close();
		}
	}

	/**
	 * Returns a DBModify reference.
	 */
	public DBModify getDBModify()
	{
		return modify;
	}
	/**
	 * Returns a DBSelect reference.
	 */
	public DBSelect getDBSelect()
	{
		return select;
	}

	/**
	 * Returns an array of objects representing the rows in the result set.
	 * This method is an important part of this multi-statement framework
	 * because it will return the row that holds the new database ID for the
	 * inserted record.
	 * @returns NewInterestListDAORow[]
	 */
	public NewInterestListIDDAORow[] getRows()
	{
		NewInterestListIDDAORow[] rows =
			new NewInterestListIDDAORow[select.getRowCount()];
		for (int i = 0; i <= select.getRowCount() - 1; i++)
		{
			rows[i] = new NewInterestListIDDAORow(select, i + 1);
		}
		return rows;
	}
	
	/**
	 * Convenience method that will return the new INT_LST_ID value.
	 * @return int
	 */
	public int getNewIntListId()
	{		
		int newIntListId = 0;
	
		try
		{
			newIntListId = Integer.parseInt(getRows()[0].getColExp1().toString());
		}
		catch (Exception e)
		{
		}
		
		return newIntListId;
	}
}