package com.ibm.itso.sal404.interestlist.dao;
import java.sql.*;
import com.ibm.db.beans.*;

/**
 * This class sets the DBSelect property values. It also provides 
 * methods that execute your SQL statement, return 
 * a DBSelect reference, and return an array of objects  
 * representing the rows in the result set.
 * Generated:  May 10, 2003 8:49:41 AM
 */

public class InterestListPropertyDetailDAO
{
	private DBSelect select;

	/**
	 * This field is used to track the number of parameters that will be sent 
	 * during the query. It helps the class modify the prepared SQL
	 * statement with the appropriate number of parameters.
	 */
	private int numberOfParameters;

	/**
	 * Constructor for a DBSelect class. This class must be constructed with
	 * the number of parameters that will be used in the prepared SQL
	 * statement.
	 * @param int numberOfParameters
	 */
	public InterestListPropertyDetailDAO(int numberOfParameters)
	{
		super();
		setNumberOfParameters(numberOfParameters);
		initializer();
	}

	/**
	 * Creates a DBSelect instance and initializes its properties.
	 */
	protected void initializer()
	{

		int numParams = getNumberOfParameters();
		select = new DBSelect();

		try
		{
			select.setDataSourceName("jdbc/sal404");

			// the SQL statement has been modified here to accept 
			// multiple parameters
			// the private method getQueryParameterString appends the appropriate
			// number of parameters to the prepared SQL statement
			select.setCommand(
				"SELECT "
					+ "DB2ADMIN.PROP.PROP_ID, "
					+ "DB2ADMIN.PROP.PROP_ADDR_BLDG_NUM, "
					+ "DB2ADMIN.PROP.PROP_ADDR_STRT_NAM, "
					+ "DB2ADMIN.PROP_TYPE.PROP_TYPE_DESC, "
					+ "DB2ADMIN.PROP_STS.PROP_STS_DESC, "
					+ "DB2ADMIN.PROP.PROP_PRICE, "
					+ "DB2ADMIN.USR.USR_FIRST_NAME, "
					+ "DB2ADMIN.USR.USR_LAST_NAME "
					+ "FROM "
					+ "DB2ADMIN.PROP "
					+ "LEFT OUTER JOIN DB2ADMIN.USR ON "
					+ "DB2ADMIN.PROP.USR_ID = DB2ADMIN.USR.USR_ID "
					+ "LEFT OUTER JOIN DB2ADMIN.PROP_TYPE ON "
					+ "DB2ADMIN.PROP.PROP_TYPE_ID = "
					+ "DB2ADMIN.PROP_TYPE.PROP_TYPE_ID "
					+ "LEFT OUTER JOIN DB2ADMIN.PROP_STS ON "
					+ "DB2ADMIN.PROP.PROP_STATUS_ID = "
					+ "DB2ADMIN.PROP_STS.PROP_STS_ID "
					+ "WHERE "
					+ "DB2ADMIN.PROP.PROP_ID IN ("
					+ getQueryParameterString()
					+ ")");

			DBParameterMetaData parmMetaData = select.getParameterMetaData();

			// notice that the setParameter method is now iterated 
			// to accept multiple parameters
			for (int lcv = 1; lcv <= numParams; lcv++)
			{
				parmMetaData.setParameter(
					lcv,
					"PROP_ID_LIST" + lcv,
					java.sql.DatabaseMetaData.procedureColumnIn,
					java.sql.Types.INTEGER,
					Integer.class);
			}
		}
		catch (SQLException ex)
		{
			ex.printStackTrace();
		}
	}

	/**
	 * Executes the SQL statement.
	 * @exception java.sql.SQLException
	 */
	public void execute(Integer[] PROP_ID_LIST) throws SQLException
	{

		int numParams;

		numParams = getNumberOfParameters();

		try
		{

			// if the number os parameters that the class was instantiated with
			// does not match the number of parameters passed in this method
			// it will most certainly throw an SQLException
			if (numParams != PROP_ID_LIST.length)
			{
				throw new SQLException(
					"Number of parameters in constructor "
						+ "does not match the number being passed.");
			}

			// notice that the setParameter is iterated
			for (int lcv = 0; lcv < numParams; lcv++)
			{
				select.setParameter(
					"PROP_ID_LIST" + Integer.toString(lcv + 1),
					PROP_ID_LIST[lcv]);
			}

			select.execute();
		}

		// Free resources of select object. 
		finally
		{
			select.close();
		}
	}

	/**
	 * Returns a DBSelect reference.
	 */
	public DBSelect getDBSelect()
	{
		return select;
	}

	/**
	 * Returns an array of objects representing the rows in the result set.
	 */
	public InterestListPropertyDetailDAORow[] getRows()
	{
		InterestListPropertyDetailDAORow[] rows =
			new InterestListPropertyDetailDAORow[select.getRowCount()];
		for (int i = 0; i <= select.getRowCount() - 1; i++)
		{
			rows[i] = new InterestListPropertyDetailDAORow(select, i + 1);
		}
		return rows;
	}
	/**
	 * Returns the numberOfParameters.
	 * @return int
	 */
	public int getNumberOfParameters()
	{
		return numberOfParameters;
	}

	/**
	 * Sets the numberOfParameters.
	 * @param numberOfParameters The numberOfParameters to set
	 */
	private void setNumberOfParameters(int numberOfParameters)
	{
		this.numberOfParameters = numberOfParameters;
	}

	/**
	 * Based on the number of parameters this class was instantiated with,
	 * this method will return the appropriate number of query parameters.
	 * @return String The query parameter string.
	 */
	private String getQueryParameterString()
	{
		StringBuffer parameterString;
		int numParms;

		numParms = getNumberOfParameters();
		parameterString = new StringBuffer();

		// create the :PROP_ID_LIST parameter string
		for (int lcv = 1; lcv <= numParms; lcv++)
		{
			parameterString.append(":PROP_ID_LIST");
			parameterString.append(lcv);
			if (lcv < numParms)
			{
				parameterString.append(", ");
			}
		}

		return parameterString.toString();
	}

}