package com.ibm.itso.sal404.interestlist.dto;

import java.util.List;
import java.util.Vector;

import com.ibm.itso.sal404.common.base.DataTransferObjectIf;
import com.ibm.itso.sal404.interestlist.itemadapter.InterestListLineItem;

/**
 * 
 * sal404 Realty sample application
 * 
 * @component	Interest list
 * @layer		Domain Layer
 * 
 * This class is a DataTransferObject that includes information
 * about the interest list
 * 
 * @author 		Mark Buensalido
 * @created		14 May 2003		
 * @version		1.0.0 / @May 14, 2003	
 *
 */
public final class InterestListDTO implements DataTransferObjectIf
{

	private boolean _newList;
	private int _id;
	private List _interestListLineItems = new Vector();

	/**
	 * Constructs an InterestListDTO.
	 * @since 1.0.0
	 */
	public InterestListDTO()
	{
		super();
	}

	/**
	 * Returns the id.
	 * @return int
	 * @since 1.0.0
	 */
	public int getId()
	{
		return _id;
	}

	/**
	 * Returns the newList.
	 * @return boolean
	 * @since 1.0.0
	 */
	public boolean isNewList()
	{
		return _newList;
	}

	/**
	 * Sets the id.
	 * @param id The id to set
	 * @since 1.0.0
	 */
	void setId(int id)
	{
		_id = id;
	}

	/**
	 * Sets the newList.
	 * @param newList The newList to set
	 * @since 1.0.0
	 */
	void setNewList(boolean newList)
	{
		_newList = newList;
	}

	/**
	 * Returns the interestListLineItems.
	 * @return List
	 * @since 1.0.0
	 */
	public List getInterestListLineItems()
	{
		return _interestListLineItems;
	}

	/**
	 * Sets the interestListLineItems.
	 * @param interestListLineItems The interestListLineItems to set
	 * @since 1.0.0
	 */
	public void setInterestListLineItems(List interestListLineItems)
	{
		_interestListLineItems = interestListLineItems;
	}

	/**
	 * Returns the InterestListLineItem called for by index.
	 * @param int index
	 * @return InterestListLineItem
	 * @since 1.0.0
	 */
	public InterestListLineItem getInterestListLineItem(int index)
	{

		List interestListLineItems = null;
		InterestListLineItem interestListLineItem = null;

		interestListLineItems = getInterestListLineItems();
		interestListLineItem =
			(InterestListLineItem) interestListLineItems.get(index);

		return interestListLineItem;

	}

	/**
	 * Returns the size of the interest list items.
	 * @return int size
	 * @since 1.0.0
	 */
	public int getItemsSize()
	{
		return this.getInterestListLineItems().size();
	}

    private static final long serialVersionUID = 3732489912033399941L;

}
