package com.ibm.itso.sal404.news.dao;

import java.sql.SQLException;
import java.util.Date;

import org.apache.log4j.Logger;

import com.ibm.db.beans.DBModify;
import com.ibm.db.beans.DBParameterMetaData;
import com.ibm.itso.sal404.common.util.AppProperties;
import com.ibm.itso.sal404.common.util.KeyGenerator;

/**
 * 
 * sal404 Realty sample application
 * 
 * @component newscomponent
 * @layer business facade
 * 
 * This class sets the DBModify property values. It also provides methods that
 * execute your SQL statement and return a DBModify reference.
 * 
 * Generated: May 21, 2003 2:32:41 PM
 * @author Ilaria Gorla
 * @version 1.0.0
 *  
 */
public class AddNewsItemDAO
{
    // Configure Log4J Logger
    private static Logger logger = Logger.getLogger(AddNewsItemDAO.class);

    private DBModify modify;

    /**
     * Constructor for a DBModify class.
     */
    public AddNewsItemDAO()
    {
        super();
        initializer();
    }

    /**
     * Creates a DBModify instance and initializes its properties.
     */
    protected void initializer()
    {
        modify = new DBModify();

        try
        {
            modify.setDataSourceName(AppProperties.getInstance().getProperty(
                    "dataSourceJNDIName"));
            modify
                    .setCommand("INSERT INTO DB2ADMIN.NEWS_ITM ( NEWS_ITM_ID, NEWS_ITM_TITLE, NEWS_ITM_DATE, NEWS_ITM_AUTHOR, NEWS_ITM_BODY ) VALUES ( :id, :title, :date, :author, :body )");
            DBParameterMetaData parmMetaData = modify.getParameterMetaData();
            parmMetaData.setParameter(1, "id",
                    java.sql.DatabaseMetaData.procedureColumnIn,
                    //				java.sql.Types.INTEGER,
                    java.sql.Types.CHAR,
                    //				Integer.class);
                    String.class);
            parmMetaData.setParameter(2, "title",
                    java.sql.DatabaseMetaData.procedureColumnIn,
                    java.sql.Types.VARCHAR, String.class);
            parmMetaData.setParameter(3, "date",
                    java.sql.DatabaseMetaData.procedureColumnIn,
                    java.sql.Types.DATE, java.sql.Date.class);
            parmMetaData.setParameter(4, "author",
                    java.sql.DatabaseMetaData.procedureColumnIn,
                    java.sql.Types.VARCHAR, String.class);
            parmMetaData.setParameter(5, "body",
                    java.sql.DatabaseMetaData.procedureColumnIn,
                    java.sql.Types.LONGVARCHAR, String.class);
        }
        catch (SQLException ex)
        {
            ex.printStackTrace();
            logger.error(ex.getMessage());
        }
    }

    /**
     * Executes the SQL statement.
     */
    public void execute(
    //String userid,
            //String password,
            Integer id, String title, Date date, String author, String body)
            throws SQLException
    {
        try
        {
            java.sql.Date _date = new java.sql.Date(date.getTime());

            KeyGenerator keyGenerator = new KeyGenerator();

            //			modify.setParameter("id", new Integer(_date.hashCode())); // ****
            // hack
            modify.setParameter("id", keyGenerator.getKeyString());
            modify.setParameter("title", title);
            modify.setParameter("date", _date);
            modify.setParameter("author", author);
            modify.setParameter("body", body);
            modify.execute();
        }
        // Free resources of modify object.
        finally
        {
            modify.close();
        }
    }

    /**
     * Returns a DBModify reference.
     */
    public DBModify getDBModify()
    {
        return modify;
    }
}