package com.ibm.itso.sal404.news.dao;
import java.sql.*;
import com.ibm.db.beans.*;
import com.ibm.itso.sal404.common.util.AppProperties;
/**
 * sal404 Realty sample application
 * 
 * @component	newscomponent
 * @layer		business facade
 * 
 * This class sets the DBSelect property values. It also provides 
 * methods that execute your SQL statement, return 
 * a DBSelect reference, and return an array of objects  
 * representing the rows in the result set.
 * 
 * Generated:  May 20, 2003 2:31:05 PM
 * @author 		Ilaria Gorla
 * @version		1.0.0	
 */
public class GetNewsItemDetailsDAO
{
	private DBSelect select;
	/**
	 * Constructor for a DBSelect class.
	 */
	public GetNewsItemDetailsDAO()
	{
		super();
		initializer();
	}
	/**
	 * Creates a DBSelect instance and initializes its properties.
	 */
	protected void initializer()
	{
		select = new DBSelect();
		try
		{
			select.setDataSourceName(AppProperties.getInstance().getProperty("dataSourceJNDIName"));
			select.setCommand(
				"SELECT DB2ADMIN.NEWS_ITM.NEWS_ITM_ID, DB2ADMIN.NEWS_ITM.NEWS_ITM_TITLE, DB2ADMIN.NEWS_ITM.NEWS_ITM_DATE, DB2ADMIN.NEWS_ITM.NEWS_ITM_AUTHOR, DB2ADMIN.NEWS_ITM.NEWS_ITM_BODY FROM DB2ADMIN.NEWS_ITM WHERE DB2ADMIN.NEWS_ITM.NEWS_ITM_ID = :id");
			DBParameterMetaData parmMetaData = select.getParameterMetaData();
			parmMetaData.setParameter(
				1,
				"newsId",
				java.sql.DatabaseMetaData.procedureColumnIn,
				java.sql.Types.CHAR,
				String.class);
		}
		catch (SQLException ex)
		{
			ex.printStackTrace();
		}
	}
	/**
	 * Executes the SQL statement.
	 */
	public void execute(String id) throws SQLException
	{
		try
		{
			select.setParameter("newsId", id);
			select.execute();
		}
		// Free resources of select object. 
		finally
		{
			select.close();
		}
	}
	
	/**
	 * Returns a DBSelect reference.
	 */
	public DBSelect getDBSelect()
	{
		return select;
	}

	/**
	 * Returns an array of objects representing the rows in the result set.
	 */
	public GetNewsItemDetailsDAORow[] getRows()
	{
		GetNewsItemDetailsDAORow[] rows =
			new GetNewsItemDetailsDAORow[select.getRowCount()];

		for (int i = 0; i <= select.getRowCount() - 1; i++)
		{
			rows[i] = new GetNewsItemDetailsDAORow(select, i + 1);
		}

		return rows;
	}
}