package com.ibm.itso.sal404.news.dao;
import java.sql.SQLException;

import com.ibm.db.beans.DBModify;
import com.ibm.db.beans.DBParameterMetaData;
import com.ibm.itso.sal404.common.util.AppProperties;
/**
 * sal404 Realty sample application
 * 
 * @component	newscomponent
 * @layer		business facade
 * 
 * This class sets the DBModify property values. It also provides 
 * methods that execute your SQL statement and return 
 * a DBModify reference.
 * 
 * Generated:   May 22, 2003 9:54:14 PM
 * @author 		Ilaria Gorla
 * @version		1.0.0
 * 
 */
public class ModifyNewsItemDetailsDAO
{
	private DBModify modify;
	/**
	 * Constructor for a DBModify class.
	 */
	public ModifyNewsItemDetailsDAO()
	{
		super();
		initializer();
	}
	/**
	 * Creates a DBModify instance and initializes its properties.
	 */
	protected void initializer()
	{
		modify = new DBModify();
		try
		{
			modify.setDataSourceName(AppProperties.getInstance().getProperty("dataSourceJNDIName"));
			modify.setCommand(
				"UPDATE DB2ADMIN.NEWS_ITM SET NEWS_ITM_TITLE = :title, NEWS_ITM_DATE = :date, NEWS_ITM_AUTHOR = :author, NEWS_ITM_BODY = :body WHERE DB2ADMIN.NEWS_ITM.NEWS_ITM_ID = :id");
			DBParameterMetaData parmMetaData = modify.getParameterMetaData();
			parmMetaData.setParameter(
				1,
				"title",
				java.sql.DatabaseMetaData.procedureColumnIn,
				java.sql.Types.VARCHAR,
				String.class);
			parmMetaData.setParameter(
				2,
				"date",
				java.sql.DatabaseMetaData.procedureColumnIn,
				java.sql.Types.DATE,
				java.sql.Date.class);
			parmMetaData.setParameter(
				3,
				"author",
				java.sql.DatabaseMetaData.procedureColumnIn,
				java.sql.Types.VARCHAR,
				String.class);
			parmMetaData.setParameter(
				4,
				"body",
				java.sql.DatabaseMetaData.procedureColumnIn,
				java.sql.Types.LONGVARCHAR,
				String.class);
			parmMetaData.setParameter(
				5,
				"id",
				java.sql.DatabaseMetaData.procedureColumnIn,
				java.sql.Types.CHAR,
				String.class);
//				java.sql.Types.INTEGER,
//				Integer.class);
		}
		catch (SQLException ex)
		{
			ex.printStackTrace();
		}
	}
	/**
	 * Executes the SQL statement.
	 */
	public void execute(
		String title,
		java.util.Date date,
		String author,
		String body,
		String id)
		throws SQLException
	{
		try
		{
			java.sql.Date _date = new java.sql.Date(date.getTime());
			
			modify.setParameter("title", title);
			modify.setParameter("date", _date);
			modify.setParameter("author", author);
			modify.setParameter("body", body);
			modify.setParameter("id", id);
			modify.execute();
		}
		// Free resources of modify object. 
		finally
		{
			modify.close();
		}
	}
	/**
	 * Returns a DBModify reference.
	 */
	public DBModify getDBModify()
	{
		return modify;
	}
}