package com.ibm.itso.sal404.news.dao;
import java.sql.*;
import com.ibm.db.beans.*;
import com.ibm.itso.sal404.common.util.AppProperties;
/**
 * sal404 Realty sample application
 * 
 * @component	newscomponent
 * @layer		business facade
 * 
 * This class sets the DBSelect property values. It also provides 
 * methods that execute your SQL statement, return 
 * a DBSelect reference, and return an array of objects  
 * representing the rows in the result set.
 * 
 * Generated:  May 16, 2003 11:36:28 AM
 * @author 		Ilaria Gorla
 * @version		1.0.0
 * 
 */
public class NewsItemDAO
{
	private DBSelect select;
	/**
	 * Constructor for a DBSelect class.
	 */
	public NewsItemDAO()
	{
		super();
		initializer();
	}
	/**
	 * Creates a DBSelect instance and initializes its properties.
	 */
	protected void initializer()
	{
		select = new DBSelect();
		try
		{
			select.setDataSourceName(AppProperties.getInstance().getProperty("dataSourceJNDIName"));
			select.setCommand(
				"SELECT DB2ADMIN.NEWS_ITM.NEWS_ITM_ID, DB2ADMIN.NEWS_ITM.NEWS_ITM_TITLE, DB2ADMIN.NEWS_ITM.NEWS_ITM_DATE, DB2ADMIN.NEWS_ITM.NEWS_ITM_AUTHOR, DB2ADMIN.NEWS_ITM.NEWS_ITM_BODY FROM DB2ADMIN.NEWS_ITM ORDER BY DB2ADMIN.NEWS_ITM.NEWS_ITM_DATE DESC");
		}
		catch (SQLException ex)
		{
			ex.printStackTrace();
		}
	}
	/**
	 * Executes the SQL statement.
	 */
	public void execute() throws SQLException
	{
		try
		{
			select.execute();
		}
		// Free resources of select object. 
		finally
		{
			select.close();
		}
	}
	/**
	 * Returns a DBSelect reference.
	 */
	public DBSelect getDBSelect()
	{
		return select;
	}
	/**
	 * Returns an array of objects representing the rows in the result set.
	 */
	public NewsItemDAORow[] getRows()
	{
		NewsItemDAORow[] rows = new NewsItemDAORow[select.getRowCount()];
		for (int i = 0; i <= select.getRowCount() - 1; i++)
		{
			rows[i] = new NewsItemDAORow(select, i + 1);
		}
		return rows;
	}
}