package com.ibm.itso.sal404.propertycatalog.dao;
import java.sql.*;
import com.ibm.db.beans.*;
/**
 * 
 * sal404 Realty sample application
 * 
 * @component	Property Catalog component
 * @layer		name of layer here
 * 
 * This class sets the DBSelect property values. It also provides 
 * methods that execute your SQL statement, return 
 * a DBSelect reference, and return an array of objects  
 * representing the rows in the result set.
 * Generated:  May 20, 2003 6:15:06 PM
 * 
 * 
 * @author 		Gwen Gaumond, Twinstar Incorporated
 * @created		initial creation date here		
 * @version		x.y.z / @May 20, 2003	
 *
 * @see		 	classes associated with this class
 * 
 */
public class NewPropertyIdDAO
{
	private DBSelect select;
	/**
	 * Constructor for a DBSelect class.
	 */
	public NewPropertyIdDAO()
	{
		super();
		initializer();
	}
	/**
	 * Creates a DBSelect instance and initializes its properties.
	 */
	protected void initializer()
	{
		select = new DBSelect();
		try
		{	select.setDataSourceName("jdbc/sal404");
			
			select.setCommand(
				"SELECT DB2ADMIN.PROP.PROP_ID FROM DB2ADMIN.PROP WHERE DB2ADMIN.PROP.PROP_CRD_ON IN ( SELECT max(DB2ADMIN.PROP.PROP_CRD_ON) FROM DB2ADMIN.PROP ) AND DB2ADMIN.PROP.USR_ID = :userId AND DB2ADMIN.PROP.PROP_ADDR_BLDG_NUM = :buildingNumber AND DB2ADMIN.PROP.PROP_ADDR_STRT_NAM = :streetName AND DB2ADMIN.PROP.PROP_ADDR_UNIT_NUM = :unitNumber AND DB2ADMIN.PROP.PROP_ADDR_PO_BOX = :postOfficeBox AND DB2ADMIN.PROP.PROP_PRICE = :price AND DB2ADMIN.PROP.PROP_PIC_URL = :pictureURL");
			DBParameterMetaData parmMetaData = select.getParameterMetaData();
			parmMetaData.setParameter(
				1,
				"userId",
				java.sql.DatabaseMetaData.procedureColumnIn,
				java.sql.Types.INTEGER,
				Integer.class);
			parmMetaData.setParameter(
				2,
				"buildingNumber",
				java.sql.DatabaseMetaData.procedureColumnIn,
				java.sql.Types.VARCHAR,
				String.class);
			parmMetaData.setParameter(
				3,
				"streetName",
				java.sql.DatabaseMetaData.procedureColumnIn,
				java.sql.Types.VARCHAR,
				String.class);
			parmMetaData.setParameter(
				4,
				"unitNumber",
				java.sql.DatabaseMetaData.procedureColumnIn,
				java.sql.Types.VARCHAR,
				String.class);
			parmMetaData.setParameter(
				5,
				"postOfficeBox",
				java.sql.DatabaseMetaData.procedureColumnIn,
				java.sql.Types.VARCHAR,
				String.class);
			parmMetaData.setParameter(
				6,
				"price",
				java.sql.DatabaseMetaData.procedureColumnIn,
				java.sql.Types.DECIMAL,
				java.math.BigDecimal.class);
			parmMetaData.setParameter(
				7,
				"pictureURL",
				java.sql.DatabaseMetaData.procedureColumnIn,
				java.sql.Types.VARCHAR,
				String.class);
		}
		catch (SQLException ex)
		{
			ex.printStackTrace();
		}
	}
	/**
	 * Executes the SQL statement.
	 */
	public void execute(
		Integer userId,
		String buildingNumber,
		String streetName,
		String unitNumber,
		String postOfficeBox,
		java.math.BigDecimal price,
		String pictureURL)
		throws SQLException
	{
		try
		{
			
			select.setParameter("userId", userId);
			select.setParameter("buildingNumber", buildingNumber);
			select.setParameter("streetName", streetName);
			select.setParameter("unitNumber", unitNumber);
			select.setParameter("postOfficeBox", postOfficeBox);
			select.setParameter("price", price);
			select.setParameter("pictureURL", pictureURL);
			select.execute();
		}
		// Free resources of select object. 
		finally
		{
			select.close();
		}
	}
	/**
	 * Returns a DBSelect reference.
	 */
	public DBSelect getDBSelect()
	{
		return select;
	}
	/**
	 * Returns an array of objects representing the rows in the result set.
	 */
	public NewPropertyIdDAORow[] getRows()
	{
		NewPropertyIdDAORow[] rows =
			new NewPropertyIdDAORow[select.getRowCount()];
		for (int i = 0; i <= select.getRowCount() - 1; i++)
		{
			rows[i] = new NewPropertyIdDAORow(select, i + 1);
		}
		return rows;
	}
}