package com.ibm.itso.sal404.reporting.dto;

import java.sql.Timestamp;

import com.ibm.itso.sal404.common.base.DataTransferObjectIf;


/**
 * 
 * sal404 Realty sample application
 * 
 * @component	Reporting component
 * @layer		Domain layer
 * 
 * This class is a DataTransferObject that encapsulates information
 * about a property and the number it was added to an interest list
 * 
 * @author 		Stelios Psarras, Cyantific.net Ltd
 * @created		14 May 2003		
 * @version		1.0.0 / @14-May-03	
 *
 * @see		 	ReportPropertiesForAgentSQL
 * 				ReportingManager
 * 
 */
public class PropertyDetailsReportItemDTO implements DataTransferObjectIf
{
	private int 		_id;
	private String 		_typeDescription;
	private String 		_statusDescription;
	private String		_addressCountryName;
	private String		_addressPostCode;
	private String		_addressRegion;
	private String		_addressMunicipality;
	private String		_addressStreetName;
	private String		_addressUnitNumber;
	private String		_addressPOBox;
	private String		_addressBuildingNumber;
	private String		_addressAdditionalText;
	private double		_price;
	private String		_pictureURL;
	private Timestamp	_createdOn;
	private int			_addedToInterestListCount;
		
	/**
	 * Constructor for PropertyDetailsReportItemDTO.
	 */
	public PropertyDetailsReportItemDTO()
	{
		super();
	}
	/**
	 * Returns the addedToInterestListCount.
	 * @return int
	 */
	public int getAddedToInterestListCount()
	{
		return _addedToInterestListCount;
	}

	/**
	 * Returns the addressAdditionalText.
	 * @return String
	 */
	public String getAddressAdditionalText()
	{
		return _addressAdditionalText;
	}

	/**
	 * Returns the addressBuildingNumber.
	 * @return String
	 */
	public String getAddressBuildingNumber()
	{
		return _addressBuildingNumber;
	}

	/**
	 * Returns the addressCountryName.
	 * @return String
	 */
	public String getAddressCountryName()
	{
		return _addressCountryName;
	}

	/**
	 * Returns the addressMunicipality.
	 * @return String
	 */
	public String getAddressMunicipality()
	{
		return _addressMunicipality;
	}

	/**
	 * Returns the addressPOBox.
	 * @return String
	 */
	public String getAddressPOBox()
	{
		return _addressPOBox;
	}

	/**
	 * Returns the addressPostCode.
	 * @return String
	 */
	public String getAddressPostCode()
	{
		return _addressPostCode;
	}

	/**
	 * Returns the addressRegion.
	 * @return String
	 */
	public String getAddressRegion()
	{
		return _addressRegion;
	}

	/**
	 * Returns the addressStreetName.
	 * @return String
	 */
	public String getAddressStreetName()
	{
		return _addressStreetName;
	}

	/**
	 * Returns the addressUnitNumber.
	 * @return String
	 */
	public String getAddressUnitNumber()
	{
		return _addressUnitNumber;
	}

	/**
	 * Returns the createdOn.
	 * @return Timestamp
	 */
	public Timestamp getCreatedOn()
	{
		return _createdOn;
	}

	/**
	 * Returns the id.
	 * @return int
	 */
	public int getId()
	{
		return _id;
	}

	/**
	 * Returns the pictureURL.
	 * @return String
	 */
	public String getPictureURL()
	{
		return _pictureURL;
	}

	/**
	 * Returns the price.
	 * @return double
	 */
	public double getPrice()
	{
		return _price;
	}

	/**
	 * Returns the statusDescription.
	 * @return String
	 */
	public String getStatusDescription()
	{
		return _statusDescription;
	}

	/**
	 * Returns the typeDescription.
	 * @return String
	 */
	public String getTypeDescription()
	{
		return _typeDescription;
	}

	/**
	 * Sets the addedToInterestListCount.
	 * @param addedToInterestListCount The addedToInterestListCount to set
	 */
	public void setAddedToInterestListCount(int addedToInterestListCount)
	{
		_addedToInterestListCount = addedToInterestListCount;
	}

	/**
	 * Sets the addressAdditionalText.
	 * @param addressAdditionalText The addressAdditionalText to set
	 */
	public void setAddressAdditionalText(String addressAdditionalText)
	{
		_addressAdditionalText = addressAdditionalText;
	}

	/**
	 * Sets the addressBuildingNumber.
	 * @param addressBuildingNumber The addressBuildingNumber to set
	 */
	public void setAddressBuildingNumber(String addressBuildingNumber)
	{
		_addressBuildingNumber = addressBuildingNumber;
	}

	/**
	 * Sets the addressCountryName.
	 * @param addressCountryName The addressCountryName to set
	 */
	public void setAddressCountryName(String addressCountryName)
	{
		_addressCountryName = addressCountryName;
	}

	/**
	 * Sets the addressMunicipality.
	 * @param addressMunicipality The addressMunicipality to set
	 */
	public void setAddressMunicipality(String addressMunicipality)
	{
		_addressMunicipality = addressMunicipality;
	}

	/**
	 * Sets the addressPOBox.
	 * @param addressPOBox The addressPOBox to set
	 */
	public void setAddressPOBox(String addressPOBox)
	{
		_addressPOBox = addressPOBox;
	}

	/**
	 * Sets the addressPostCode.
	 * @param addressPostCode The addressPostCode to set
	 */
	public void setAddressPostCode(String addressPostCode)
	{
		_addressPostCode = addressPostCode;
	}

	/**
	 * Sets the addressRegion.
	 * @param addressRegion The addressRegion to set
	 */
	public void setAddressRegion(String addressRegion)
	{
		_addressRegion = addressRegion;
	}

	/**
	 * Sets the addressStreetName.
	 * @param addressStreetName The addressStreetName to set
	 */
	public void setAddressStreetName(String addressStreetName)
	{
		_addressStreetName = addressStreetName;
	}

	/**
	 * Sets the addressUnitNumber.
	 * @param addressUnitNumber The addressUnitNumber to set
	 */
	public void setAddressUnitNumber(String addressUnitNumber)
	{
		_addressUnitNumber = addressUnitNumber;
	}

	/**
	 * Sets the createdOn.
	 * @param createdOn The createdOn to set
	 */
	public void setCreatedOn(Timestamp createdOn)
	{
		_createdOn = createdOn;
	}

	/**
	 * Sets the id.
	 * @param id The id to set
	 */
	public void setId(int id)
	{
		_id = id;
	}

	/**
	 * Sets the pictureURL.
	 * @param pictureURL The pictureURL to set
	 */
	public void setPictureURL(String pictureURL)
	{
		_pictureURL = pictureURL;
	}

	/**
	 * Sets the price.
	 * @param price The price to set
	 */
	public void setPrice(double price)
	{
		_price = price;
	}

	/**
	 * Sets the statusDescription.
	 * @param statusDescription The statusDescription to set
	 */
	public void setStatusDescription(String statusDescription)
	{
		_statusDescription = statusDescription;
	}

	/**
	 * Sets the typeDescription.
	 * @param typeDescription The typeDescription to set
	 */
	public void setTypeDescription(String typeDescription)
	{
		_typeDescription = typeDescription;
	}

    private static final long serialVersionUID = 4708179426003895036L;

}
