package com.ibm.itso.sal404.user.dao;
import java.sql.*;
import com.ibm.db.beans.*;
import com.ibm.itso.sal404.common.util.AppProperties;

// Import Log4J Logger
import org.apache.log4j.Logger;

/**
 * This class sets the DBSelect property values. It also provides 
 * methods that execute your SQL statement, return 
 * a DBSelect reference, and return an array of objects  
 * representing the rows in the result set.
 * Generated:  May 27, 2003 5:28:32 PM
 */

public class GetAllUsersDAO
{
	// Configure Log4J Logger
	private static Logger logger = Logger.getLogger(GetAllUsersDAO.class);	

	private DBSelect select;

	/**
	 * Constructor for a DBSelect class.
	 */
	public GetAllUsersDAO()
	{
		super();
		initializer();
	}

	/**
	 * Creates a DBSelect instance and initializes its properties.
	 */
	protected void initializer()
	{
		select = new DBSelect();
		try
		{
			select.setDataSourceName(AppProperties.getInstance().getProperty("dataSourceJNDIName"));
			select.setCommand(
				"SELECT DB2ADMIN.USR.USR_ID, DB2ADMIN.USR.USR_USERNAME, DB2ADMIN.USR.USR_PASSWORD, DB2ADMIN.USR.USR_ROLE, DB2ADMIN.USR.USR_FIRST_NAME, DB2ADMIN.USR.USR_LAST_NAME, DB2ADMIN.USR.USR_EMAIL_ADDR, DB2ADMIN.USR.USR_WEB_URL, DB2ADMIN.USR.USR_PHN_NUM, DB2ADMIN.USR.USR_ACTIVE, DB2ADMIN.USR.USR_CRD_ON FROM DB2ADMIN.USR");
		}
		catch (SQLException ex)
		{
			ex.printStackTrace();
		}
	}

	/**
	 * Executes the SQL statement.
	 */
	public void execute() throws SQLException
	{
		try
		{
			select.execute();
		}

		// Free resources of select object. 
		finally
		{
			select.close();
		}
	}

	/**
	 * Returns a DBSelect reference.
	 */
	public DBSelect getDBSelect()
	{
		return select;
	}

	/**
	 * Returns an array of objects representing the rows in the result set.
	 */
	public GetAllUsersDAORow[] getRows()
	{
		GetAllUsersDAORow[] rows = new GetAllUsersDAORow[select.getRowCount()];
		for (int i = 0; i <= select.getRowCount() - 1; i++)
		{
			rows[i] = new GetAllUsersDAORow(select, i + 1);
		}
		return rows;
	}
}