package com.ibm.itso.sal404.user.dao;
import java.sql.*;
import com.ibm.db.beans.*;
import com.ibm.itso.sal404.common.util.AppProperties;

// Import Log4J Logger
import org.apache.log4j.Logger;

/**
 * This class sets the DBSelect property values. It also provides 
 * methods that execute your SQL statement, return 
 * a DBSelect reference, and return an array of objects  
 * representing the rows in the result set.
 * Generated:  May 27, 2003 12:14:15 PM
 */

public class UserAddressSearchDAO
{
	// Configure Log4J Logger
	private static Logger logger = Logger.getLogger(UserAddressSearchDAO.class);	
	
	private DBSelect select;

	/**
	 * Constructor for a DBSelect class.
	 */
	public UserAddressSearchDAO()
	{
		super();
		initializer();
	}

	/**
	 * Creates a DBSelect instance and initializes its properties.
	 */
	protected void initializer()
	{
		select = new DBSelect();
		try
		{
			select.setDataSourceName(AppProperties.getInstance().getProperty("dataSourceJNDIName"));
			select.setCommand(
				"SELECT DB2ADMIN.USR_ADDR.USR_ADDR_ID, DB2ADMIN.USR_ADDR.USR_ID, DB2ADMIN.USR_ADDR.USR_ADDR_NAME, DB2ADMIN.USR_ADDR.USR_ADDR_CNTRY_CD, DB2ADMIN.USR_ADDR.USR_ADDR_POST_CD, DB2ADMIN.USR_ADDR.USR_ADDR_RGN, DB2ADMIN.USR_ADDR.USR_ADDR_MUNI, DB2ADMIN.USR_ADDR.USR_ADDR_STRT_NAME, DB2ADMIN.USR_ADDR.USR_ADDR_BLDG_NUM, DB2ADMIN.USR_ADDR.USR_ADDR_UNIT_NUM, DB2ADMIN.USR_ADDR.USR_ADDR_PO_BOX, DB2ADMIN.USR_ADDR.USR_ADDR_ADDL_TEXT, DB2ADMIN.USR_ADDR.USR_CRD_ON FROM DB2ADMIN.USR_ADDR WHERE DB2ADMIN.USR_ADDR.USR_ID = :userId");
			DBParameterMetaData parmMetaData = select.getParameterMetaData();
			parmMetaData.setParameter(
				1,
				"userId",
				java.sql.DatabaseMetaData.procedureColumnIn,
				java.sql.Types.INTEGER,
				Integer.class);
		}
		catch (SQLException ex)
		{
			ex.printStackTrace();
		}
	}

	/**
	 * Executes the SQL statement.
	 */
	public void execute(Integer userId)
		throws SQLException
	{
		try
		{
			select.setParameter("userId", userId);
			select.execute();
		}

		// Free resources of select object. 
		finally
		{
			select.close();
		}
	}

	/**
	 * Returns a DBSelect reference.
	 */
	public DBSelect getDBSelect()
	{
		return select;
	}

	/**
	 * Returns an array of objects representing the rows in the result set.
	 */
	public UserAddressSearchDAORow[] getRows()
	{
		UserAddressSearchDAORow[] rows =
			new UserAddressSearchDAORow[select.getRowCount()];
		for (int i = 0; i <= select.getRowCount() - 1; i++)
		{
			rows[i] = new UserAddressSearchDAORow(select, i + 1);
		}
		return rows;
	}
}