package com.ibm.itso.sal404.user.dao;
import java.sql.*;
import com.ibm.db.beans.*;
import com.ibm.itso.sal404.common.util.AppProperties;

// Import Log4J Logger
import org.apache.log4j.Logger;


/**
 * This class sets the DBSelect property values. It also provides 
 * methods that execute your SQL statement, return 
 * a DBSelect reference, and return an array of objects  
 * representing the rows in the result set.
 * Generated:  May 26, 2003 12:08:00 PM
 */

public class UserSearchDAO
{
	// Configure Log4J Logger
	private static Logger logger = Logger.getLogger(UserSearchDAO.class);	

	private DBSelect select;

	/**
	 * Constructor for a DBSelect class.
	 */
	public UserSearchDAO()
	{
		super();
		initializer();
	}

	/**
	 * Creates a DBSelect instance and initializes its properties.
	 */
	protected void initializer()
	{
		select = new DBSelect();
		try
		{
			select.setDataSourceName(AppProperties.getInstance().getProperty("dataSourceJNDIName"));
			select.setCommand(
				"SELECT DB2ADMIN.USR.USR_ID, DB2ADMIN.USR.USR_USERNAME, DB2ADMIN.USR.USR_PASSWORD, DB2ADMIN.USR.USR_ROLE, DB2ADMIN.USR.USR_FIRST_NAME, DB2ADMIN.USR.USR_LAST_NAME, DB2ADMIN.USR.USR_EMAIL_ADDR, DB2ADMIN.USR.USR_WEB_URL, DB2ADMIN.USR.USR_PHN_NUM, DB2ADMIN.USR.USR_ACTIVE, DB2ADMIN.USR.USR_CRD_ON FROM DB2ADMIN.USR WHERE DB2ADMIN.USR.USR_USERNAME = :username");
			DBParameterMetaData parmMetaData = select.getParameterMetaData();
			parmMetaData.setParameter(
				1,
				"username",
				java.sql.DatabaseMetaData.procedureColumnIn,
				java.sql.Types.CHAR,
				String.class);
		}
		catch (SQLException ex)
		{
			ex.printStackTrace();
		}
	}

	/**
	 * Executes the SQL statement.
	 */
	public void execute(String username)
		throws SQLException
	{
		try
		{
			select.setParameter("username", username);
			select.execute();
		}

		// Free resources of select object. 
		finally
		{
			select.close();
		}
	}

	/**
	 * Returns a DBSelect reference.
	 */
	public DBSelect getDBSelect()
	{
		return select;
	}

	/**
	 * Returns an array of objects representing the rows in the result set.
	 */
	public UserSearchDAORow[] getRows()
	{
		UserSearchDAORow[] rows = new UserSearchDAORow[select.getRowCount()];
		for (int i = 0; i <= select.getRowCount() - 1; i++)
		{
			rows[i] = new UserSearchDAORow(select, i + 1);
		}
		return rows;
	}
}