package com.ibm.itso.sal404.interestlist.action;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;

import org.apache.struts.action.Action;
import org.apache.struts.action.ActionError;
import org.apache.struts.action.ActionErrors;
import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionForward;
import org.apache.struts.action.ActionMapping;

import com.ibm.itso.sal404.interestlist.InterestListManager;
import com.ibm.itso.sal404.interestlist.dto.InterestListDTO;

// Import Log4J Logger
import org.apache.log4j.Logger;

/**
 * 
 * sal404 Realty sample application
 * 
 * @component	Interest list
 * @layer		action
 * 
 * AddPropertyToInterestListAction<br>
 * This Action adds a property to the interest list.<br>
 * 
 * 
 * @author 		Mark Buensalido
 * @version		1.0.0
 *
 * 
 */
public final class AddPropertyToInterestListAction extends Action
{

	/**
	 * Configures the log4j Logger.
	 * @since 1.0.0
	 */
	private static Logger logger =
		Logger.getLogger(AddPropertyToInterestListAction.class);

	/**
	* Constructor
	*/
	public AddPropertyToInterestListAction()
	{

		super();

	}
	public ActionForward execute(
		ActionMapping mapping,
		ActionForm form,
		HttpServletRequest request,
		HttpServletResponse response)
		throws Exception
	{

		ActionErrors errors = new ActionErrors();
		ActionForward forward = new ActionForward();
		// return value

		InterestListManager manager;
		HttpSession session;
		String propertyId;
		InterestListDTO DTO;

		logger.info("ENTRY:execute");

		try
		{

			// grab the session and retrieved the DTO
			session = request.getSession(false);
			DTO = (InterestListDTO) session.getAttribute("interestList");
			logger.debug("InterestListDTO retrieved");

			// grab the propertyID from the property catalog
			propertyId = request.getParameter("propertyId");
			logger.debug("PropertyId to add is:" + propertyId);

			// manager will lookup the property information
			// and add the property to the interest list
			logger.debug("Manager begin");
			manager = new InterestListManager(DTO);
			manager.addItem(propertyId);
			logger.debug("Manager done");

		}
		catch (Exception e)
		{

			// the logger warns here because there may be uncaught exceptions			
			logger.warn(e.getMessage());
			// Report the error using the appropriate name and ID.
			errors.add("name", new ActionError(e.getMessage()));

		}

		// If a message is required, save the specified key(s)
		// into the request for use by the <struts:errors> tag.

		if (!errors.isEmpty())
		{
			saveErrors(request, errors);
			forward = mapping.findForward("failure");
		}
		else
		{
			forward = mapping.findForward("success");
		}

		logger.info("EXIT:execute");

		// Finish with
		return (forward);

	}
}
