package com.ibm.itso.sal404.interestlist.action;

import java.util.List;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;

import org.apache.struts.action.Action;
import org.apache.struts.action.ActionError;
import org.apache.struts.action.ActionErrors;
import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionForward;
import org.apache.struts.action.ActionMapping;

import com.ibm.itso.sal404.common.exception.ApplicationException;
import com.ibm.itso.sal404.interestlist.InterestListManager;
import com.ibm.itso.sal404.interestlist.dto.InterestListDTO;
import com.ibm.itso.sal404.interestlist.form.InterestListForm;
import com.ibm.itso.sal404.interestlist.itemadapter.InterestListLineItem;
import com.ibm.itso.sal404.user.dto.UserDetailsDTO;

// Import Log4J Logger
import org.apache.log4j.Logger;

/**
 * 
 * sal404 Realty sample application
 * 
 * @component	Interest list
 * @layer		action
 * 
 * UpdateInterestListAction<br>
 * This Action updates the interest list and also handles the Checkout procedure.<br>
 * 
 * 
 * @author 		Mark Buensalido
 * @version		1.0.0
 *
 * 
 */
public final class UpdateInterestListAction extends Action
{

	/**
	 * Configures the log4j Logger.
	 * @since 1.0.0
	 */
	private static Logger logger =
		Logger.getLogger(UpdateInterestListAction.class);

	/**
	* Constructor
	*/
	public UpdateInterestListAction()
	{

		super();

	}
	public ActionForward execute(
		ActionMapping mapping,
		ActionForm form,
		HttpServletRequest request,
		HttpServletResponse response)
		throws Exception
	{

		ActionErrors errors = new ActionErrors();
		ActionForward forward = new ActionForward();
		// return value
		InterestListForm interestListForm = (InterestListForm) form;
		List items;
		InterestListLineItem item;
		InterestListManager manager;
		HttpSession session;
		InterestListDTO DTO;
		UserDetailsDTO userDTO;
		boolean checkout = false, checkoutSuccessful = false;

		logger.info("ENTRY:execute");


		try
		{

			// retrieve the session and the DTO
			session = request.getSession(false);
			logger.debug("HttpSession retrieved");
			
			DTO = (InterestListDTO) session.getAttribute("interestList");
			logger.debug("InterestListDTO retrieved");

			// instance the manager and grab the list of items from the FORM
			logger.debug("Manager begin");			
			manager = new InterestListManager(DTO);
			items = interestListForm.getInterestListLineItems();

			logger.debug("InterestListLineItem list retrieved...iterate");

			// iterate the list of items from the form
			// use the manager's update method
			for (int lcv = 0; lcv < items.size(); lcv++)
			{
				item = (InterestListLineItem) items.get(lcv);
				logger.debug("InterestListLineItem:" + lcv +" retrieved");
				manager.updateItem(item);
				logger.debug("Manager updated item");
			}

			// determine the status of checkout
			// if the user presses the checkout button, the
			// dispatcher field in the FORM will say Checkout
			checkout = interestListForm.getDispatcher().equals("Checkout");

			if (checkout)
			{

				// during checkout, use the manager's checkout method
				// then, reset the interest list because you don't
				// want the interest list to be checked out more than once
				logger.debug("Checkout was selected");
				userDTO = (UserDetailsDTO) session.getAttribute("user");
				manager.checkout(userDTO.getId());
				session.setAttribute(
					"interestList",
					InterestListManager.getNewInterestList(userDTO));
				checkoutSuccessful = true;
			}

		}
		catch (ApplicationException e)
		{

			// Report the error using the appropriate name and ID.
			errors.add("name", new ActionError(e.getMessage()));

		}
		catch (Exception e)
		{

			// warn here if there is a non ApplicationException
			logger.warn(e.getClass().getName() + ":" + e.getMessage());
			// Report the error using the appropriate name and ID.
			errors.add("name", new ActionError("interestList.error.checkout.unknown"));
		}

		// If a message is required, save the specified key(s)
		// into the request for use by the <struts:errors> tag.

		if (!errors.isEmpty())
		{
			saveErrors(request, errors);
		}

		// if this was a checkout session and it was successful
		// then go to the checkout success forward
		// otherwise
		// proceed as normal so that the errors can be displayed
		// to the client
		if (checkout && checkoutSuccessful)
		{
			forward = mapping.findForward("checkoutSuccessful");

		}
		else
		{

			forward = mapping.findForward("success");
		}
		
		logger.info("EXIT:execute");
		// Finish with
		return (forward);

	}
}
