package com.ibm.itso.sal404.news.action;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.log4j.Logger;
import org.apache.struts.action.Action;
import org.apache.struts.action.ActionError;
import org.apache.struts.action.ActionErrors;
import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionForward;
import org.apache.struts.action.ActionMapping;
import org.apache.struts.util.MessageResources;

import com.ibm.itso.sal404.common.exception.ApplicationException;
import com.ibm.itso.sal404.news.NewsSessionData;
import com.ibm.itso.sal404.news.dto.NewsItemDTO;
import com.ibm.itso.sal404.news.form.NewsItemFormBean;

/**
 * 
 * sal404 Realty sample application
 * 
 * @component	newscomponent
 * @layer		Controller Layer
 * 
 * This Action adds a news item to the news list
 * 
 * @author 		Ilaria Gorla
 * @created		18 May 2003		
 * @version		1.0.0	
 * 
 */
public class AddNewsItemAction extends Action
{
	// Configure Log4J Logger
	private static Logger logger = Logger.getLogger(AddNewsItemAction.class);

	/**
	* Constructor
	*/
	public AddNewsItemAction()
	{
		super();
	}
	
	/**
	 * 
	 */
	public ActionForward execute(
		ActionMapping mapping,
		ActionForm form,
		HttpServletRequest request,
		HttpServletResponse response)
	{
		logger.info("ENTRY: execute");

		ActionErrors errors = new ActionErrors();
		ActionForward forward = new ActionForward();
		// return value

		/* set up the DTO  */
		NewsItemDTO newsItemDTO = populateNewsDTO(form);
		/* set Manager class and do add business logic */
		addNews(request, errors, newsItemDTO);

		// If a message is required, save the specified key(s)
		// into the request for use by the <struts:errors> tag.
		forward = checkForErrors(mapping, request, errors);

		logger.info("EXIT:  execute");
		// Finish with
		return (forward);
	}

	/**
	 * 
	 * @param mapping
	 * @param request
	 * @param errors
	 * @return
	 */
	public ActionForward checkForErrors(
		ActionMapping mapping,
		HttpServletRequest request,
		ActionErrors errors)
	{
		ActionForward forward;
		if (!errors.isEmpty())
		{
			saveErrors(request, errors);
		
			// Forward control to the appropriate 'failure' URI (change name as desired)
			forward = mapping.findForward("failure");
		}
		else
		{
			// Forward control to the appropriate 'success' URI (change name as desired)
			forward = mapping.findForward("success");
			setupSuccessMessage(request);
		}
		return forward;
	}

	/**
	 * 
	 * @param request
	 * @param errors
	 * @param newsItemDTO
	 */
	public void addNews(HttpServletRequest request, ActionErrors errors, NewsItemDTO newsItemDTO)
	{
		NewsSessionData newsSessionData = 
		    (NewsSessionData)request.getSession().getAttribute("newsSessionData");
		   
		try
		{
		    newsSessionData.create(newsItemDTO);
		}
		catch (ApplicationException ae)
		{
			// Report the error using the appropriate name and ID.
			errors.add("News", new ActionError(ae.getStrutsMessage()));
		}
	}

	/**
	 * 
	 * @param form
	 * @return
	 */
	public NewsItemDTO populateNewsDTO(ActionForm form)
	{
		NewsItemFormBean addNewsItemFormBean = (NewsItemFormBean) form;
		NewsItemDTO newsItemDTO = new NewsItemDTO();
		newsItemDTO.setTitle(addNewsItemFormBean.getTitle());
		newsItemDTO.setDate(addNewsItemFormBean.getDate());
		newsItemDTO.setAuthor(addNewsItemFormBean.getAuthor());
		newsItemDTO.setBody(addNewsItemFormBean.getBody());
		return newsItemDTO;
	}

	/**
	 * 
	 * @param request
	 */
	public void setupSuccessMessage(HttpServletRequest request)
	{
		MessageResources messages = getResources(request);
		String confirmMessage = messages.getMessage("news.add.ok");
		// confirmation message
		request.setAttribute("confirmationMessage", confirmMessage);
	}
}
