package com.ibm.itso.sal404.news.action;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.log4j.Logger;
import org.apache.struts.action.Action;
import org.apache.struts.action.ActionError;
import org.apache.struts.action.ActionErrors;
import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionForward;
import org.apache.struts.action.ActionMapping;

import com.ibm.itso.sal404.common.exception.ApplicationException;
import com.ibm.itso.sal404.news.NewsSessionData;
import com.ibm.itso.sal404.news.dto.NewsItemDTO;
import com.ibm.itso.sal404.news.dto.NewsItemVectorDTO;
import com.ibm.itso.sal404.news.form.ManageNewsFormBean;

/**
 * sal404 Realty sample application
 * 
 * @component	newscomponent
 * @layer		Controller Layer
 * 
 * This Action adds or modifies a news item
 * 
 * @author 		Ilaria Gorla
 * @created		May 2003		
 * @version		1.0.0	
 */
public class ManageNewsAction extends Action
{
	// Configure Log4J Logger
	private static Logger logger = Logger.getLogger(ManageNewsAction.class);

	ActionErrors errors = new ActionErrors();
	ActionForward forward = new ActionForward();

	// return value
	ManageNewsFormBean manageNewsFormBean = null;

	/**
	* Constructor
	*/
	public ManageNewsAction()
	{
		super();
	}

	/**
	 * 
	 */
	public ActionForward execute(
		ActionMapping mapping,
		ActionForm form,
		HttpServletRequest request,
		HttpServletResponse response)
	{
		logger.info("ENTRY: execute");
		manageNewsFormBean = (ManageNewsFormBean) form;
		ActionForward forward = null;
		errors.clear();

		if (request.getParameter("new") != null)
		{
			forward = (addNews(mapping, manageNewsFormBean, request, response));
		}

		if (request.getParameter("modify") != null)
		{
			forward =
				(modifyNews(mapping, manageNewsFormBean, request, response));
		}

		if (request.getParameter("delete") != null)
		{
			try {
                forward =
                	(deleteNews(mapping, manageNewsFormBean, request, response));
            } catch (Exception e) {
                logger.error(e.getMessage());
                e.printStackTrace();
            }
		}

		logger.info("EXIT:  execute");
		return (forward);
	}

	/**
	 * 
	 * @param mapping
	 * @param form
	 * @param request
	 * @param response
	 * @return
	 */
	public ActionForward addNews(
		ActionMapping mapping,
		ActionForm form,
		HttpServletRequest request,
		HttpServletResponse response)
	{
		return mapping.findForward("new");
	}

	/**
	 * 
	 * @param mapping
	 * @param form
	 * @param request
	 * @param response
	 * @return
	 */
	public ActionForward modifyNews(
		ActionMapping mapping,
		ActionForm form,
		HttpServletRequest request,
		HttpServletResponse response)
	{
	    logger.info("ENTRY: modifyNews");
		if (manageNewsFormBean.getId() != null)
		{
			NewsSessionData newsSessionData = 
			    (NewsSessionData)request.getSession().getAttribute("newsSessionData");
			   
			try {
                newsSessionData.setCurrent(manageNewsFormBean.getId());
            } catch (ApplicationException e) {
                logger.error("error setting current nets item: " + e.getMessage());
            }
		}
		else
		{
			errors.add( "News", new ActionError("news.error.no.modify.selection"));
		}

		// If a message is required, save the specified key(s)
		// into the request for use by the <struts:errors> tag.
		if (!errors.isEmpty())
		{
			saveErrors(request, errors);
			forward = mapping.findForward("failure");
		}
		else
		{
			forward = mapping.findForward("modify");
		}

	    logger.info("EXIT: modifyNews");
		return (forward);
	}

	/**
	 * 
	 * @param mapping
	 * @param form
	 * @param request
	 * @param response
	 * @return
	 * @throws Exception
	 */
	public ActionForward deleteNews(
		ActionMapping mapping,
		ActionForm form,
		HttpServletRequest request,
		HttpServletResponse response)
	{
		boolean deletesSelected = false;
		logger.debug("now check for deletes");
		NewsItemVectorDTO newsItemVectorDTO =
			manageNewsFormBean.getNewsItemVectorDTO();
		
		NewsSessionData newsSessionData = 
		    (NewsSessionData)request.getSession().getAttribute("newsSessionData");

		
		logger.debug(
			"Vector size is " + newsItemVectorDTO.getNewsItemVector().size());
		for (int i = 0; i < newsItemVectorDTO.getNewsItemVector().size(); i++)
		{
			NewsItemDTO newsItemDTO =
				(NewsItemDTO) newsItemVectorDTO.getNewsItemVector().elementAt(i);
			if (newsItemDTO.isDelete())
			{
				deletesSelected = true;
				logger.debug("Delete news item " + newsItemDTO.getId());
				try
				{
				    newsSessionData.setCurrent(newsItemDTO.getId());
				    newsSessionData.delete();
				}
				catch (ApplicationException ae)
				{
					// Report the error using the appropriate name and ID.
					errors.add("News", new ActionError(ae.getStrutsMessage()));
				}
			}
		}
		logger.debug("delete flag is " + deletesSelected);
		if (!deletesSelected)
		{
			logger.debug("delete flag error " + deletesSelected);
			errors.add(
				"News",
				new ActionError("news.error.no.delete.selection"));
		}
		if (!errors.isEmpty())
		{
			saveErrors(request, errors);
			forward = mapping.findForward("failure");
		}
		else
		{
			forward = mapping.findForward("delete");
		}
		logger.info("EXIT:  execute");
		return (forward);

	}
}
