package com.ibm.itso.sal404.news.action;

import java.lang.reflect.InvocationTargetException;
import java.text.SimpleDateFormat;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.commons.beanutils.PropertyUtils;
import org.apache.log4j.Logger;
import org.apache.struts.action.Action;
import org.apache.struts.action.ActionError;
import org.apache.struts.action.ActionErrors;
import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionForward;
import org.apache.struts.action.ActionMapping;
import org.apache.struts.util.MessageResources;

import com.ibm.itso.sal404.common.exception.ApplicationException;
import com.ibm.itso.sal404.news.NewsSessionData;
import com.ibm.itso.sal404.news.dto.NewsItemDTO;
import com.ibm.itso.sal404.news.form.NewsItemFormBean;

/**
 * sal404 Realty sample application
 * 
 * @component	newscomponent
 * @layer		Controller Layer
 * 
 * This Action modifies a news item
 * 
 * @author 		Ilaria Gorla
 * @created		May 2003		
 * @version		1.0.0	
 */
public class ModifyNewsItemAction extends Action
{
	// Configure Log4J Logger
	private static Logger logger = Logger.getLogger(ModifyNewsItemAction.class);

	private SimpleDateFormat dateFormat;

	/**
	* Constructor
	*/
	public ModifyNewsItemAction()
	{
		super();
	}

	/**
	 * 
	 */
	public ActionForward execute(
		ActionMapping mapping,
		ActionForm form,
		HttpServletRequest request,
		HttpServletResponse response)
	{
		logger.info("ENTRY: execute");

		ActionErrors errors = new ActionErrors();
		ActionForward forward = new ActionForward();
		// return value

		NewsItemDTO newsItemDTO = populateNewsDTO(form);

		modifyNews(request, errors, newsItemDTO);

		// If a message is required, save the specified key(s)
		// into the request for use by the <struts:errors> tag.
		if (!errors.isEmpty())
		{
			saveErrors(request, errors);
			forward = mapping.findForward("failure");
		}
		else
		{
		    forward = mapping.findForward("success");
			setupSuccessMessage(request);
		}

		// Finish with
		logger.info("EXIT: execute");
		return (forward);
	}

	/**
	 * 
	 * @param errors
	 * @param newsItemDTO
	 */
	public void modifyNews(HttpServletRequest request, ActionErrors errors, NewsItemDTO newsItemDTO)
	{
		NewsSessionData newsSessionData = null;
		try
		{
		    newsSessionData = (NewsSessionData)request.getSession().getAttribute("newsSessionData");
		    newsSessionData.update(newsItemDTO);
		}
		catch (ApplicationException ae)
		{
			// Report the error using the appropriate name and ID.
			errors.add("news", new ActionError(ae.getMessage()));
		}
	}

	/**
	 * 
	 * @param request
	 */
	public void setupSuccessMessage(HttpServletRequest request)
	{
		MessageResources messages = getResources(request);
		String confirmMessage = messages.getMessage("news.modify.ok");
		// confirmation message
		request.setAttribute("confirmationMessage", confirmMessage);
	}

	/**
	 * 
	 * @param form
	 * @return
	 */
	public NewsItemDTO populateNewsDTO(ActionForm form)
	{
		logger.info("ENTRY: populateNewsDTO");
		NewsItemFormBean newsItemFormBean =
			(NewsItemFormBean) form;
		NewsItemDTO newsItemDTO = new NewsItemDTO();
		try {
			PropertyUtils.copyProperties(newsItemDTO, newsItemFormBean);
		} catch (IllegalAccessException e1) {
			e1.printStackTrace();
		} catch (InvocationTargetException e1) {
			e1.printStackTrace();
		} catch (NoSuchMethodException e1) {
			e1.printStackTrace();
		}
		logger.info("EXIT:  populateNewsDTO");		
		return newsItemDTO;
	}
}