package com.ibm.itso.sal404.news.form;

import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Date;

import javax.servlet.http.HttpServletRequest;

import org.apache.log4j.Logger;
import org.apache.struts.action.ActionError;
import org.apache.struts.action.ActionErrors;
import org.apache.struts.action.ActionMapping;
import org.apache.struts.validator.ValidatorForm;

/**
 * sal404 Realty sample application
 * 
 * @component	newscomponent
 * @layer		Business Facade Layer
 * 
 * Form bean for a Struts application.
 * Users may access 5 fields on this form:
 * <ul>
 * <li>id - news id
 * <li>title - news title
 * <li>date - news date
 * <li>author - news author
 * <li>body - news body
 * </ul>
 * @version 	1.0
 * @author	Ilaria Gorla
 */
public class NewsItemFormBean extends ValidatorForm
{
	// Configure Log4J Logger
	private static Logger logger = Logger.getLogger(NewsItemFormBean.class);

	private String id = null;
	private String title = null;
	private String sdate = null;
	private String author = null;
	private String body = null;
	private Date date = new Date();
	
	SimpleDateFormat formatter = null;
	
	/**
	* Constructor
	*/
	public NewsItemFormBean()
	{
		super();

		formatter = new SimpleDateFormat("yyyy-MM-dd");
		setSdate(formatter.format(getDate()));
	}
	
	/**
	 * Get id
	 * @return String
	 */
	public String getId()
	{
		return id;
	}

	/**
	 * Set id
	 * @param <code>String</code>
	 */
	public void setId(String i)
	{
		id = i;
	}
	/**
	 * Get title
	 * @return String
	 */
	public String getTitle()
	{
		return title;
	}

	/**
	 * Set title
	 * @param <code>String</code>
	 */
	public void setTitle(String t)
	{
		title = t;
	}
    /**
     * @return Returns the sdate.
     */
    public String getSdate() {
        return sdate;
    }
    /**
     * @param date The sdate to set.
     */
    public void setSdate(String date) {
        sdate = date;
    }
	public String getAuthor()
	{
		return author;
	}

	/**
	 * Set author
	 * @param <code>String</code>
	 */
	public void setAuthor(String a)
	{
		author = a;
	}
	/**
	 * Get body
	 * @return String
	 */
	public String getBody()
	{
		return body;
	}

	/**
	 * Set body
	 * @param <code>String</code>
	 */
	public void setBody(String b)
	{
		body = b;
	}

	public void reset(ActionMapping mapping, HttpServletRequest request)
	{
		id = null;
		title = null;
		author = null;
		body = null;
	}
    /**
     * @param date The date to set.
     */
    public void setDate(Date date) {
        this.date = date;
    }
    /**
     * @return Returns the date.
     */
    public Date getDate() {
        return date;
    }
    
    /**
     * 
     */
	public ActionErrors validate(
			ActionMapping mapping,
			HttpServletRequest request)
		{
			logger.info("ENTRY: validate");

			ActionErrors errors = super.validate(mapping, request);
			
			try
			{
				setDate(formatter.parse(getSdate()));
			}
			catch (ParseException e)
			{
			    e.printStackTrace();
				errors.add("News", 
					new ActionError("error.news.invalidDate"));
			}
			
			logger.info("EXIT:  validate");
			return errors;
		}
}
