package com.ibm.itso.sal404.propertycatalog.action;
import java.lang.reflect.InvocationTargetException;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.commons.beanutils.PropertyUtils;
import org.apache.log4j.Logger;
import org.apache.struts.action.Action;
import org.apache.struts.action.ActionError;
import org.apache.struts.action.ActionErrors;
import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionForward;
import org.apache.struts.action.ActionMapping;

import com.ibm.itso.sal404.common.exception.ApplicationException;
import com.ibm.itso.sal404.propertycatalog.PropertyCatalogManager;
import com.ibm.itso.sal404.propertycatalog.dto.PropertyDTO;
import com.ibm.itso.sal404.propertycatalog.dto.PropertyFeatureDTO;
import com.ibm.itso.sal404.propertycatalog.dto.PropertyFeatureVectorDTO;
import com.ibm.itso.sal404.propertycatalog.dto.SearchPropertiesByCriteriaDTO;
import com.ibm.itso.sal404.propertycatalog.form.PropertyDetailsForm;

/**
 * 
 * sal404 Realty sample application
 * 
 * @component 	PropertyCatalog component
 * @layer		Controller layer
 * 
 * Description of the class here
 * 
 * @author 		Gwen Gaumond, Twinstar Incorporated
 * @created		May 13, 2003	
 * @version		1.0.0 / @May 13, 2003	
 *
 * @see		 	viewProperties.jsp
 * 				
 * 				PropertyDetailsForm.java 
 * 				addPropertyDetails.jsp
 */
public class AddPropertyDetailsAction extends Action
{
	// Configure Log4J Logger
	private static Logger logger =
		Logger.getLogger(PropertyCatalogManager.class);

	PropertyDTO propertyDTO = null;
	/**
	* Constructor
	*/

	String type = null;

	public AddPropertyDetailsAction()
	{
		super();
	}
	public ActionForward execute(
		ActionMapping mapping,
		ActionForm form,
		HttpServletRequest request,
		HttpServletResponse response)
		throws Exception
	{
		ActionErrors errors = new ActionErrors();
		ActionForward forward = new ActionForward();

		//create form
		PropertyDetailsForm addPropertyDetailsForm =
			(PropertyDetailsForm) form;

		//set manager class variable up
		PropertyCatalogManager propertyCatalogManager =
			new PropertyCatalogManager();
		try
		{
			propertyDTO = populatePropertyDTO(addPropertyDetailsForm);
			propertyDTO = addProperty(propertyDTO);

			/*The features are set into the PropertyFeatureDTO
			 * here.  They will then be passed to the manager class
			 * as well. */

			PropertyFeatureVectorDTO propertyFeatureVectorDTO =
				populateFeatureVectorDTO(addPropertyDetailsForm);
			logger.debug(
				"Feature vector has contents "
					+ propertyFeatureVectorDTO.isEmpty());
			if (!propertyFeatureVectorDTO.isEmpty())
			{
				logger.debug("features found to add");
				addPropertyFeatures(propertyDTO, propertyFeatureVectorDTO);
			}
		}
		catch (ApplicationException e)
		{
			if (e.getSeverityLevel() != 0)
			{
				errors.add("fatalerror", new ActionError(e.getStrutsMessage()));
				saveErrors(request, errors);
				forward = mapping.findForward("fatalError");
				return (forward);
			}
			else
			{
				errors.add(
					"addProperty",
					new ActionError(e.getStrutsMessage()));
				logger.debug("message " + e.getStrutsMessage());
			}

		}
		// If a message is required, save the specified key(s)
		// into the request for use by the <struts:errors> tag.*/
		forward = checkForErrors(mapping, request, errors);
		// Finish with
		return (forward);
	}
	public ActionForward checkForErrors(
		ActionMapping mapping,
		HttpServletRequest request,
		ActionErrors errors)
	{
		ActionForward forward;
		if (!errors.isEmpty())
		{
			saveErrors(request, errors);
			// Forward control to the appropriate 'failure' URI (change name as desired)
			forward = mapping.findForward("failure");
		}
		else
		{

			// Forward control to the appropriate 'success' URI (change name as desired)
			SearchPropertiesByCriteriaDTO searchDTO =
				(SearchPropertiesByCriteriaDTO) request
					.getSession()
					.getAttribute(
					"SearchPropertyDTO");
			if (searchDTO == null || searchDTO.getPropertyTypeId() == null)
			{
				searchDTO = new SearchPropertiesByCriteriaDTO();
				searchDTO.setPropertyTypeId(propertyDTO.getType().toString());
				searchDTO.setMaxPrice("9999999999");
				searchDTO.setMinPrice("0");
				searchDTO.setPostalCode("%");
				request.getSession().setAttribute("SearchPropertyDTO",searchDTO);
			}
			else if (searchDTO.getPropertyTypeId().equalsIgnoreCase("0"))
			{
				searchDTO.setPropertyTypeId(propertyDTO.getType().toString());
			}
			forward = mapping.findForward("success");
		}
		return forward;
	}

	public void addPropertyFeatures(
		PropertyDTO propertyDTO,
		PropertyFeatureVectorDTO propertyFeatureVectorDTO)
		throws ApplicationException
	{
		PropertyCatalogManager propertyCatalogManager;
		propertyCatalogManager = new PropertyCatalogManager();

		//The manager is executed using this call and arguments
		propertyCatalogManager.addPropertyFeatures(
			propertyDTO,
			propertyFeatureVectorDTO);
	}

	public PropertyDTO addProperty(PropertyDTO propertyDTO)
		throws ApplicationException
	{
		PropertyCatalogManager propertyCatalogManager;
		propertyCatalogManager = new PropertyCatalogManager();

		//The manager is executed using this call and arguments
		return propertyCatalogManager.addPropertyDetails(propertyDTO);
	}

	public PropertyFeatureVectorDTO populateFeatureVectorDTO(PropertyDetailsForm addPropertyDetailsForm)
	{
		PropertyFeatureVectorDTO propertyFeatureVectorDTO =
			new PropertyFeatureVectorDTO();

		PropertyFeatureDTO propertyFeature1DTO = new PropertyFeatureDTO();
		PropertyFeatureDTO propertyFeature2DTO = new PropertyFeatureDTO();
		PropertyFeatureDTO propertyFeature3DTO = new PropertyFeatureDTO();

		if (addPropertyDetailsForm.getValue1().length() > 0)
		{
			propertyFeature1DTO.setName(addPropertyDetailsForm.getName1());
			propertyFeature1DTO.setValue(addPropertyDetailsForm.getValue1());
			propertyFeatureVectorDTO.addElement(propertyFeature1DTO);
		}

		if (addPropertyDetailsForm.getValue2().length() > 0)
		{
			propertyFeature2DTO.setName(addPropertyDetailsForm.getName2());
			propertyFeature2DTO.setValue(addPropertyDetailsForm.getValue2());
			propertyFeatureVectorDTO.addElement(propertyFeature2DTO);
		}

		if (addPropertyDetailsForm.getValue3().length() > 0)
		{
			propertyFeature3DTO.setName(addPropertyDetailsForm.getName3());
			propertyFeature3DTO.setValue(addPropertyDetailsForm.getValue3());
			propertyFeatureVectorDTO.addElement(propertyFeature3DTO);
		}

		logger.debug(
			"feature 1 dto has value" + propertyFeature1DTO.getValue());
		logger.debug(
			"feature 2 dto has value" + propertyFeature2DTO.getValue());
		logger.debug(
			"feature 3 dto has value" + propertyFeature3DTO.getValue());
		return propertyFeatureVectorDTO;
	}

	public PropertyDTO populatePropertyDTO(PropertyDetailsForm addPropertyDetailsForm)
	{
		PropertyDTO propertyDTO;
		propertyDTO = new PropertyDTO();
		// Property ID is generated by the database and is not set here

		/*This section sets all of the data from the form in 
		 * the PropertyDTO.  The data will be passed to the
		 * PropertyCatalogManager.java class. */

        logger.info("ENTRY: populatePropertyDTO");
        try {
            PropertyUtils.copyProperties(propertyDTO, addPropertyDetailsForm);
        } catch (IllegalAccessException e1) {
            e1.printStackTrace();
        } catch (InvocationTargetException e1) {
            e1.printStackTrace();
        } catch (NoSuchMethodException e1) {
            e1.printStackTrace();
        }
        logger.info("EXIT:  populatePropertyDTO");

		return propertyDTO;
	}
}
