package com.ibm.itso.sal404.propertycatalog.action;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.log4j.Logger;
import org.apache.struts.action.Action;
import org.apache.struts.action.ActionError;
import org.apache.struts.action.ActionErrors;
import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionForward;
import org.apache.struts.action.ActionMapping;

import com.ibm.itso.sal404.common.exception.ApplicationException;
import com.ibm.itso.sal404.propertycatalog.PropertyCatalogManager;
import com.ibm.itso.sal404.propertycatalog.dto.SearchPropertiesByCriteriaDTO;
import com.ibm.itso.sal404.user.UserManager;
import com.ibm.itso.sal404.user.dto.UserVectorDTO;

/**
 * 
 * sal404 Realty sample application
 * 
 * @component 	PropertyCatalog component
 * @layer		Controller Layer
 * 
 * This action retrieves property types. Its called when the user 
 * selects Properties from the main menu.
 * 
 * @author 		Pasi Valjus
 * @created		May 25  2003	
 * @version		1.0.0 / @May 25, 2003	
 *
 * @see		 	to be completed
 * 
 */
public class PropertiesAction extends Action
{
	// Configure Log4J Logger 
	private static Logger logger =
		Logger.getLogger(PropertiesAction.class);

	/**
	* Constructor
	*/
	public PropertiesAction()
	{
		super();
	}
	public ActionForward execute(
		ActionMapping mapping,
		ActionForm form,
		HttpServletRequest request,
		HttpServletResponse response)
	{
		logger.info("ENTRY: execute");

		ActionErrors errors = new ActionErrors();
		ActionForward forward = new ActionForward();
		// return value
		try
		{
			PropertyCatalogManager propertyCatalogManager =
				new PropertyCatalogManager();

			setupSearchPropertiesByCriteriaDTO(request);
			setupAgents(request);
		}
		catch (ApplicationException e)
		{
			// Report the error using the appropriate name and ID.			
			if (e.getSeverityLevel() != 0)
			{
				errors.add("fatalerror", new ActionError(e.getStrutsMessage()));
				saveErrors(request, errors);
				forward = mapping.findForward("fatalError");
				return (forward);
			}
			else
				errors.add("properties", new ActionError(e.getStrutsMessage()));
		}
		catch (Exception e)
		{
			errors.add(
				"fatalerror",
				new ActionError("prop.error.general.failure"));
			saveErrors(request, errors);
			forward = mapping.findForward("fatalError");
			return (forward);
		}
		// If a message is required, save the specified key(s)
		// into the request for use by the <struts:errors> tag.
		forward = checkForErrors(mapping, request, errors);

		logger.info("EXIT:  execute");

		// Finish with
		return (forward);
	}
	public ActionForward checkForErrors(
		ActionMapping mapping,
		HttpServletRequest request,
		ActionErrors errors)
	{
		ActionForward forward;
		if (!errors.isEmpty())
		{
			saveErrors(request, errors);
			// Forward control to the appropriate 'failure' URI (change name as desired)
			forward = mapping.findForward("failure");
		}
		else
		{
			// Forward control to the appropriate 'success' URI (change name as desired)
			forward = mapping.findForward("success");
		}
		return forward;
	}

	/**
	 * 
	 * @param request
	 */
	public void setupSearchPropertiesByCriteriaDTO(HttpServletRequest request)
	{

		SearchPropertiesByCriteriaDTO searchByCriteriaDTO = null;
		if (request.getSession().getAttribute("SearchPropertyDTO") == null)
		{
			searchByCriteriaDTO = new SearchPropertiesByCriteriaDTO();
		}

		request.getSession().setAttribute(
			"SearchPropertyDTO",
			searchByCriteriaDTO);

	}
	public void setupAgents(HttpServletRequest request)
		throws ApplicationException
	{
		UserManager userManager = new UserManager();
		UserVectorDTO agentsAndAdministrators =
			userManager.getAgentsAndAdministrators();
		//Put the result from the search in the request
		request.getSession().setAttribute(
			"agentsAndAdministrators",
			agentsAndAdministrators.getUserVector());
	}

}
