package com.ibm.itso.sal404.propertycatalog.action;

import java.util.Vector;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;

import org.apache.struts.action.Action;
import org.apache.struts.action.ActionError;
import org.apache.struts.action.ActionErrors;
import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionForward;
import org.apache.struts.action.ActionMapping;

import com.ibm.itso.sal404.common.exception.ApplicationException;
import com.ibm.itso.sal404.propertycatalog.PropertyCatalogManager;
import com.ibm.itso.sal404.propertycatalog.dto.SearchPropertiesByCriteriaDTO;
import com.ibm.itso.sal404.propertycatalog.form.SearchPropertiesByCriteriaForm;

/**
 * 
 * sal404 Realty sample application
 * 
 * @component PropertyCatalog component
 * @layer Controller Layer
 * 
 * This action retrieves a list of properties. It's called when the user searchs
 * properties
 * 
 * @author Pasi Valjus
 * @created May 25 2003
 * @version 1.0.0 /
 * @May 25, 2003
 * 
 * @see to be completed
 *  
 */
public class SearchByCriteraAction extends Action
{

    /**
     * Constructor
     */
    public SearchByCriteraAction()
    {

        super();

    }

    public ActionForward execute(ActionMapping mapping, ActionForm form,
            HttpServletRequest request, HttpServletResponse response)
            throws Exception
    {

        ActionErrors errors = new ActionErrors();
        ActionForward forward = new ActionForward();
        // return value

        if (request.getParameter("new") != null)
        { //actions for adding property details
            SearchPropertiesByCriteriaDTO searchByCriteriaDTO = createSearchDTO(
                    form, request);
            forward = mapping.findForward("add");
            return forward;
        } else
        {

            try
            {

                SearchPropertiesByCriteriaDTO searchByCriteriaDTO = createSearchDTO(
                        form, request);

                //Create the manager and pass the DTO to the manager for search
                HttpSession session = request.getSession(true);
                Vector propertiesVector = propertiesVector = searchPropertiesByCriteria(searchByCriteriaDTO);

                //No properties found
                if (propertiesVector.size() == 0)
                    errors.add("no properties found", new ActionError(
                            "prop.results.found"));

                //Put the result from the search in the session
                session.setAttribute("propertyVectorDTO", propertiesVector);

            } catch (ApplicationException e)
            {
                // Report the error using the appropriate name and ID.
                if (e.getSeverityLevel() != 0)
                {
                    errors.add("fatalerror", new ActionError(e
                            .getStrutsMessage()));
                    saveErrors(request, errors);
                    forward = mapping.findForward("fatalError");
                    return (forward);
                } else
                    errors.add("searchByCriteria", new ActionError(e
                            .getStrutsMessage()));
            } catch (Exception e)
            {
                errors.add("fatalerror", new ActionError(
                        "prop.error.general.failure"));
                saveErrors(request, errors);
                forward = mapping.findForward("fatalError");
                return (forward);
            }
        }

        // If a message is required, save the specified key(s)
        // into the request for use by the <struts:errors> tag.

        forward = checkForErrors(mapping, request, errors);

        // Finish with
        return (forward);

    }

    public SearchPropertiesByCriteriaDTO createSearchDTO(ActionForm form,
            HttpServletRequest request)
    {
        SearchPropertiesByCriteriaDTO searchByCriteriaDTO = buildDTOFromForm(form);
        request.getSession().setAttribute("SearchPropertyDTO",
                searchByCriteriaDTO);
        return searchByCriteriaDTO;
    }

    public ActionForward checkForErrors(ActionMapping mapping,
            HttpServletRequest request, ActionErrors errors)
    {
        ActionForward forward;
        if (!errors.isEmpty())
        {
            saveErrors(request, errors);
            // Forward control to the appropriate 'failure' URI (change name as
            // desired)
            forward = mapping.findForward("failure");

        } else
        {

            // Forward control to the appropriate 'success' URI (change name as
            // desired)
            forward = mapping.findForward("success");

        }
        return forward;
    }

    public Vector searchPropertiesByCriteria(
            SearchPropertiesByCriteriaDTO searchByCriteriaDTO)
            throws ApplicationException
    {
        PropertyCatalogManager manager = new PropertyCatalogManager();
        Vector propertiesVector = manager.searchByCriteria(searchByCriteriaDTO);
        return propertiesVector;
    }

    public SearchPropertiesByCriteriaDTO buildDTOFromForm(ActionForm form)
    {
        SearchPropertiesByCriteriaDTO searchByCriteriaDTO = new SearchPropertiesByCriteriaDTO();

        //Read the Form and update the DTO
        SearchPropertiesByCriteriaForm searchPropertiesByCriteriaForm = (SearchPropertiesByCriteriaForm) form;
        searchByCriteriaDTO.setPropertyTypeId(searchPropertiesByCriteriaForm
                .getPropertyTypeId());
        //If no price to is selected then price from is set to "0"
        if (searchPropertiesByCriteriaForm.getMinPrice().equals(""))
            searchPropertiesByCriteriaForm.setMinPrice("0");
        searchByCriteriaDTO.setMinPrice(searchPropertiesByCriteriaForm
                .getMinPrice());
        if (searchPropertiesByCriteriaForm.getMaxPrice().equals(""))
            searchPropertiesByCriteriaForm.setMaxPrice("9999999999");
        searchByCriteriaDTO.setMaxPrice(searchPropertiesByCriteriaForm
                .getMaxPrice());
        StringBuffer buf = new StringBuffer(searchPropertiesByCriteriaForm
                .getPostalCode());
        buf.append("%");
        searchByCriteriaDTO.setPostalCode(buf.toString());

        return searchByCriteriaDTO;
    }
}