package com.ibm.itso.sal404.propertycatalog.form;

import java.math.BigDecimal;

import javax.servlet.http.HttpServletRequest;

import org.apache.log4j.Logger;
import org.apache.struts.action.ActionError;
import org.apache.struts.action.ActionErrors;
import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionMapping;

/**
 * 
 * sal404 Realty sample application
 * 
 * @component PropertyCatalog component
 * @layer Domain Layer
 * 
 * Description of the class here
 * 
 * @author Gwen Gaumond, Twinstar Incorporated
 * @created May 13, 2003
 * @version 1.0.0 /
 * @May 13, 2003
 * 
 * @see to be completed
 * 
 * 
 * Form bean for a Struts application. Users may access 15 fields on this form:
 * <ul>
 * <li>id - Property ID
 * <li>userId - User ID
 * <li>type - Property Type
 * <li>status - Property Status
 * <li>postalCode - Postal Code
 * <li>countryCode - Country Code
 * <li>region - Region
 * <li>municipality - Municipality
 * <li>streetName - Property Street Name
 * <li>buildingNumber - Building Number
 * <li>unitNumber - Unit Number
 * <li>postOfficeBox - Post Office Box
 * <li>additionalText - Additional Text
 * <li>sprice - Property Price
 * <li>pictureURL - Directory location and filename of picture of the property.
 * </ul>
 * @version 1.0
 * @author
 */
public class PropertyDetailsForm extends ActionForm {
    private static Logger logger = Logger
            .getLogger(PropertyDetailsForm.class);

    private String id = null;
    private Integer userId = null;
    private Integer type = null;
    private String postalCode;
    private String countryCode = null;
    private String region = null;
    private String municipality = null;
    private String streetName = null;
    private String buildingNumber = null;
    private String unitNumber = null;
    private String postOfficeBox = null;
    private String additionalText = null;
    private String sprice = null;
    private BigDecimal price = null;
    private String pictureURL = null;
    private String createdOn = null;
    private Integer status = null;
    private Integer agent = null;
    private Integer seller = null;

    //Features
    private String name1 = null;
    private String value1 = null;
    private String name2 = null;
    private String value2 = null;
    private String name3 = null;
    private String value3 = null;

    /**
     * Constructor
     */
    public PropertyDetailsForm() {
        super();
    }

    /**
     * 
     */
    public void reset(ActionMapping mapping, HttpServletRequest request) {
        // Reset values are provided as samples only. Change as appropriate.
        //id = null;
        //userId = null;
        seller = null;
        type = null;
        status = null;
        countryCode = null;
        region = null;
        municipality = null;
        streetName = null;
        buildingNumber = null;
        unitNumber = null;
        postOfficeBox = null;
        additionalText = null;
        sprice = null;
        pictureURL = null;
        postalCode = null;
        createdOn = null;
        name1 = null;
        value1 = null;
        name2 = null;
        value2 = null;
        name3 = null;
        value3 = null;
    }

    /**
     * 
     */
    public ActionErrors validate(ActionMapping mapping,
            HttpServletRequest request) {
        ActionErrors errors = new ActionErrors();

        logger.debug("Seller ID is: " + seller.toString());
        logger.debug("Country Code is: " +getCountryCode());
        
        if (getType().intValue() == 0) {
            errors.add("type", new ActionError(
                    "prop.error.addModify.type.required"));
        }

        if (getUserId() != null) {
            if (getUserId().intValue() == 0) {
                errors.add("type", new ActionError(
                        "prop.error.addModify.agent.required"));
            }
        } else {
            logger.debug("ID is: " + getId());
            setUserId(new Integer(getId()));
        }

        logger.debug("Status is " + getStatus());
        if (getStatus() == null) {
            errors.add("status", new ActionError(
                    "prop.error.addModify.status.required"));
        }

        //Postal Code is required
        if (getPostalCode().length() <= 0) {
            errors.add("postalCode", new ActionError(
                    "prop.error.addModify.postalCode.required"));
        }
        //Country Code is required
        if (getCountryCode().equals("0")) {
            errors.add("countryCode", new ActionError(
                    "prop.error.addModify.countryCode.required"));
        }
        //Municipality is required
        if (getMunicipality().length() <= 0) {
            errors.add("municipality", new ActionError(
                    "prop.error.addModify.municipality.required"));
        }
        //Street Name is required
        if (getStreetName().length() <= 0) {
            errors.add("streetName", new ActionError(
                    "prop.error.addModify.streetName.required"));
        }
        //Price is required
        if (getSprice().length() == 0) {
            errors.add("price", new ActionError(
                    "prop.error.addModify.price.required"));
        }
        //Price must contain numbers
        if (getSprice().length() > 0) {
            try {
                setPrice(new BigDecimal(getSprice()));
                BigDecimal maxPrice = new BigDecimal(9999999999.99);
                if (getPrice().max(maxPrice) == getPrice()) {
                    errors.add("price", new ActionError(
                            "prop.error.addModify.price.exceedsMax"));
                }
            } catch (NumberFormatException e) {
                errors.add("price", new ActionError(
                        "prop.error.addModify.price.notnumbers"));
            }
        }
        return errors;
    }

    /**
     * Get id
     * 
     * @return String
     */
    public String getId() {
        return id;
    }

    /**
     * Set id
     * 
     * @param <code>String</code>
     */
    public void setId(String i) {
        id = i;
    }

    /**
     * Get type
     * 
     * @return String
     */
    public Integer getType() {
        return (Integer) type;
    }

    /**
     * Set type
     * 
     * @param <code>String</code>
     */
    public void setType(Integer t) {
        type = t;
    }

    /**
     * Returns the postalCode.
     * 
     * @return String
     */
    public String getPostalCode() {
        return postalCode;
    }

    /**
     * Sets the postalCode.
     * 
     * @param postalCode
     *            The postalCode to set
     */
    public void setPostalCode(String pc) {
        this.postalCode = pc;
    }

    /**
     * Get countryCode
     * 
     * @return String
     */
    public String getCountryCode() {
        return countryCode;
    }

    /**
     * Set countryCode
     * 
     * @param <code>String</code>
     */
    public void setCountryCode(String c) {
        countryCode = c;
    }

    /**
     * Get region
     * 
     * @return String
     */
    public String getRegion() {
        return region;
    }

    /**
     * Set region
     * 
     * @param <code>String</code>
     */
    public void setRegion(String r) {
        region = r;
    }

    /**
     * Get municipality
     * 
     * @return String
     */
    public String getMunicipality() {
        return municipality;
    }

    /**
     * Set municipality
     * 
     * @param <code>String</code>
     */
    public void setMunicipality(String m) {
        municipality = m;
    }

    /**
     * Get streetName
     * 
     * @return String
     */
    public String getStreetName() {
        return streetName;
    }

    /**
     * Set streetName
     * 
     * @param <code>String</code>
     */
    public void setStreetName(String s) {
        streetName = s;
    }

    /**
     * Get buildingNumber
     * 
     * @return String
     */
    public String getBuildingNumber() {
        return buildingNumber;
    }

    /**
     * Set buildingNumber
     * 
     * @param <code>String</code>
     */
    public void setBuildingNumber(String b) {
        buildingNumber = b;
    }

    /**
     * Get unitNumber
     * 
     * @return String
     */
    public String getUnitNumber() {
        return unitNumber;
    }

    /**
     * Set unitNumber
     * 
     * @param <code>String</code>
     */
    public void setUnitNumber(String u) {
        unitNumber = u;
    }

    /**
     * Get postOfficeBox
     * 
     * @return String
     */
    public String getPostOfficeBox() {
        return postOfficeBox;
    }

    /**
     * Set postOfficeBox
     * 
     * @param <code>String</code>
     */
    public void setPostOfficeBox(String p) {
        postOfficeBox = p;
    }

    /**
     * Get additionalText
     * 
     * @return String
     */
    public String getAdditionalText() {
        return additionalText;
    }

    /**
     * Set additionalText
     * 
     * @param <code>String</code>
     */
    public void setAdditionalText(String a) {
        additionalText = a;
    }

    /**
     * Get pictureURL
     * 
     * @return String
     */
    public String getPictureURL() {
        return pictureURL;
    }

    /**
     * Set pictureURL
     * 
     * @param <code>String</code>
     */
    public void setPictureURL(String p) {
        pictureURL = p;
    }

    /**
     * Returns the createdOn.
     * 
     * @return String
     */
    public String getCreatedOn() {
        return createdOn;
    }

    /**
     * Sets the createdOn.
     * 
     * @param createdOn
     *            The createdOn to set
     */
    public void setCreatedOn(String co) {
        this.createdOn = co;
    }

    /**
     * Returns the sprice as a Double.
     * 
     * @return Double
     */
    public String getSprice() {
        return sprice;
    }

    /**
     * Returns the sprice as a Double.
     * 
     * @return Double
     * 
     * public Double getPriceAsDouble() { return sprice = Double.valueOf(sprice); }
     */
    /**
     * Sets the sprice.
     * 
     * @param sprice
     *            The sprice to set
     */
    public void setSprice(String price) {
        this.sprice = price;
    }

    /**
     * Returns the name1.
     * 
     * @return String
     */
    public String getName1() {
        return name1;
    }

    /**
     * Returns the name2.
     * 
     * @return String
     */
    public String getName2() {
        return name2;
    }

    /**
     * Returns the name3.
     * 
     * @return String
     */
    public String getName3() {
        return name3;
    }

    /**
     * Returns the value1.
     * 
     * @return String
     */
    public String getValue1() {
        return value1;
    }

    /**
     * Returns the value2.
     * 
     * @return String
     */
    public String getValue2() {
        return value2;
    }

    /**
     * Returns the value3.
     * 
     * @return String
     */
    public String getValue3() {
        return value3;
    }

    /**
     * Sets the name1.
     * 
     * @param name1
     *            The name1 to set
     */
    public void setName1(String name1) {
        this.name1 = name1;
    }

    /**
     * Sets the name2.
     * 
     * @param name2
     *            The name2 to set
     */
    public void setName2(String name2) {
        this.name2 = name2;
    }

    /**
     * Sets the name3.
     * 
     * @param name3
     *            The name3 to set
     */
    public void setName3(String name3) {
        this.name3 = name3;
    }

    /**
     * Sets the value1.
     * 
     * @param value1
     *            The value1 to set
     */
    public void setValue1(String value1) {
        this.value1 = value1;
    }

    /**
     * Sets the value2.
     * 
     * @param value2
     *            The value2 to set
     */
    public void setValue2(String value2) {
        this.value2 = value2;
    }

    /**
     * Sets the value3.
     * 
     * @param value3
     *            The value3 to set
     */
    public void setValue3(String value3) {
        this.value3 = value3;
    }

    /**
     * Returns the logger.
     * 
     * @return Logger
     */
    public static Logger getLogger() {
        return logger;
    }

    /**
     * Sets the logger.
     * 
     * @param logger
     *            The logger to set
     */
    public static void setLogger(Logger logger) {
        PropertyDetailsForm.logger = logger;
    }

    /**
     * Returns the status.
     * 
     * @return Integer
     */
    public Integer getStatus() {
        return status;
    }

    /**
     * Sets the status.
     * 
     * @param status
     *            The status to set
     */
    public void setStatus(Integer status) {
        this.status = status;
    }

    /**
     * Returns the agent.
     * 
     * @return Integer
     */
    public Integer getAgent() {
        return agent;
    }

    /**
     * Sets the agent.
     * 
     * @param agent
     *            The agent to set
     */
    public void setAgent(Integer agent) {
        this.agent = agent;
    }

    /**
     * Returns the userId.
     * 
     * @return Integer
     */
    public Integer getUserId() {
        return userId;
    }

    /**
     * Sets the userId.
     * 
     * @param userId
     *            The userId to set
     */
    public void setUserId(Integer userId) {
        this.userId = userId;
    }

    /**
     * Returns the price.
     * 
     * @return BigDecimal
     */
    public BigDecimal getPrice() {
        return price;
    }

    /**
     * Sets the price.
     * 
     * @param price
     *            The price to set
     */
    public void setPrice(BigDecimal decimalPrice) {
        this.price = decimalPrice;
    }

    /**
     * @return Returns the seller.
     */
    public Integer getSeller() {
        return seller;
    }

    /**
     * @param seller
     *            The seller to set.
     */
    public void setSeller(Integer seller) {
        this.seller = seller;
    }
}