package com.ibm.itso.sal404.user.action;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.apache.struts.action.Action;
import org.apache.struts.action.ActionError;
import org.apache.struts.action.ActionErrors;
import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionForward;
import org.apache.struts.action.ActionMapping;

import com.ibm.itso.sal404.common.exception.ApplicationException;
import com.ibm.itso.sal404.interestlist.InterestListManager;
import com.ibm.itso.sal404.user.UserSessionData;
import com.ibm.itso.sal404.user.dto.UserDetailsDTO;
import com.ibm.itso.sal404.user.form.LoginFormBean;

// Import Log4J Logger
import org.apache.log4j.Logger;

/**
 * 
 * sal404 Realty sample application
 * 
 * @component	User management
 * @layer		action
 * 
 * Description of the class here
 * 
 * @author 		Doug Grove
 * @created		initial creation date here		
 * @version		4/5/2003	
 *
 * @see		 	classes associated with this class
 * 
 */public class LoginAction extends Action
{
	// Configure Log4J Logger
	private static Logger logger = Logger.getLogger(LoginAction.class);

	/**
	* Constructor
	*/
	public LoginAction()
	{
		super();
	}
	
	public ActionForward execute(
		ActionMapping mapping,
		ActionForm form,
		HttpServletRequest request,
		HttpServletResponse response)
	{
		logger.info("ENTRY: execute");

		ActionErrors errors = new ActionErrors();
		ActionForward forward = new ActionForward();
		// return value
		LoginFormBean loginFormBean = (LoginFormBean) form;

		// Create DTO
		UserDetailsDTO userDetailsDTO = new UserDetailsDTO();
		userDetailsDTO.setUserName(loginFormBean.getUserName().trim());
		userDetailsDTO.setPassword(loginFormBean.getPassword());

		UserSessionData userSessionData = null;
		InterestListManager interestListManager = null;
		try
		{
		    userSessionData = (UserSessionData)request.getSession().getAttribute("userSessionData");
			
			// Call User Manager - if the login fails, the the User Manager throws
			// an exception.  If an exception is not thrown, then the login succeeded.
			userDetailsDTO = userSessionData.login(userDetailsDTO);
		}
		catch (ApplicationException ae)
		{
			// Report the error using the appropriate name and ID.
			errors.add("error", new ActionError(ae.getStrutsMessage()));
		}

		// If a message is required, save the specified key(s)
		// into the request for use by the <struts:errors> tag.
		if (!errors.isEmpty())
		{
			// null out everything on error
		    userSessionData.reset();
			request.getSession().setAttribute("interestList", null);

			saveErrors(request, errors);
			forward = mapping.findForward("failure");
		}
		else
		{
			request.getSession().setAttribute("interestList", 
				InterestListManager.getNewInterestList(userDetailsDTO));

			String uri = (String) request.getSession().getAttribute("requestedURI");
			if (uri != null)
			{
				forward = new ActionForward(uri);
				forward.setContextRelative(true);
				request.getSession().setAttribute("requestedURI", null);
				logger.debug("Requested URI is " + uri);
			}
			else
			{
				forward = mapping.findForward("success");
				logger.debug("Requested URI is null");
			}
		}

		logger.info("EXIT:  execute");
		// Finish with
		return (forward);
	}
}
