DROP DATABASE SAL301R;
CREATE DATABASE SAL301R ON C: ALIAS SAL301R USING CODESET UTF-8 TERRITORY US COLLATE USING SYSTEM WITH "SAL301R Information System";
CONNECT TO SAL301R USER DB2ADMIN;

CREATE TABLE CNTRY (
       CNTRY_ID             INTEGER NOT NULL GENERATED ALWAYS AS IDENTITY,
       CNTRY_CD             CHAR(4) NOT NULL,
       CNTRY_NAME           VARCHAR(60),
       PRIMARY KEY (CNTRY_ID)
);

CREATE UNIQUE INDEX XAK1CNTRY ON CNTRY
(
       CNTRY_CD                       ASC
);

CREATE TABLE USR (
       USR_ID               INTEGER NOT NULL GENERATED ALWAYS AS IDENTITY,
       USR_USERNAME         CHAR(20) NOT NULL,
       USR_PASSWORD         VARCHAR(20) NOT NULL,
       USR_ROLE             VARCHAR(20) NOT NULL,
       USR_FIRST_NAME       VARCHAR(40) NOT NULL,
       USR_LAST_NAME        VARCHAR(40) NOT NULL,
       USR_EMAIL_ADDR       VARCHAR(100),
       USR_WEB_URL          VARCHAR(200),
       USR_PHN_NUM          VARCHAR(20),
       USR_ACTIVE           CHAR NOT NULL,
       USR_CRD_ON           TIMESTAMP NOT NULL DEFAULT CURRENT TIMESTAMP,
       PRIMARY KEY (USR_ID)
);

CREATE UNIQUE INDEX XAK1USR ON USR
(
       USR_USERNAME                   ASC
);

CREATE  INDEX XAK2USR ON DB2ADMIN.USR (USR_ROLE ASC)  PCTFREE 10 MINPCTUSED 10;


CREATE TABLE USR_ADDR (
       USR_ADDR_ID          INTEGER NOT NULL GENERATED ALWAYS AS IDENTITY,
       USR_ID               INTEGER NOT NULL,
       USR_ADDR_NAME        VARCHAR(20),
       USR_ADDR_CNTRY_CD    CHAR(4),
       USR_ADDR_POST_CD     VARCHAR(20),
       USR_ADDR_RGN         VARCHAR(40),
       USR_ADDR_MUNI        VARCHAR(40),
       USR_ADDR_STRT_NAME   VARCHAR(100),
       USR_ADDR_BLDG_NUM    VARCHAR(10),
       USR_ADDR_UNIT_NUM    VARCHAR(10),
       USR_ADDR_PO_BOX      VARCHAR(10),
       USR_ADDR_ADDL_TEXT   VARCHAR(100),
       USR_CRD_ON           TIMESTAMP NOT NULL DEFAULT CURRENT TIMESTAMP,
       PRIMARY KEY (USR_ADDR_ID, USR_ID), 
       FOREIGN KEY (USR_ID)
                             REFERENCES USR
                             ON DELETE CASCADE

);


CREATE TABLE PROP_STS (
       PROP_STS_ID          INTEGER NOT NULL GENERATED ALWAYS AS IDENTITY,
       PROP_STS_DESC        VARCHAR(60),
       PRIMARY KEY (PROP_STS_ID)
);


CREATE TABLE PROP_TYPE (
       PROP_TYPE_ID         INTEGER NOT NULL GENERATED ALWAYS AS IDENTITY,
       PROP_TYPE_DESC       VARCHAR(60),
       PRIMARY KEY (PROP_TYPE_ID)
);


CREATE TABLE PROP (
       PROP_ID              INTEGER NOT NULL GENERATED ALWAYS AS IDENTITY,
       USR_ID               INTEGER NOT NULL,
       PROP_TYPE_ID         INTEGER NOT NULL,
       PROP_STATUS_ID       INTEGER NOT NULL,
       PROP_ADDR_CNTRY_CD   CHAR(4),
       PROP_ADDR_POST_CD    VARCHAR(20),
       PROP_ADDR_RGN        VARCHAR(40),
       PROP_ADDR_MUNI       VARCHAR(40),
       PROP_ADDR_STRT_NAM   VARCHAR(100),
       PROP_ADDR_BLDG_NUM   VARCHAR(10),
       PROP_ADDR_UNIT_NUM   VARCHAR(10),
       PROP_ADDR_PO_BOX     VARCHAR(10),
       PROP_ADDR_ADDL_TEX   VARCHAR(100),
       PROP_PRICE           DECIMAL(12,2) NOT NULL,
       PROP_PIC_URL         VARCHAR(200),
       PROP_CRD_ON          TIMESTAMP NOT NULL DEFAULT CURRENT TIMESTAMP,
       PRIMARY KEY (PROP_ID, USR_ID), 
       FOREIGN KEY (USR_ID)
                             REFERENCES USR
                             ON DELETE CASCADE

);

CREATE INDEX XIE1PROP ON PROP
(
       PROP_TYPE_ID                   ASC
);

CREATE INDEX XIE2PROP ON PROP
(
       PROP_PRICE                     ASC
);

CREATE INDEX XIE3PROP ON PROP
(
       PROP_ADDR_POST_CD              ASC
);


CREATE TABLE INT_LIST (
       INT_LIST_ID          INTEGER NOT NULL GENERATED ALWAYS AS IDENTITY,
       USR_ID              INTEGER NOT NULL,
       INT_LIST_CRD_ON      TIMESTAMP NOT NULL DEFAULT CURRENT TIMESTAMP,
       INT_LIST_MOD_ON      TIMESTAMP,
       PRIMARY KEY (INT_LIST_ID, USR_ID)
);


CREATE TABLE INT_LIST_ITM (
       INT_LIST_ITM_ID      INTEGER NOT NULL GENERATED ALWAYS AS IDENTITY,
       INT_LIST_ID          INTEGER NOT NULL,
       PROP_ID              INTEGER NOT NULL,
       INT_LIST_ITM_DESC    VARCHAR(200),
       INT_LIST_ITM_EMAIL   CHAR(1),
       INT_LIST_ITM_BROC    CHAR(1),
       PRIMARY KEY (INT_LIST_ITM_ID, INT_LIST_ID)
);

CREATE UNIQUE INDEX XAK1INT_LIST_ITM ON INT_LIST_ITM
(
       PROP_ID                        ASC,
       INT_LIST_ID                    ASC
);

CREATE TABLE NEWS_ITM (
       NEWS_ITM_ID          INTEGER NOT NULL GENERATED ALWAYS AS IDENTITY,
       NEWS_ITM_TITLE       VARCHAR(100),
       NEWS_ITM_DATE        DATE,
       NEWS_ITM_AUTHOR      VARCHAR(100),
       NEWS_ITM_BODY        LONG VARCHAR,
       PRIMARY KEY (NEWS_ITM_ID)
);


CREATE TABLE PROP_VLOG (
       PROP_VLOG_ID         INTEGER NOT NULL GENERATED ALWAYS AS IDENTITY,
       PROP_ID              INTEGER NOT NULL,
       PROP_VLOG_VIEW_BY    INTEGER,
       PROP_VLOG_CRD_ON     TIMESTAMP NOT NULL DEFAULT CURRENT TIMESTAMP,
       PRIMARY KEY (PROP_VLOG_ID, PROP_ID)
);

CREATE INDEX XIE1PROP_VLOG ON PROP_VLOG
(
       PROP_VLOG_VIEW_BY              ASC
);


CREATE TABLE PROP_FTR_ITM (
       PROP_FTR_ITM_ID      INTEGER NOT NULL GENERATED ALWAYS AS IDENTITY,
       PROP_ID              INTEGER NOT NULL,
       PROP_FTR_NAME        VARCHAR(100) NOT NULL,
       PROP_FTR_VALUE       VARCHAR(100),
       PRIMARY KEY (PROP_FTR_ITM_ID, PROP_ID)
);

CREATE TRIGGER TD_INT_LIST AFTER DELETE ON INT_LIST
REFERENCING OLD AS OLD FOR EACH ROW MODE DB2SQL
DELETE FROM INT_LIST_ITM WHERE
INT_LIST_ITM.INT_LIST_ID = OLD.INT_LIST_ID;


INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('AFGHANISTAN', 'AF');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('ALBANIA', 'AL');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('ALGERIA', 'DZ');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('AMERICAN SAMOA', 'AS');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('ANDORRA', 'AD');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('ANGOLA', 'AO');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('ANGUILLA', 'AI');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('ANTARCTICA', 'AQ');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('ANTIGUA AND BARBUDA', 'AG');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('ARGENTINA', 'AR');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('ARMENIA', 'AM');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('ARUBA', 'AW');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('AUSTRALIA', 'AU');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('AUSTRIA', 'AT');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('AZERBAIJAN', 'AZ');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('BAHAMAS', 'BS');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('BAHRAIN', 'BH');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('BANGLADESH', 'BD');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('BARBADOS', 'BB');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('BELARUS', 'BY');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('BELGIUM', 'BE');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('BELIZE', 'BZ');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('BENIN', 'BJ');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('BERMUDA', 'BM');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('BHUTAN', 'BT');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('BOLIVIA', 'BO');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('BOSNIA AND HERZEGOVINA', 'BA');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('BOTSWANA', 'BW');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('BOUVET ISLAND', 'BV');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('BRAZIL', 'BR');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('BRITISH INDIAN OCEAN TERRITORY', 'IO');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('BRUNEI DARUSSALAM', 'BN');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('BULGARIA', 'BG');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('BURKINA FASO', 'BF');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('BURUNDI', 'BI');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('CAMBODIA', 'KH');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('CAMEROON', 'CM');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('CANADA', 'CA');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('CAPE VERDE', 'CV');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('CAYMAN ISLANDS', 'KY');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('CENTRAL AFRICAN REPUBLIC', 'CF');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('CHAD', 'TD');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('CHILE', 'CL');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('CHINA', 'CN');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('CHRISTMAS ISLAND', 'CX');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('COCOS (KEELING) ISLANDS', 'CC');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('COLOMBIA', 'CO');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('COMOROS', 'KM');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('CONGO', 'CG');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('CONGO, THE DEMOCRATIC REPUBLIC OF THE', 'CD');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('COOK ISLANDS', 'CK');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('COSTA RICA', 'CR');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('CROATIA', 'HR');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('CUBA', 'CU');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('CYPRUS', 'CY');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('CZECH REPUBLIC', 'CZ');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('DENMARK', 'DK');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('DJIBOUTI', 'DJ');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('DOMINICA', 'DM');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('DOMINICAN REPUBLIC', 'DO');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('ECUADOR', 'EC');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('EGYPT', 'EG');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('EL SALVADOR', 'SV');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('EQUATORIAL GUINEA', 'GQ');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('ERITREA', 'ER');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('ESTONIA', 'EE');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('ETHIOPIA', 'ET');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('FALKLAND ISLANDS (MALVINAS)', 'FK');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('FAROE ISLANDS', 'FO');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('FIJI', 'FJ');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('FINLAND', 'FI');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('FRANCE', 'FR');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('FRENCH GUIANA', 'GF');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('FRENCH POLYNESIA', 'PF');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('FRENCH SOUTHERN TERRITORIES', 'TF');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('GABON', 'GA');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('GAMBIA', 'GM');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('GEORGIA', 'GE');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('GERMANY', 'DE');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('GHANA', 'GH');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('GIBRALTAR', 'GI');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('GREECE', 'GR');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('GREENLAND', 'GL');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('GRENADA', 'GD');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('GUADELOUPE', 'GP');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('GUAM', 'GU');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('GUATEMALA', 'GT');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('GUINEA', 'GN');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('GUINEA-BISSAU', 'GW');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('GUYANA', 'GY');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('HAITI', 'HT');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('HEARD ISLAND AND MCDONALD ISLANDS', 'HM');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('HOLY SEE (VATICAN CITY STATE)', 'VA');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('HONDURAS', 'HN');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('HONG KONG', 'HK');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('HUNGARY', 'HU');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('ICELAND', 'IS');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('INDIA', 'IN');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('INDONESIA', 'ID');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('IRAN, ISLAMIC REPUBLIC OF', 'IR');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('IRAQ', 'IQ');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('IRELAND', 'IE');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('ISRAEL', 'IL');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('ITALY', 'IT');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('JAMAICA', 'JM');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('JAPAN', 'JP');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('JORDAN', 'JO');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('KAZAKHSTAN', 'KZ');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('KENYA', 'KE');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('KIRIBATI', 'KI');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('KOREA, DEMOCRATIC PEOPLE''S REPUBLIC OF', 'KP');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('KOREA, REPUBLIC OF', 'KR');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('KUWAIT', 'KW');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('KYRGYZSTAN', 'KG');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('LAO PEOPLE''S DEMOCRATIC REPUBLIC', 'LA');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('LATVIA', 'LV');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('LEBANON', 'LB');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('LESOTHO', 'LS');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('LIBERIA', 'LR');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('LIBYAN ARAB JAMAHIRIYA', 'LY');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('LIECHTENSTEIN', 'LI');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('LITHUANIA', 'LT');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('LUXEMBOURG', 'LU');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('MACAO', 'MO');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('MACEDONIA, THE FORMER YUGOSLAV REPUBLIC OF', 'MK');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('MADAGASCAR', 'MG');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('MALAWI', 'MW');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('MALAYSIA', 'MY');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('MALDIVES', 'MV');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('MALI', 'ML');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('MALTA', 'MT');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('MARSHALL ISLANDS', 'MH');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('MARTINIQUE', 'MQ');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('MAURITANIA', 'MR');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('MAURITIUS', 'MU');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('MAYOTTE', 'YT');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('MEXICO', 'MX');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('MICRONESIA, FEDERATED STATES OF', 'FM');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('MOLDOVA, REPUBLIC OF', 'MD');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('MONACO', 'MC');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('MONGOLIA', 'MN');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('MONTSERRAT', 'MS');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('MOROCCO', 'MA');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('MOZAMBIQUE', 'MZ');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('MYANMAR', 'MM');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('NAMIBIA', 'NA');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('NAURU', 'NR');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('NEPAL', 'NP');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('NETHERLANDS', 'NL');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('NETHERLANDS ANTILLES', 'AN');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('NEW CALEDONIA', 'NC');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('NEW ZEALAND', 'NZ');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('NICARAGUA', 'NI');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('NIGER', 'NE');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('NIGERIA', 'NG');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('NIUE', 'NU');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('NORFOLK ISLAND', 'NF');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('NORTHERN MARIANA ISLANDS', 'MP');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('NORWAY', 'NO');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('OMAN', 'OM');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('PAKISTAN', 'PK');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('PALAU', 'PW');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('PALESTINIAN TERRITORY, OCCUPIED', 'PS');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('PANAMA', 'PA');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('PAPUA NEW GUINEA', 'PG');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('PARAGUAY', 'PY');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('PERU', 'PE');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('PHILIPPINES', 'PH');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('PITCAIRN', 'PN');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('POLAND', 'PL');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('PORTUGAL', 'PT');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('PUERTO RICO', 'PR');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('QATAR', 'QA');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('REUNION', 'RE');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('ROMANIA', 'RO');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('RUSSIAN FEDERATION', 'RU');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('RWANDA', 'RW');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('SAINT HELENA', 'SH');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('SAINT KITTS AND NEVIS', 'KN');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('SAINT LUCIA', 'LC');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('SAINT PIERRE AND MIQUELON', 'PM');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('SAINT VINCENT AND THE GRENADINES', 'VC');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('SAMOA', 'WS');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('SAN MARINO', 'SM');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('SAO TOME AND PRINCIPE', 'ST');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('SAUDI ARABIA', 'SA');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('SENEGAL', 'SN');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('SEYCHELLES', 'SC');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('SIERRA LEONE', 'SL');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('SINGAPORE', 'SG');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('SLOVAKIA', 'SK');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('SLOVENIA', 'SI');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('SOLOMON ISLANDS', 'SB');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('SOMALIA', 'SO');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('SOUTH AFRICA', 'ZA');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('SOUTH GEORGIA AND THE SOUTH SANDWICH ISLANDS', 'GS');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('SPAIN', 'ES');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('SRI LANKA', 'LK');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('SUDAN', 'SD');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('SURINAME', 'SR');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('SVALBARD AND JAN MAYEN', 'SJ');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('SWAZILAND', 'SZ');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('SWEDEN', 'SE');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('SWITZERLAND', 'CH');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('SYRIAN ARAB REPUBLIC', 'SY');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('TAIWAN, PROVINCE OF CHINA', 'TW');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('TAJIKISTAN', 'TJ');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('TANZANIA, UNITED REPUBLIC OF', 'TZ');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('THAILAND', 'TH');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('TIMOR-LESTE', 'TL');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('TOGO', 'TG');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('TOKELAU', 'TK');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('TONGA', 'TO');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('TRINIDAD AND TOBAGO', 'TT');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('TUNISIA', 'TN');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('TURKEY', 'TR');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('TURKMENISTAN', 'TM');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('TURKS AND CAICOS ISLANDS', 'TC');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('TUVALU', 'TV');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('UGANDA', 'UG');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('UKRAINE', 'UA');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('UNITED ARAB EMIRATES', 'AE');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('UNITED KINGDOM', 'GB');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('UNITED STATES', 'US');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('UNITED STATES MINOR OUTLYING ISLANDS', 'UM');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('URUGUAY', 'UY');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('UZBEKISTAN', 'UZ');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('VANUATU', 'VU');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('VENEZUELA', 'VE');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('VIET NAM', 'VN');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('VIRGIN ISLANDS, BRITISH', 'VG');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('VIRGIN ISLANDS, U.S.', 'VI');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('WALLIS AND FUTUNA', 'WF');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('WESTERN SAHARA', 'EH');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('YEMEN', 'YE');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('YUGOSLAVIA', 'YU');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('ZAMBIA', 'ZM');
INSERT INTO CNTRY (CNTRY_NAME, CNTRY_CD) VALUES ('ZIMBABWE', 'ZW');

INSERT INTO PROP_TYPE (PROP_TYPE_DESC) VALUES ('Single Family Dwelling');
INSERT INTO PROP_TYPE (PROP_TYPE_DESC) VALUES ('Condominium');
INSERT INTO PROP_TYPE (PROP_TYPE_DESC) VALUES ('Attached Dwelling');

INSERT INTO PROP_STS (PROP_STS_DESC) VALUES ('Active');
INSERT INTO PROP_STS (PROP_STS_DESC) VALUES ('Sold');
INSERT INTO PROP_STS (PROP_STS_DESC) VALUES ('Backup Offers');
INSERT INTO PROP_STS (PROP_STS_DESC) VALUES ('Escrow');

INSERT INTO USR (USR_USERNAME, USR_PASSWORD, USR_ROLE, USR_FIRST_NAME, USR_LAST_NAME, USR_ACTIVE) VALUES ('bill', 'password', 'Administrators', 'Bill', 'Moore', 'Y');
INSERT INTO USR (USR_USERNAME, USR_PASSWORD, USR_ROLE, USR_FIRST_NAME, USR_LAST_NAME, USR_ACTIVE) VALUES ('ilaria', 'password', 'Agents', 'Ilaria', 'Gorla', 'Y');
INSERT INTO USR (USR_USERNAME, USR_PASSWORD, USR_ROLE, USR_FIRST_NAME, USR_LAST_NAME, USR_ACTIVE) VALUES ('john', 'password', 'Customers', 'John', 'Bo', 'Y');
INSERT INTO USR (USR_USERNAME, USR_PASSWORD, USR_ROLE, USR_FIRST_NAME, USR_LAST_NAME, USR_ACTIVE) VALUES ('mark', 'password', 'Agents', 'Mark', 'Buensalido', 'Y');
INSERT INTO USR (USR_USERNAME, USR_PASSWORD, USR_ROLE, USR_FIRST_NAME, USR_LAST_NAME, USR_ACTIVE) VALUES ('pasi', 'password', 'Customers', 'Pasi', 'Valjus', 'Y');
INSERT INTO USR (USR_USERNAME, USR_PASSWORD, USR_ROLE, USR_FIRST_NAME, USR_LAST_NAME, USR_ACTIVE) VALUES ('stelios', 'password', 'Administrators', 'Stelios', 'Psarras', 'Y');
INSERT INTO USR (USR_USERNAME, USR_PASSWORD, USR_ROLE, USR_FIRST_NAME, USR_LAST_NAME, USR_ACTIVE) VALUES ('doug', 'password', 'Customers', 'Doug', 'Grove', 'Y');
INSERT INTO USR (USR_USERNAME, USR_PASSWORD, USR_ROLE, USR_FIRST_NAME, USR_LAST_NAME, USR_ACTIVE) VALUES ('cust1', 'password', 'Customers', 'cust1', 'cust1', 'Y');

INSERT INTO USR_ADDR (USR_ID,USR_ADDR_NAME,USR_ADDR_CNTRY_CD,USR_ADDR_POST_CD,USR_ADDR_STRT_NAME) VALUES (1, '1 Somewhere', 'US', '27709', 'A Long Street');
INSERT INTO USR_ADDR (USR_ID,USR_ADDR_NAME,USR_ADDR_CNTRY_CD,USR_ADDR_POST_CD,USR_ADDR_STRT_NAME) VALUES (2, '2 Somewhere', 'US', '27709', 'A Long Street');
INSERT INTO USR_ADDR (USR_ID,USR_ADDR_NAME,USR_ADDR_CNTRY_CD,USR_ADDR_POST_CD,USR_ADDR_STRT_NAME) VALUES (3, '3 Somewhere', 'US', '27709', 'A Long Street');
INSERT INTO USR_ADDR (USR_ID,USR_ADDR_NAME,USR_ADDR_CNTRY_CD,USR_ADDR_POST_CD,USR_ADDR_STRT_NAME) VALUES (4, '4 Somewhere', 'US', '27709', 'A Long Street');
INSERT INTO USR_ADDR (USR_ID,USR_ADDR_NAME,USR_ADDR_CNTRY_CD,USR_ADDR_POST_CD,USR_ADDR_STRT_NAME) VALUES (5, '5 Somewhere', 'US', '27709', 'A Long Street');
INSERT INTO USR_ADDR (USR_ID,USR_ADDR_NAME,USR_ADDR_CNTRY_CD,USR_ADDR_POST_CD,USR_ADDR_STRT_NAME) VALUES (6, '6 Somewhere', 'US', '27709', 'A Long Street');
INSERT INTO USR_ADDR (USR_ID,USR_ADDR_NAME,USR_ADDR_CNTRY_CD,USR_ADDR_POST_CD,USR_ADDR_STRT_NAME) VALUES (7, '7 Somewhere', 'US', '27709', 'A Long Street');
INSERT INTO USR_ADDR (USR_ID,USR_ADDR_NAME,USR_ADDR_CNTRY_CD,USR_ADDR_POST_CD,USR_ADDR_STRT_NAME) VALUES (8, '8 Somewhere', 'US', '27709', 'A Long Street');



INSERT INTO PROP (USR_ID, PROP_TYPE_ID, PROP_STATUS_ID, PROP_ADDR_CNTRY_CD, PROP_ADDR_POST_CD, PROP_ADDR_RGN, PROP_ADDR_MUNI, PROP_ADDR_STRT_NAM, PROP_ADDR_BLDG_NUM, PROP_ADDR_UNIT_NUM, PROP_PRICE) VALUES (2, 1, 1, 'US', '92651', 'CA','Laguna Beach', '182 EMERALD BAY', null, null, 6950000);
INSERT INTO PROP (USR_ID, PROP_TYPE_ID, PROP_STATUS_ID, PROP_ADDR_CNTRY_CD, PROP_ADDR_POST_CD, PROP_ADDR_RGN, PROP_ADDR_MUNI, PROP_ADDR_STRT_NAM, PROP_ADDR_BLDG_NUM, PROP_ADDR_UNIT_NUM, PROP_PRICE) VALUES (4, 1, 1, 'US', '90742', 'CA','Sunset Beach', '17055 S PACIFIC AVENUE', null, null, 2400000);
INSERT INTO PROP (USR_ID, PROP_TYPE_ID, PROP_STATUS_ID, PROP_ADDR_CNTRY_CD, PROP_ADDR_POST_CD, PROP_ADDR_RGN, PROP_ADDR_MUNI, PROP_ADDR_STRT_NAM, PROP_ADDR_BLDG_NUM, PROP_ADDR_UNIT_NUM, PROP_PRICE) VALUES (4, 1, 1, 'US', '92675', 'CA','San Juan Capistrano', '33762 VALLE ROAD', null, null, 2397000);
INSERT INTO PROP (USR_ID, PROP_TYPE_ID, PROP_STATUS_ID, PROP_ADDR_CNTRY_CD, PROP_ADDR_POST_CD, PROP_ADDR_RGN, PROP_ADDR_MUNI, PROP_ADDR_STRT_NAM, PROP_ADDR_BLDG_NUM, PROP_ADDR_UNIT_NUM, PROP_PRICE) VALUES (2, 1, 1, 'US', '92675', 'CA','San Juan Capistrano', '30862 STEEPLECHASE DRIVE', null, null, 2750000);
INSERT INTO PROP (USR_ID, PROP_TYPE_ID, PROP_STATUS_ID, PROP_ADDR_CNTRY_CD, PROP_ADDR_POST_CD, PROP_ADDR_RGN, PROP_ADDR_MUNI, PROP_ADDR_STRT_NAM, PROP_ADDR_BLDG_NUM, PROP_ADDR_UNIT_NUM, PROP_PRICE) VALUES (2, 1, 1, 'US', '92675', 'CA','San Juan Capistrano', '31540 PEPPERTREE BEND', null, null, 7250000);
INSERT INTO PROP (USR_ID, PROP_TYPE_ID, PROP_STATUS_ID, PROP_ADDR_CNTRY_CD, PROP_ADDR_POST_CD, PROP_ADDR_RGN, PROP_ADDR_MUNI, PROP_ADDR_STRT_NAM, PROP_ADDR_BLDG_NUM, PROP_ADDR_UNIT_NUM, PROP_PRICE) VALUES (4, 2, 1, 'US', '92672', 'CA','San Clemente', '911 BUENA VISTA', null, '1', 2100000);
INSERT INTO PROP (USR_ID, PROP_TYPE_ID, PROP_STATUS_ID, PROP_ADDR_CNTRY_CD, PROP_ADDR_POST_CD, PROP_ADDR_RGN, PROP_ADDR_MUNI, PROP_ADDR_STRT_NAM, PROP_ADDR_BLDG_NUM, PROP_ADDR_UNIT_NUM, PROP_PRICE) VALUES (2, 1, 1, 'US', '92705', 'CA','North Tustin', '1899 HOLLY TREE LANE', null, null, 2950000);
INSERT INTO PROP (USR_ID, PROP_TYPE_ID, PROP_STATUS_ID, PROP_ADDR_CNTRY_CD, PROP_ADDR_POST_CD, PROP_ADDR_RGN, PROP_ADDR_MUNI, PROP_ADDR_STRT_NAM, PROP_ADDR_BLDG_NUM, PROP_ADDR_UNIT_NUM, PROP_PRICE) VALUES (4, 1, 1, 'US', '92657', 'CA','Newport Coast', '3 RIM RIDGE', null, null, 11500000);
INSERT INTO PROP (USR_ID, PROP_TYPE_ID, PROP_STATUS_ID, PROP_ADDR_CNTRY_CD, PROP_ADDR_POST_CD, PROP_ADDR_RGN, PROP_ADDR_MUNI, PROP_ADDR_STRT_NAM, PROP_ADDR_BLDG_NUM, PROP_ADDR_UNIT_NUM, PROP_PRICE) VALUES (2, 1, 1, 'US', '92657', 'CA','Newport Coast', '2 PENINSULA', null, null, 2795000);
INSERT INTO PROP (USR_ID, PROP_TYPE_ID, PROP_STATUS_ID, PROP_ADDR_CNTRY_CD, PROP_ADDR_POST_CD, PROP_ADDR_RGN, PROP_ADDR_MUNI, PROP_ADDR_STRT_NAM, PROP_ADDR_BLDG_NUM, PROP_ADDR_UNIT_NUM, PROP_PRICE) VALUES (4, 1, 1, 'US', '92663', 'CA','Newport Beach', '1721 KINGS ROAD', null, null, 2895000);
INSERT INTO PROP (USR_ID, PROP_TYPE_ID, PROP_STATUS_ID, PROP_ADDR_CNTRY_CD, PROP_ADDR_POST_CD, PROP_ADDR_RGN, PROP_ADDR_MUNI, PROP_ADDR_STRT_NAM, PROP_ADDR_BLDG_NUM, PROP_ADDR_UNIT_NUM, PROP_PRICE) VALUES (4, 1, 1, 'US', '90802', 'CA','Long Beach', '1804 E OCEAN BLVD', null, null, 2499000);
INSERT INTO PROP (USR_ID, PROP_TYPE_ID, PROP_STATUS_ID, PROP_ADDR_CNTRY_CD, PROP_ADDR_POST_CD, PROP_ADDR_RGN, PROP_ADDR_MUNI, PROP_ADDR_STRT_NAM, PROP_ADDR_BLDG_NUM, PROP_ADDR_UNIT_NUM, PROP_PRICE) VALUES (2, 1, 1, 'US', '90803', 'CA','Long Beach', '6067 LIDO LANE', null, null, 2250000);
INSERT INTO PROP (USR_ID, PROP_TYPE_ID, PROP_STATUS_ID, PROP_ADDR_CNTRY_CD, PROP_ADDR_POST_CD, PROP_ADDR_RGN, PROP_ADDR_MUNI, PROP_ADDR_STRT_NAM, PROP_ADDR_BLDG_NUM, PROP_ADDR_UNIT_NUM, PROP_PRICE) VALUES (4, 1, 1, 'US', '92677', 'CA','Laguna Niguel', '4 JENCOURT', null, null, 4100000);
INSERT INTO PROP (USR_ID, PROP_TYPE_ID, PROP_STATUS_ID, PROP_ADDR_CNTRY_CD, PROP_ADDR_POST_CD, PROP_ADDR_RGN, PROP_ADDR_MUNI, PROP_ADDR_STRT_NAM, PROP_ADDR_BLDG_NUM, PROP_ADDR_UNIT_NUM, PROP_PRICE) VALUES (4, 1, 1, 'US', '92677', 'CA','Laguna Niguel', '6 WILDFLOWER', null, null, 2395000);
INSERT INTO PROP (USR_ID, PROP_TYPE_ID, PROP_STATUS_ID, PROP_ADDR_CNTRY_CD, PROP_ADDR_POST_CD, PROP_ADDR_RGN, PROP_ADDR_MUNI, PROP_ADDR_STRT_NAM, PROP_ADDR_BLDG_NUM, PROP_ADDR_UNIT_NUM, PROP_PRICE) VALUES (2, 1, 1, 'US', '92677', 'CA','Laguna Niguel', '3 UPPER VINTAGE', null, null, 2750000);
INSERT INTO PROP (USR_ID, PROP_TYPE_ID, PROP_STATUS_ID, PROP_ADDR_CNTRY_CD, PROP_ADDR_POST_CD, PROP_ADDR_RGN, PROP_ADDR_MUNI, PROP_ADDR_STRT_NAM, PROP_ADDR_BLDG_NUM, PROP_ADDR_UNIT_NUM, PROP_PRICE) VALUES (4, 1, 1, 'US', '92677', 'CA','Laguna Niguel', '25 LE CONTE', null, null, 2150000);
INSERT INTO PROP (USR_ID, PROP_TYPE_ID, PROP_STATUS_ID, PROP_ADDR_CNTRY_CD, PROP_ADDR_POST_CD, PROP_ADDR_RGN, PROP_ADDR_MUNI, PROP_ADDR_STRT_NAM, PROP_ADDR_BLDG_NUM, PROP_ADDR_UNIT_NUM, PROP_PRICE) VALUES (4, 1, 1, 'US', '92677', 'CA','Laguna Niguel', '31902 MONARCH CREST', null, null, 2490000);
INSERT INTO PROP (USR_ID, PROP_TYPE_ID, PROP_STATUS_ID, PROP_ADDR_CNTRY_CD, PROP_ADDR_POST_CD, PROP_ADDR_RGN, PROP_ADDR_MUNI, PROP_ADDR_STRT_NAM, PROP_ADDR_BLDG_NUM, PROP_ADDR_UNIT_NUM, PROP_PRICE) VALUES (2, 1, 1, 'US', '90631', 'CA','La Habra Heights', '2301 SKYLINE DRIVE', null, null, 2250000);
INSERT INTO PROP (USR_ID, PROP_TYPE_ID, PROP_STATUS_ID, PROP_ADDR_CNTRY_CD, PROP_ADDR_POST_CD, PROP_ADDR_RGN, PROP_ADDR_MUNI, PROP_ADDR_STRT_NAM, PROP_ADDR_BLDG_NUM, PROP_ADDR_UNIT_NUM, PROP_PRICE) VALUES (4, 1, 1, 'US', '92651', 'CA','Laguna Beach', '48 N VISTA DE CATALINA', null, null, 2485000);
INSERT INTO PROP (USR_ID, PROP_TYPE_ID, PROP_STATUS_ID, PROP_ADDR_CNTRY_CD, PROP_ADDR_POST_CD, PROP_ADDR_RGN, PROP_ADDR_MUNI, PROP_ADDR_STRT_NAM, PROP_ADDR_BLDG_NUM, PROP_ADDR_UNIT_NUM, PROP_PRICE) VALUES (2, 1, 1, 'US', '92651', 'CA','Laguna Beach', '10 BAY DRIVE', null, null, 4400000);


CONNECT RESET;